@@ -2,7 +2,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -121,7 +121,7 @@ public:
     unsigned int getPortCount() const { return m_ports.size(); }
 
     // export
-    std::string toXmlString() const;
+    std::string toXmlString() const override;
 
     // Is the instance assigned to a plugin?
     //
