@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -82,7 +82,7 @@ Segment *
 Clipboard::getSingleSegment() const
 {
     if (isSingleSegment()) return *begin();
-    else return 0;
+    else return nullptr;
 }
 
 bool
