@@ -49,7 +49,7 @@ public:
     static const DeviceId NO_DEVICE;
     static const DeviceId ALL_DEVICES;
     // The "external controller" ALSA port that we create.
-    static const DeviceId CONTROL_DEVICE;
+    static const DeviceId EXTERNAL_CONTROLLER;
 
     Device(DeviceId id, const std::string &name, DeviceType type):
         m_name(name), m_type(type), m_id(id) { }
@@ -96,8 +96,6 @@ public:
      */
     void sendChannelSetups();
 
-    void setConnection(std::string connection)  { m_connection = connection; }
-
 protected:
     virtual void addInstrument(Instrument *) = 0;
     virtual void renameInstruments() = 0;
@@ -106,7 +104,6 @@ protected:
     std::string        m_name;
     DeviceType         m_type;
     DeviceId           m_id;
-    std::string        m_connection;
 };
 
 }
