@@ -18,6 +18,7 @@
 #include "Instrument.h"
 
 #include "base/AllocateChannels.h"
+#include "base/AudioLevel.h"
 #include "base/AudioPluginInstance.h"
 #include "sound/ControlBlock.h"
 #include "misc/Debug.h"
@@ -55,8 +56,6 @@ Instrument::Instrument(InstrumentId id,
     m_device(device),
     m_sendBankSelect(false),
     m_sendProgramChange(false),
-    m_sendPan(false),
-    m_sendVolume(false),
     m_mappedId(0),
     m_audioInput(1000),
     m_audioInputChannel(0),
@@ -97,14 +96,12 @@ Instrument::Instrument(InstrumentId id,
     m_transpose(MidiMidValue),
     m_pan(MidiMidValue),
     m_volume(100),
-    m_fixed(false), // However, this ctor isn't used for MIDI.
+    m_fixed(true),  // Always fixed channel for audio/softsynth.
     m_level(0.0),
     m_recordLevel(0.0),
     m_device(device),
     m_sendBankSelect(false),
     m_sendProgramChange(false),
-    m_sendPan(false),
-    m_sendVolume(false),
     m_mappedId(0),
     m_audioInput(1000),
     m_audioInputChannel(0),
@@ -171,8 +168,6 @@ Instrument::Instrument(const Instrument &ins):
     m_device(ins.getDevice()),
     m_sendBankSelect(ins.sendsBankSelect()),
     m_sendProgramChange(ins.sendsProgramChange()),
-    m_sendPan(ins.sendsPan()),
-    m_sendVolume(ins.sendsVolume()),
     m_mappedId(ins.getMappedId()),
     m_audioInput(ins.m_audioInput),
     m_audioInputChannel(ins.m_audioInputChannel),
@@ -222,8 +217,6 @@ Instrument::operator=(const Instrument &ins)
     m_device = ins.getDevice();
     m_sendBankSelect = ins.sendsBankSelect();
     m_sendProgramChange = ins.sendsProgramChange();
-    m_sendPan = ins.sendsPan();
-    m_sendVolume = ins.sendsVolume();
     m_mappedId = ins.getMappedId();
     m_audioInput = ins.m_audioInput;
     m_audioInputChannel = ins.m_audioInputChannel;
@@ -604,6 +597,8 @@ Instrument::setControllerValue(MidiByte controller, MidiByte value)
         setVolume(value);
     }
 
+    // If it's in m_staticControllers, update it.
+
     for (StaticControllers::iterator it = m_staticControllers.begin();
          it != m_staticControllers.end(); ++it)
     {
@@ -615,11 +610,24 @@ Instrument::setControllerValue(MidiByte controller, MidiByte value)
         }
     }
 
+    // It's not in m_staticControllers, add it.
+
     m_staticControllers.push_back(ControllerValuePair(controller, value));
 
     emit changedChannelSetup();
 }
 
+bool
+Instrument::hasController(MidiByte controlNumber) const
+{
+    for (const StaticControllers::value_type &pair : m_staticControllers) {
+        if (pair.first == controlNumber)
+            return true;
+    }
+
+    return false;
+}
+
 MidiByte
 Instrument::getControllerValue(MidiByte controller) const
 {
@@ -721,6 +729,33 @@ Instrument::getStaticSignals()
     return instrumentStaticSignals;
 }
 
+MidiByte Instrument::getVolumeCC() const
+{
+    // MIDI
+    if (m_type == Midi) {
+        return m_volume;
+    } else {  // Audio
+        return static_cast<MidiByte>(AudioLevel::dB_to_fader(
+                m_level,  // dB
+                127,  // maxLevel
+                AudioLevel::LongFader));  // type
+    }
+}
+
+MidiByte Instrument::getPanCC() const
+{
+    // MIDI
+    if (m_type == Midi) {
+        return m_pan;
+    } else {  // Audio
+        // Scale 0-200 to 0-127.
+        MidiByte pan = AudioLevel::MIDIPanI(m_pan);
+        if (pan > 127)
+            return 127;
+        return pan;
+    }
+}
+
 
 }
 
