@@ -16,7 +16,7 @@
 #define RG_MODULE_STRING "[MidiDevice]"
 
 #include "MidiDevice.h"
-#include "sound/Midi.h"
+#include "sound/Midi.h"  // For MIDI_CONTROLLER_VOLUME, etc...
 #include "base/AllocateChannels.h"
 #include "base/ControlParameter.h"
 #include "base/Instrument.h"
@@ -554,14 +554,14 @@ MidiDevice::toXmlString() const
     std::stringstream midiDevice;
 
     midiDevice << "    <device id=\""  << m_id 
-               << "\" name=\""         << m_name 
+               << "\" name=\""         << encode(m_name)
                << "\" direction=\""    << (m_direction == Play ?
                                            "play" : "record")
                << "\" variation=\""    << (m_variationType == VariationFromLSB ?
                                            "LSB" :
                                            m_variationType == VariationFromMSB ?
                                            "MSB" : "")
-               << "\" connection=\""   << encode(m_connection)
+               << "\" connection=\""   << encode(m_userConnection)
                << "\" type=\"midi\">"  << std::endl << std::endl;
 
     midiDevice << "        <librarian name=\"" << encode(m_librarian.first)
@@ -981,9 +981,30 @@ findControlParameter(std::string type, MidiByte controllerNumber) const
 bool 
 MidiDevice::isVisibleControlParameter(const ControlParameter &con) const
 {
+    // ??? Inline this and get rid of it.  It is a one-liner that is only
+    //     used internally.
+
     return (con.getIPBPosition() > -1);
 }
 
+bool
+MidiDevice::isVisibleControlParameter(MidiByte controlNumber) const
+{
+    // For each CC...
+    for (const ControlParameter &controlParameter : m_controlList)
+    {
+        // Not a CC?  Skip.
+        if (controlParameter.getType() != Controller::EventType)
+            continue;
+
+        // If we found it...
+        if (controlParameter.getControllerNumber() == controlNumber)
+            return (controlParameter.getIPBPosition() > -1 );
+    }
+
+    return false;
+}
+
 void
 MidiDevice::addControlToInstrument(const ControlParameter &con)
 {
@@ -1022,8 +1043,6 @@ MidiDevice::getIPBControlParameters() const
 {
     ControlList retList;
 
-    Rosegarden::MidiByte MIDI_CONTROLLER_VOLUME = 0x07;
-
     for (ControlList::const_iterator it = m_controlList.begin();
          it != m_controlList.end(); ++it)
     {
