@@ -51,6 +51,7 @@ public:
     // Copy ctor.
     // ??? Switch pointers to objects and rely on bitwise copy to take
     //     care of this.  If that's workable, then this can go.
+    // ??? Only used by ImportDeviceDialog.
     MidiDevice(const MidiDevice &);
 
     //MidiDevice();
@@ -182,9 +183,16 @@ public:
     const ControlParameter *
         findControlParameter(std::string type, MidiByte conNumber) const;
     
-    // Check if controller is visible.
-    //
+    /// The CC or other controller has a knob on the MIPP.
+    /**
+     * ??? Only CCs can have knobs.  It's misleading to allow a complete
+     *     ControlParameter here.  Perhaps remove this routine.  Certainly
+     *     move it to private as it is only called internally (like most
+     *     of the routines in this class).
+     */
     bool isVisibleControlParameter(const ControlParameter &con) const;
+    /// The CC has a knob on the MIPP.
+    bool isVisibleControlParameter(MidiByte controlNumber) const;
 
     // Generate some default controllers for the MidiDevice
     //
@@ -195,6 +203,15 @@ public:
     static bool isPercussionNumber(int channel)
     { return channel == 9; }
 
+    /// See m_userConnection.
+    void setUserConnection(std::string connection)
+            { m_userConnection = connection; }
+    std::string getUserConnection() const
+            { return m_userConnection; }
+    /// See m_currentConnection.
+    void setCurrentConnection(std::string connection)
+            { m_currentConnection = connection; }
+
 protected:
     void createInstruments(InstrumentId);
     void renameInstruments() override;
@@ -214,6 +231,21 @@ protected:
     //
     void removeControlFromInstrument(const ControlParameter &con);
 
+    /// The connection the user has asked for.
+    /**
+     * This can only be changed by the user.  It is used when attempting
+     * to make a connection.  It is stored in the .rg file.
+     */
+    std::string m_userConnection;
+
+    /// The connection that was actually made.
+    /**
+     * Since the necessary ALSA device might not exist (e.g. it isn't
+     * plugged in), this might be very different from m_userConnection.
+     * This is not stored in the .rg file.
+     */
+    std::string m_currentConnection;
+
     ProgramList    m_programList;
     BankList       m_bankList;
     ControlList    m_controlList;
