@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -1010,6 +1010,16 @@ public:
      */
     Event *getAsNoteEvent(timeT absoluteTime, timeT duration) const;
 
+    /**
+     * Get the major key that has this Pitch as the tonic
+     */
+    Key getAsKey() const;
+
+    /**
+     * Get the major or minor key that has this Pitch as the tonic
+     */
+    Key getAsKey(bool isMinor) const;
+
 private:
     int m_pitch;
     Accidental m_accidental;
