@@ -1,7 +1,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -17,11 +17,13 @@
 #include "Property.h"
 #include "base/PropertyName.h"
 
+#include <rosegardenprivate_export.h>
+
 #include <map>
 
 namespace Rosegarden {
 
-class PropertyMap : public std::map<PropertyName, PropertyStoreBase *>
+class ROSEGARDENPRIVATE_EXPORT PropertyMap : public std::map<PropertyName, PropertyStoreBase *>
 {
 public:
     PropertyMap() { }
