@@ -24,7 +24,7 @@
 #include "base/SegmentLinker.h"
 #include "document/DocumentGet.h"
 #include "gui/general/GUIPalette.h"
-//#include "misc/Debug.h"
+#include "misc/Debug.h"
 
 #include <QtGlobal>
 
@@ -40,8 +40,6 @@
 
 namespace Rosegarden
 {
-using std::cerr;
-using std::endl;
 using std::string;
 
 //#define DEBUG_NORMALIZE_RESTS 1
@@ -86,7 +84,8 @@ Segment::Segment(SegmentType segmentType, timeT startTime) :
     m_isTmp(0),
     m_participation(normal),
     m_verseCount(-1),   // -1 => computation needed
-    m_verse(0)
+    m_verse(0),
+    m_forNotation(true)
 {
 }
 
@@ -156,15 +155,12 @@ Segment::cloneImpl() const
 Segment::~Segment()
 {
     if (!m_observers.empty()) {
-        cerr << "Warning: Segment::~Segment() with " << m_observers.size()
-             << " observers still extant" << endl;
-        cerr << "Observers are:";
+        RG_WARNING << "dtor: Warning: " << m_observers.size() << " observers still extant";
+        RG_WARNING << "Observers are:";
         for (ObserverSet::const_iterator i = m_observers.begin();
              i != m_observers.end(); ++i) {
-            cerr << " " << (void *)(*i);
-            cerr << " [" << typeid(**i).name() << "]";
+            RG_WARNING << " " << (void *)(*i) << " [" << typeid(**i).name() << "]";
         }
-        cerr << endl;
     }
 
     //unlink it
@@ -211,6 +207,16 @@ Segment::getRealSegment() const {
     return this;
 }
 
+void
+Segment::setForNotation(bool f) {
+    m_forNotation = f;
+}
+
+bool
+Segment::getForNotation() const {
+    return m_forNotation;
+}
+
 void
 Segment::setTmp() {
     m_isTmp = true;
@@ -1255,10 +1261,9 @@ Segment::getClefAtTime(timeT time, timeT &ctime) const
         ctime = (*i)->getAbsoluteTime();
         return Clef(**i);
     } catch (const Exception &e) {
-        std::cerr << "Segment::getClefAtTime(" << time
-                  << "): bogus clef in ClefKeyList: event dump follows:"
-                  << std::endl;
-        (*i)->dump(std::cerr);
+        RG_WARNING << "getClefAtTime(" << time << "): bogus clef in ClefKeyList: event dump follows:";
+        RG_WARNING << (*i);
+
         return Clef();
     }
 }
@@ -1313,13 +1318,12 @@ Segment::getKeyAtTime(timeT time, timeT &ktime) const
     try {
         ktime = (*i)->getAbsoluteTime();
         Key k(**i);
-//        std::cerr << "Segment::getKeyAtTime: Requested time " << time << ", found key " << k.getName() << " at time " << ktime << std::endl;
+        //RG_DEBUG << "getKeyAtTime(): Requested time " << time << ", found key " << k.getName() << " at time " << ktime;
         return k;
     } catch (const Exception &e) {
-        std::cerr << "Segment::getClefAtTime(" << time
-                  << "): bogus key in ClefKeyList: event dump follows:"
-                  << std::endl;
-        (*i)->dump(std::cerr);
+        RG_WARNING << "getKeyAtTime(" << time << "): bogus key in ClefKeyList: event dump follows:";
+        RG_WARNING << (*i);
+
         return Key();
     }
 }
@@ -1607,8 +1611,8 @@ Segment::getPreviewColour() const
         return Qt::black;
     }
 
-    QColor segmentColour = GUIPalette::convertColour(
-            m_composition->getSegmentColourMap().getColourByIndex(m_colourIndex));
+    QColor segmentColour =
+            m_composition->getSegmentColourMap().getColour(m_colourIndex);
 
     int intensity = qGray(segmentColour.rgb());
 
@@ -1736,23 +1740,54 @@ SegmentRefreshStatus::push(timeT from, timeT to)
 void
 Segment::dumpObservers()
 {
-    std::cerr << "Observers of segment " << this << " are:\n";
+    RG_DEBUG << "Observers of segment " << this << " are:";
      for (ObserverSet::const_iterator i = m_observers.begin();
           i != m_observers.end(); ++i) {
-        std::cerr << " " << (*i);
+        RG_DEBUG << "  " << (*i);
     }
-    std::cerr << "\n";
     for (ObserverSet::const_iterator i = m_observers.begin();
           i != m_observers.end(); ++i) {
-              Segment * seg = dynamic_cast<Segment *>(*i);
-              StaffHeader * sh = dynamic_cast<StaffHeader *>(*i);
-        std::cerr << "        " << (*i);
-        if (seg) std::cerr << " ==> Segment " << seg;
-        if (sh) std::cerr << " ==> StaffHeader " << sh;
-        std::cerr << "\n";
+        Segment *seg = dynamic_cast<Segment *>(*i);
+        if (seg)
+            RG_DEBUG << "  " << (*i) << " ==> Segment " << seg;
+
+        StaffHeader *sh = dynamic_cast<StaffHeader *>(*i);
+        if (sh)
+            RG_DEBUG << "  " << (*i) << " ==> StaffHeader " << sh;
     }
 }
 
+ROSEGARDENPRIVATE_EXPORT QDebug &operator<<(QDebug &dbg, const Rosegarden::Segment &t)
+{
+//    dbg << "Segment for instrument " << t.getTrack()
+//        << " starting at " << t.getStartTime() << '\n';
+
+    dbg << "Segment Object\n";
+    dbg << "  Label: " << t.getLabel() << '\n';
+    dbg << "  Track: " << t.getTrack() << '\n';
+    // Assume 4/4 time and provide a potentially helpful bar number.
+    dbg << "  Start Time: " << t.getStartTime() <<
+        "(4/4 bar" << t.getStartTime() / (960.0*4.0) + 1 << ")\n";
+    dbg << "  End Time: " << t.getEndTime() <<
+        "(4/4 bar" << t.getEndTime() / (960.0*4.0) + 1 << ")\n";
+    dbg << "  End Marker Time: " << t.getEndMarkerTime() <<
+        "(4/4 bar" << t.getEndMarkerTime() / (960.0*4.0) + 1 << ")\n";
+
+    dbg << "Events:\n";
+
+    for (Rosegarden::Segment::const_iterator i = t.begin();
+            i != t.end(); ++i) {
+        if (!(*i)) {
+            dbg << "WARNING : skipping null event ptr\n";
+            continue;
+        }
+
+        dbg << *(*i) << endl;
+    }
+
+    return dbg;
+}
+
 void
 SegmentObserver::
 allEventsChanged(const Segment *s)
