@@ -46,7 +46,7 @@ SoftSynthDevice::SoftSynthDevice(DeviceId id, const std::string &name) :
     checkControlList();
 }
 
-
+#if 0
 SoftSynthDevice::SoftSynthDevice(const SoftSynthDevice &dev) :
     Device(dev.getId(), dev.getName(), dev.getType()),
     Controllable(),
@@ -60,6 +60,7 @@ SoftSynthDevice::SoftSynthDevice(const SoftSynthDevice &dev) :
         m_instruments.push_back(new Instrument(**iIt));
     if (dev.m_metronome) m_metronome = new MidiMetronome(*dev.m_metronome);
 }
+#endif
 
 SoftSynthDevice::~SoftSynthDevice()
 {
@@ -98,7 +99,7 @@ SoftSynthDevice::checkControlList()
         { "Volume", Rosegarden::Controller::EventType, "<none>", "0", "127", "100", "7", "1", "2" },
         { "Reverb", Rosegarden::Controller::EventType, "<none>", "0", "127", "0", "91", "3", "3" },
         { "Sustain", Rosegarden::Controller::EventType, "<none>", "0", "127", "0", "64", "4", "-1" },
-        { "Expression", Rosegarden::Controller::EventType, "<none>", "0", "127", "100", "11", "2", "-1" },
+        { "Expression", Rosegarden::Controller::EventType, "<none>", "0", "127", "127", "11", "2", "-1" },
         { "Modulation", Rosegarden::Controller::EventType, "<none>", "0", "127", "0", "1", "4", "-1" },
         { "PitchBend", Rosegarden::PitchBend::EventType, "<none>", "0", "16383", "8192", "1", "4", "-1" }
     };
@@ -146,7 +147,7 @@ SoftSynthDevice::getControlParameter(const std::string &type,
             
             // Also match controller value for Controller events
             //
-            if (it->getControllerValue() == controllerValue)
+            if (it->getControllerNumber() == controllerValue)
                 return  &*it;
         }
     }
