@@ -130,15 +130,33 @@ Studio::removeDevice(DeviceId id)
 }
 
 void
-Studio::
-resyncDeviceConnections()
+Studio::resyncDeviceConnections()
 {
-    // Sync all the device connections
+    // Sync all the MidiDevice connections to the current connections
+    // according to RosegardenSequencer.
+
     DeviceList *devices = getDevices();
-    for (uint i = 0; i < devices->size(); ++i) {
-        DeviceId id = (*devices)[i]->getId();
-        QString connection = RosegardenSequencer::getInstance()->getConnection(id);
-        (*devices)[i]->setConnection(qstrtostr(connection));
+
+    // For each Device
+    for (unsigned i = 0; i < devices->size(); ++i) {
+        // Only MidiDevice's have connections.
+        MidiDevice *midiDevice = dynamic_cast<MidiDevice *>((*devices)[i]);
+        if (!midiDevice)
+            continue;
+
+        DeviceId deviceId = midiDevice->getId();
+        QString connection =
+                RosegardenSequencer::getInstance()->getConnection(deviceId);
+
+        midiDevice->setCurrentConnection(qstrtostr(connection));
+
+        // If we are connected to something, but the user didn't ask for
+        // anything, we must have been connected up by
+        // AlsaDriver::connectSomething().  In that case, we'd better store
+        // the connection as the user selection in case the user actually
+        // likes it.
+        if (connection != ""  &&  midiDevice->getUserConnection() == "")
+            midiDevice->setUserConnection(qstrtostr(connection));
     }
 }
 
@@ -688,8 +706,6 @@ Studio::unassignAllInstruments()
                     //     default values.
                     //(*iit)->sendChannelSetup();
 
-                    (*iit)->setSendPan(false);
-                    (*iit)->setSendVolume(false);
                     (*iit)->setPan(MidiMidValue);
                     (*iit)->setVolume(100);
 
