@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -13,8 +13,8 @@
     COPYING included with this distribution for more information.
 */
 
-#include <string>
-#include <vector>
+#ifndef RG_STUDIO_H
+#define RG_STUDIO_H
 
 #include "XmlExportable.h"
 #include "Instrument.h"
@@ -22,22 +22,21 @@
 #include "MidiProgram.h"
 #include "MidiMetronome.h"
 #include "ControlParameter.h"
+
 #include <QCoreApplication>
 
-// The Studio is where Midi and Audio devices live.  We can query
-// them for a list of Instruments, connect them together or to
-// effects units (eventually) and generally do real studio-type
-// stuff to them.
-//
-//
-
-
-#ifndef RG_STUDIO_H
-#define RG_STUDIO_H
+#include <string>
+#include <vector>
 
 namespace Rosegarden
 {
 
+
+class RecordIn;
+class MidiDevice;
+class Segment;
+class Track;
+
 typedef std::vector<Instrument *> InstrumentList;
 typedef std::vector<Device*> DeviceList;
 typedef std::vector<Buss *> BussList;
@@ -45,19 +44,24 @@ typedef std::vector<RecordIn *> RecordInList;
 typedef std::vector<Device*>::iterator DeviceListIterator;
 typedef std::vector<Device*>::const_iterator DeviceListConstIterator;
 
-class MidiDevice;
-
-class Segment;
-class Track;
-
 
+/// Holds Device objects.
+/**
+ * The Studio is where Midi and Audio devices live.  We can query
+ * them for a list of Instruments, connect them together or to
+ * effects units (eventually) and generally do real studio-type
+ * stuff to them.
+ *
+ * RosegardenDocument has an instance of Studio.  A reference can be obtained
+ * using RosegardenDocument::getStudio().
+ */
 class Studio : public XmlExportable
 {
     Q_DECLARE_TR_FUNCTIONS(Rosegarden::Studio)
 
 public:
     Studio();
-    ~Studio();
+    ~Studio() override;
 
 private:
     Studio(const Studio &);
@@ -71,7 +75,7 @@ public:
 
     void removeDevice(DeviceId id);
 
-    void resyncDeviceConnections(void);
+    void resyncDeviceConnections();
 
     DeviceId getSpareDeviceId(InstrumentId &baseInstrumentId);
 
@@ -171,7 +175,7 @@ public:
 
     // Export as XML string
     //
-    virtual std::string toXmlString() const;
+    std::string toXmlString() const override;
 
     // Export a subset of devices as XML string.  If devices is empty,
     // exports all devices just as the above method does.
