@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2018 the Rosegarden development team.
+    Copyright 2000-2020 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -23,17 +23,6 @@ namespace Rosegarden
     // Time in internal units (pulses).  Timebase is 960ppq.
     typedef long timeT;
     constexpr timeT timebase = 960;
-
-    // Time used in the rewriter to represent tupled notes exactly.
-    // It doesn't have a fixed conversion to timeT, instead each bar
-    // figures out a scaling that allows all tupleting in it to be
-    // represented exactly.
-    typedef timeT stretchedTimeT;
-
-    // Time in 256th notes; equivalently, 4 times the time in smallest
-    // notes.  We need the unit to be 1/4 of the smallest note so we
-    // can represent dotted and double-dotted notes exactly.
-    typedef int Num256ths;
 }
 
-#endif /* ifndef RG_TIMET_H */
+#endif
