@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -27,7 +27,7 @@ QString
 AlternatingParameterPattern::getText(QString propertyName) const
 {
     return
-        EventParameterDialog::tr("Alternating - set %1 to max and min on alternate events").arg(propertyName);
+        QObject::tr("Alternating - set %1 to max and min on alternate events").arg(propertyName);
 }
 
 ParameterPattern::SliderSpecVector
@@ -38,9 +38,9 @@ AlternatingParameterPattern::getSliderSpec(const SelectionSituation *situation)
         situation->getMinMax();
 
     // First is high value, second is low.
-    result.push_back(SliderSpec(EventParameterDialog::tr("First Value"),  
+    result.push_back(SliderSpec(QObject::tr("First Value"),
                                 minMax.second, situation));
-    result.push_back(SliderSpec(EventParameterDialog::tr("Second Value"), 
+    result.push_back(SliderSpec(QObject::tr("Second Value"),
                                 minMax.first, situation));
     return result;
 }
