@@ -145,21 +145,23 @@ ParameterPattern::getTimes (iterator begin, iterator end)
 // @param situation This call will take ownership of situation.
 void
 ParameterPattern::setProperties(QMainWindow *parent,
-                                SelectionSituation   *situation,
+                                QString windowName,
+                                SelectionSituation *situation,
                                 const ParameterPatternVec *patterns)
 {
-    EventParameterDialog
-        dialog(parent,
-               QObject::tr("Set Event Velocities"),
-               situation,
-               patterns);
+    EventParameterDialog dialog(parent,
+                                windowName,
+                                situation,
+                                patterns);
 
     if (dialog.exec() == QDialog::Accepted) {
         TmpStatusMsg msg(QObject::tr("Setting Velocities..."),
                          parent);
-        CommandHistory::getInstance()->addCommand
-            (new SelectionPropertyCommand(dialog.getResult()));
-    } else { delete situation; }
+        CommandHistory::getInstance()->addCommand(
+                new SelectionPropertyCommand(dialog.getResult()));
+    } else {
+        delete situation;
+    }
 }
 
 ParameterPattern::~ParameterPattern()
@@ -180,6 +182,7 @@ setProperties(QMainWindow *parent,
     // situation will ultimately be owned by SelectionPropertyCommand via
     // dialog result
     setProperties(parent,
+                  QObject::tr("Set Event Velocities"),
                   new SelectionSituation(eventType, selection, normValue),
                   patterns);
 }
