@@ -16,24 +16,30 @@
 */
 
 #include "QuarterSinePattern.h"
+
 #include "gui/dialogs/EventParameterDialog.h"
+#include "misc/Constants.h"
+
 #include <cmath>
 
 namespace Rosegarden
 {
 
 
-QuarterSinePattern
-QuarterSinePattern::
-crescendo(EventParameterDialog::
-          tr("Quarter-wave crescendo - set %1 rising from min to max in a quarter sine wave contour"),
-          false);
+QuarterSinePattern QuarterSinePattern::crescendo(false);
+QuarterSinePattern QuarterSinePattern::diminuendo(true);
 
-QuarterSinePattern
-QuarterSinePattern::
-diminuendo(EventParameterDialog::
-           tr("Quarter-wave diminuendo - set %1 falling from max to min in a quarter sine wave contour"),
-           true);
+QString
+QuarterSinePattern::getText(QString propertyName) const
+{
+    QString text;
+    if (m_isDiminuendo) {
+        text = QObject::tr("Quarter-wave diminuendo - set %1 falling from max to min in a quarter sine wave contour");
+    } else {
+        text = QObject::tr("Quarter-wave crescendo - set %1 rising from min to max in a quarter sine wave contour");
+    }
+    return text.arg(propertyName);
+}
 
 double
 QuarterSinePattern::
@@ -43,10 +49,8 @@ getValueDelta(double valueChange, double timeRatio) const
        For a quarter-sine, range is 0 to pi/2, giving 0 to 1
 
        value delta = sin(pi * ratio/2) * valueChange
-
-       Use acos(0.0) = pi/2
     **/
-    const double sinArg = acos(0.0) * timeRatio;
+    const double sinArg = pi/2 * timeRatio;
     return sin(sinArg) * valueChange;
 }
 
