@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -28,18 +28,18 @@ namespace Rosegarden
 // @author Tom Breton (Tehom)
 class RelativeRamp : public ParameterPattern
 {
-    virtual QString getText(QString propertyName) const;
+    QString getText(QString propertyName) const override;
 
-    virtual SliderSpecVector
-        getSliderSpec(const SelectionSituation *situation) const;
+    SliderSpecVector
+        getSliderSpec(const SelectionSituation *situation) const override;
 
     // Set the properties of events from begin to end.
-    virtual void
+    void
         setEventProperties(iterator begin, iterator end,
-                           Result *result) const;
+                           Result *result) const override;
 
 public:
-    RelativeRamp(void) 
+    RelativeRamp() 
     {};
     static RelativeRamp single;
 };
