@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -27,7 +27,7 @@ QString
 RingingParameterPattern::getText(QString propertyName) const
 {
     return
-        EventParameterDialog::tr("Ringing - set %1 alternating from max to min with both dying to zero").arg(propertyName);
+        QObject::tr("Ringing - set %1 alternating from max to min with both dying to zero").arg(propertyName);
 }
 
 ParameterPattern::SliderSpecVector
@@ -36,9 +36,9 @@ RingingParameterPattern::getSliderSpec(const SelectionSituation *situation) cons
     SliderSpecVector result;
     std::pair<int,int> minMax = situation->getMinMax();
 
-    result.push_back(SliderSpec(EventParameterDialog::tr("First Value"),  
+    result.push_back(SliderSpec(QObject::tr("First Value"),
                                 minMax.second, situation));
-    result.push_back(SliderSpec(EventParameterDialog::tr("Second Value"), 
+    result.push_back(SliderSpec(QObject::tr("Second Value"),
                                 minMax.first, situation));
     return result;
 }
