@@ -25,12 +25,14 @@
 #include "base/BaseProperties.h"
 #include "document/BasicSelectionCommand.h"
 #include "gui/editors/notation/NotationProperties.h"
+
 #include <QString>
 
 
 namespace Rosegarden
 {
 
+
 EraseCommand::EraseCommand(EventSelection &selection) :
         BasicSelectionCommand(getGlobalName(), selection, true),
         m_selection(&selection),
@@ -39,6 +41,12 @@ EraseCommand::EraseCommand(EventSelection &selection) :
     // nothing else
 }
 
+EraseCommand::~EraseCommand()
+{
+    // ??? MEMORY LEAK (confirmed)  delete here isn't a reliable solution.
+    //delete m_selection;
+}
+
 void
 EraseCommand::modifySegment()
 {
