@@ -26,11 +26,10 @@
 namespace Rosegarden
 {
 
-EventInsertionCommand::EventInsertionCommand(Segment &segment,
-        Event *event) :
-        BasicCommand(tr("Insert Event"), segment, event->getAbsoluteTime(),
-                     event->getAbsoluteTime() + event->getDuration()),
-        m_event(new Event(*event))
+EventInsertionCommand::EventInsertionCommand(Segment &segment, Event *event) :
+    BasicCommand(tr("Insert Event"), segment, event->getAbsoluteTime(),
+                 event->getAbsoluteTime() + event->getDuration()),
+    m_event(event)
 {
     // nothing
 }
