@@ -38,8 +38,11 @@ class EventInsertionCommand : public BasicCommand
     Q_DECLARE_TR_FUNCTIONS(Rosegarden::EventInsertionCommand)
 
 public:
-    EventInsertionCommand(Segment &segment,
-                          Event *event);
+    /**
+     * NOTE: This class takes ownership of event and will delete
+     *       it upon destruction.
+     */
+    EventInsertionCommand(Segment &segment, Event *event);
 
     ~EventInsertionCommand() override;
 
