@@ -40,7 +40,7 @@ public:
 	static QString getGlobalName(bool sounding);
 
 protected:
-    virtual void modifySegment();
+    void modifySegment() override;
 
 private:
     EventSelection *m_selection;// only used on 1st execute (cf bruteForceRedo)
