@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -33,7 +33,7 @@ PlaceControllersCommand::PlaceControllersCommand
   BasicSelectionCommand(globalName, selection, true),
     m_selection(&selection),
     m_eventType(cp->getType()),
-    m_controllerId(cp->getControllerValue()),
+    m_controllerId(cp->getControllerNumber()),
     m_controllerValue(getDefaultValue(instrument, cp))
 { }
                                     
@@ -49,7 +49,7 @@ PlaceControllersCommand::getDefaultValue(const Instrument *instrument,
         {
             try {
                 return
-                    instrument->getControllerValue(cp->getControllerValue()); }
+                    instrument->getControllerValue(cp->getControllerNumber()); }
             catch (...) { return cp->getDefault(); }
         }
     else
@@ -59,7 +59,7 @@ PlaceControllersCommand::getDefaultValue(const Instrument *instrument,
 
 void
 PlaceControllersCommand::
-modifySegment(void)
+modifySegment()
 {
     typedef EventSelection::eventcontainer container;
     typedef container::iterator iterator;
