@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -42,7 +42,7 @@ public:
     BeatInterpolator(timeT duration,
                      timeT prevBeatDuration,
                      int numSkippedBeats);
-    BeatInterpolator(void) :
+    BeatInterpolator() :
         m_baseBeatDuration(480), // No good default for this.
         m_logScalingPerBeat(1.0)
         {}
@@ -85,13 +85,13 @@ BeatEvent(Event *event, int numSkippedBeats,
                                           Event *firstBeat,
                                           Event *secondBeat);
     static BeatEventVector findBeatEvents(EventSelection *eventSelection);
-    virtual EventSelection *getSubsequentSelection();
+    EventSelection *getSubsequentSelection() override;
 
  private:
     static QString getGlobalName() { return tr("Select Beats"); }
     static timeT getStartTime(BeatEventVector &beatEventVector);
     static timeT getEndTime(BeatEventVector &beatEventVector);
-    virtual void modifySegment();
+    void modifySegment() override;
         
     BeatEventVector m_beatEventVector;
     EventVector     m_eventsAdded;
