@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -41,27 +41,33 @@ public:
                                      timeT time,
                                      Event *event);
 
-    virtual ~MatrixPercussionInsertionCommand();
+    ~MatrixPercussionInsertionCommand() override;
 
     Event *getLastInsertedEvent() { return m_lastInsertedEvent; }
     
 protected:
-    virtual void modifySegment();
+    void modifySegment() override;
 
     timeT getEffectiveStartTime(Segment &segment,
                                             timeT startTime,
                                             Event &event);
-    timeT getEndTime(Segment &segment,
-                                 timeT endTime,
-                                 Event &event);
+
+    /// Compute the end time for a percussion event.
+    /**
+     * We try to make percussion notes contiguous so that they will look
+     * correct in notation.  Unfortunately, this wreaks some havoc on
+     * the velocity ruler.  Perhaps the velocity ruler needs a percussion mode
+     * where it would show each note as if it were a 64th?
+     */
+    timeT getEndTime(const Segment &segment,
+                     timeT endTime,
+                     const Event &event);
 
     Event *m_event;
     timeT m_time;
     Event *m_lastInsertedEvent; // an alias for another event
 };
 
-//------------------------------
-
 
 }
 
