@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -100,7 +100,7 @@ AddIndicationCommand::AddIndicationCommand(std::string indicationType,
     m_indicationType(indicationType),
     m_indicationStart(selection.getNotationStartTime()),
     m_indicationDuration(selection.getTotalNotationDuration()),
-    m_lastInsertedEvent(0)
+    m_lastInsertedEvent(nullptr)
 {
     if (!canExecute()) {
         throw CommandFailed
