@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -46,7 +46,7 @@ AddSlashesCommand::getArgument(QString actionName, CommandArgumentQuerier &)
 {
     QString pfx("slashes_");
     if (actionName.startsWith(pfx)) {
-        return actionName.right(actionName.length() - pfx.length()).toInt();
+        return actionName.rightRef(actionName.length() - pfx.length()).toInt();
     }
     return 0;
 }
