@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -39,12 +39,12 @@ public:
     EraseEventCommand(Segment &segment,
                       Event *event,
                       bool collapseRest);
-    virtual ~EraseEventCommand();
+    ~EraseEventCommand() override;
 
-    virtual timeT getRelayoutEndTime();
+    timeT getRelayoutEndTime() override;
 
 protected:
-    virtual void modifySegment();
+    void modifySegment() override;
 
     bool m_collapseRest;
 
