@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -41,12 +41,12 @@ public:
     GuitarChordInsertionCommand(Segment &segment,
                               timeT time,
                               const Guitar::Chord& chord);
-    virtual ~GuitarChordInsertionCommand();
+    ~GuitarChordInsertionCommand() override;
 
     Event *getLastInsertedEvent() { return m_lastInsertedEvent; }
 
 protected:
-    virtual void modifySegment();
+    void modifySegment() override;
 
     Guitar::Chord m_chord;
     Event *m_lastInsertedEvent;
