@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -58,9 +58,9 @@ public:
                         bool shouldTranspose,
                         bool shouldTransposeKey,
 			bool shouldIgnorePercussion);
-    virtual ~KeyInsertionCommand();
+    ~KeyInsertionCommand() override;
 
-    static QString getGlobalName(Key *key = 0) {
+    static QString getGlobalName(Key *key = nullptr) {
         if (key) {
             return tr("Change to &Key %1...").arg(strtoqstr(key->getName()));
         } else {
@@ -68,11 +68,11 @@ public:
         }
     }
 
-    virtual EventSelection *getSubsequentSelection();
+    EventSelection *getSubsequentSelection() override;
     Event *getLastInsertedEvent() { return m_lastInsertedEvent; }
 
 protected:
-    virtual void modifySegment();
+    void modifySegment() override;
 
     Key m_key;
     Event *m_lastInsertedEvent;
