@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -51,9 +51,9 @@ public:
                              bool shouldTranspose,
                              bool shouldTransposeKey,
 			     bool shouldIgnorePercussion); 
-    virtual ~MultiKeyInsertionCommand();
+    ~MultiKeyInsertionCommand() override;
 
-    static QString getGlobalName(Key *key = 0) {
+    static QString getGlobalName(Key *key = nullptr) {
         if (key) {
             return tr("Change all to &Key %1...").arg(strtoqstr(key->getName()));
         } else {
