@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -40,15 +40,15 @@ public:
     SymbolInsertionCommand(Segment &segment,
                          timeT time,
                          Symbol symbol);
-    virtual ~SymbolInsertionCommand();
+    ~SymbolInsertionCommand() override;
 
-    static QString getGlobalName(Symbol *symbol = 0);
+    static QString getGlobalName(Symbol *symbol = nullptr);
 
-    virtual EventSelection *getSubsequentSelection();
+    EventSelection *getSubsequentSelection() override;
     Event *getLastInsertedEvent() { return m_lastInsertedEvent; }
 
 protected:
-    virtual void modifySegment();
+    void modifySegment() override;
 
     Symbol m_symbol;
 
