@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -36,7 +36,7 @@ public:
     AddTimeSignatureAndNormalizeCommand(Composition *composition,
                                         timeT time,
                                         TimeSignature timeSig);
-    virtual ~AddTimeSignatureAndNormalizeCommand();
+    ~AddTimeSignatureAndNormalizeCommand() override;
 };
 
 
