@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -33,7 +33,7 @@ AddTimeSignatureCommand::AddTimeSignatureCommand(Composition *composition,
         m_composition(composition),
         m_time(time),
         m_timeSignature(timeSig),
-        m_oldTimeSignature(0)
+        m_oldTimeSignature(nullptr)
 {
     // nothing else
 }
