@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -43,12 +43,12 @@ public:
                              timeT duration, // start time always 0
                              int basePitch = -1,
                              int baseVelocity = -1);
-    virtual ~AddTriggerSegmentCommand();
+    ~AddTriggerSegmentCommand() override;
 
     TriggerSegmentId getId() const; // after invocation
 
-    virtual void execute();
-    virtual void unexecute();
+    void execute() override;
+    void unexecute() override;
 
 private:
     Composition *m_composition;
