@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -41,10 +41,10 @@ class AudioSegmentResizeFromStartCommand : public NamedCommand
 public:
     AudioSegmentResizeFromStartCommand(Segment *segment,
                                        timeT newStartTime);
-    virtual ~AudioSegmentResizeFromStartCommand();
+    ~AudioSegmentResizeFromStartCommand() override;
 
-    virtual void execute();
-    virtual void unexecute();
+    void execute() override;
+    void unexecute() override;
 
 private:
     Segment *m_segment;
