@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -35,9 +35,9 @@ AudioSegmentSplitCommand::AudioSegmentSplitCommand(Segment *segment,
         timeT splitTime) :
         NamedCommand(tr("Split Audio Segment")),
         m_segment(segment),
-        m_newSegment(0),
+        m_newSegment(nullptr),
         m_splitTime(splitTime),
-        m_previousEndMarkerTime(0),
+        m_previousEndMarkerTime(nullptr),
         m_detached(false)
 {}
 
@@ -124,7 +124,7 @@ AudioSegmentSplitCommand::execute()
     if (emt) {
         m_previousEndMarkerTime = new timeT(*emt);
     } else {
-        m_previousEndMarkerTime = 0;
+        m_previousEndMarkerTime = nullptr;
     }
 
     RG_DEBUG << "AudioSegmentSplitCommand::execute: Setting end marker of left segment to " << m_splitTime;
@@ -147,7 +147,7 @@ AudioSegmentSplitCommand::unexecute()
 
         m_segment->setEndMarkerTime(*m_previousEndMarkerTime);
         delete m_previousEndMarkerTime;
-        m_previousEndMarkerTime = 0;
+        m_previousEndMarkerTime = nullptr;
     } else {
         m_segment->clearEndMarker();
     }
