@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -48,18 +48,18 @@ public:
         {
             Q_ASSERT(firstSplitTime < secondSplitTime);
         }
-    virtual ~SegmentGroupDeleteRangeCommand();
+    ~SegmentGroupDeleteRangeCommand() override;
 
 protected:
-    virtual void execute();
-    virtual void unexecute();
+    void execute() override;
+    void unexecute() override;
     Segment *splitTwiceRejoin(Segment *segment);
     Segment *splitAtFirst(Segment *segment);
     Segment *splitAtSecond(Segment *segment);
-    void     calculateNewSegments(void);
+    void     calculateNewSegments();
 
 private:
-    timeT getRangeDuration(void)
+    timeT getRangeDuration()
     { return m_secondSplitTime - m_firstSplitTime; }
 
     timeT m_firstSplitTime;
@@ -227,7 +227,7 @@ splitTwiceRejoin(Segment *segment)
 }
 void
 SegmentGroupDeleteRangeCommand::
-calculateNewSegments(void)
+calculateNewSegments()
 {
     Q_ASSERT(!m_originalSegments.empty());
 
@@ -370,7 +370,7 @@ DeleteRangeCommand::DeleteRangeCommand(Composition *composition,
             }
 
             if (count > 0) {
-                if ((*i)->getLinker() == 0) {
+                if ((*i)->getLinker() == nullptr) {
                     // If not linked, immediately add a command to
                     // handle it.  It can't be stored in linkedGroups
                     // because all unlinked Segments would wrongly
