@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -55,7 +55,7 @@ PasteToTriggerSegmentCommand(Composition *composition,
 }
 
 PasteToTriggerSegmentCommand::
-~PasteToTriggerSegmentCommand(void)
+~PasteToTriggerSegmentCommand()
 {}
     
 void
@@ -79,7 +79,7 @@ PasteToTriggerSegmentWorker::PasteToTriggerSegmentWorker(Composition *compositio
         m_label(label),
         m_basePitch(basePitch),
         m_baseVelocity(baseVelocity),
-        m_segment(0),
+        m_segment(nullptr),
         m_detached(false)
 {
     // nothing else
@@ -96,7 +96,7 @@ PasteToTriggerSegmentWorker(Composition *composition,
         m_label(label),
         m_basePitch(basePitch),
         m_baseVelocity(baseVelocity),
-        m_segment(0),
+        m_segment(nullptr),
         m_detached(false)
 {
     m_clipboard->newSegment(selection);
