@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -37,12 +37,12 @@ class SegmentChangeQuantizationCommand : public NamedCommand
 public:
     /// Set quantization on segments.  If unit is zero, switch quantization off
     SegmentChangeQuantizationCommand(timeT);
-    virtual ~SegmentChangeQuantizationCommand();
+    ~SegmentChangeQuantizationCommand() override;
 
     void addSegment(Segment *s);
 
-    virtual void execute();
-    virtual void unexecute();
+    void execute() override;
+    void unexecute() override;
 
     static QString getGlobalName(timeT unit) {
         if (!unit) {
