@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -46,12 +46,12 @@ class SegmentResizeFromStartCommand : public BasicCommand
 public:
     SegmentResizeFromStartCommand(Segment *segment,
                                   timeT newStartTime);
-    virtual ~SegmentResizeFromStartCommand();
+    ~SegmentResizeFromStartCommand() override;
 
     static QString getGlobalName() { return tr("Resize Segment"); }
 
 protected:
-    virtual void modifySegment();
+    void modifySegment() override;
 
 private:
     Segment *m_segment;
