@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -32,7 +32,7 @@ SegmentSingleRepeatToCopyCommand::SegmentSingleRepeatToCopyCommand(
         NamedCommand(tr("Turn Single Repeat into Copy")),
         m_composition(segment->getComposition()),
         m_segment(segment),
-        m_newSegment(0),
+        m_newSegment(nullptr),
         m_time(time),
         m_detached(false)
 {}
