@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -57,13 +57,13 @@ public:
                                SplitStrategy splitStrategy,
                                bool duplicateNonNoteEvents,
                                ClefHandling clefHandling);
-    virtual ~SegmentSplitByPitchCommand();
+    ~SegmentSplitByPitchCommand() override;
 
     static QString getGlobalName()
         { return tr("Split by &Pitch..."); }
 
-    virtual void execute();
-    virtual void unexecute();
+    void execute() override;
+    void unexecute() override;
 
 private:
     int getSplitPitchAt(Segment::iterator i);
