@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -41,7 +41,7 @@ class SegmentSyncClefCommand : public MacroCommand
 public:
     SegmentSyncClefCommand(Segment &segment, const Clef& clef);
 
-    virtual ~SegmentSyncClefCommand();
+    ~SegmentSyncClefCommand() override;
 
 protected:
     void processSegment(Segment &segment, const Clef& clef);
