@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -51,7 +51,7 @@ public:
     SegmentSyncCommand(SegmentMultiSet& segments, TrackId track,
             int newTranspose, int lowRange, int highRange, const Clef& clef);
 
-    virtual ~SegmentSyncCommand();
+    ~SegmentSyncCommand() override;
 
 protected:
     void processSegment(Segment &segment, int newTranspose, int lowRange, int highRange, const Clef& clef);
