@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -42,7 +42,7 @@ public:
     SegmentTransposeCommand(SegmentSelection selection,
         bool changeKey, int steps, int semitones, bool transposeSegmentBack);
 
-    virtual ~SegmentTransposeCommand();
+    ~SegmentTransposeCommand() override;
 
     static QString getGlobalName(int semitones = 0) {
         switch (semitones) {
