@@ -15,20 +15,17 @@
     COPYING included with this distribution for more information.
 */
 
-
 #define RG_MODULE_STRING "[ReconnectDeviceCommand]"
 
 #include "ReconnectDeviceCommand.h"
 
-#include "misc/Strings.h"
 #include "misc/Debug.h"
 #include "base/Device.h"
-#include "base/Studio.h"
-#include <QByteArray>
-#include <QDataStream>
-#include <QString>
-#include "sequencer/RosegardenSequencer.h"
+#include "base/MidiDevice.h"
 #include "gui/application/RosegardenMainWindow.h"
+#include "sequencer/RosegardenSequencer.h"
+#include "misc/Strings.h"  // For strtoqstr()...
+#include "base/Studio.h"
 
 
 namespace Rosegarden
@@ -39,19 +36,32 @@ void
 ReconnectDeviceCommand::execute()
 {
     Device *device = m_studio->getDevice(m_deviceId);
+    MidiDevice *midiDevice = dynamic_cast<MidiDevice *>(device);
 
-    if (device) {
-        RosegardenSequencer *sequencer = RosegardenSequencer::getInstance();
+    if (!midiDevice)
+        return;
 
-        m_oldConnection = qstrtostr(
-                sequencer->getConnection(device->getId()));
+    RosegardenSequencer *sequencer = RosegardenSequencer::getInstance();
 
-        sequencer->setConnection(m_deviceId, strtoqstr(m_newConnection));
-        device->setConnection(m_newConnection);
-        device->sendChannelSetups();
+    if (!sequencer)
+        return;
 
-        //RG_DEBUG << "execute(): reconnected device " << m_deviceId << " to " << m_newConnection;
-    }
+    // Preserve the old values for undo.
+    m_oldUserConnection = midiDevice->getUserConnection();
+    // We don't trust MidiDevice::m_currentConnection as that may
+    // not be in sync.  Get the actual connection direct from the source.
+    m_oldConnection = qstrtostr(
+            sequencer->getConnection(midiDevice->getId()));
+
+    // Make the actual connection.
+    sequencer->setConnection(m_deviceId, strtoqstr(m_newConnection));
+
+    // Update the MidiDevice
+    midiDevice->setUserConnection(m_newConnection);
+    midiDevice->setCurrentConnection(m_newConnection);
+    midiDevice->sendChannelSetups();
+
+    //RG_DEBUG << "execute(): reconnected device " << m_deviceId << " to " << m_newConnection;
 
     // ??? Instead of this kludge, we should be calling a Studio::hasChanged()
     //     which would then notify all observers (e.g. MIPP) who, in turn,
@@ -63,15 +73,21 @@ void
 ReconnectDeviceCommand::unexecute()
 {
     Device *device = m_studio->getDevice(m_deviceId);
+    MidiDevice *midiDevice = dynamic_cast<MidiDevice *>(device);
 
-    if (device) {
-        RosegardenSequencer::getInstance()->setConnection(
-                m_deviceId, strtoqstr(m_oldConnection));
-        device->setConnection(m_oldConnection);
-        device->sendChannelSetups();
+    if (!midiDevice)
+        return;
 
-        //RG_DEBUG << "unexecute(): reconnected device " << m_deviceId << " to " << m_oldConnection;
-    }
+    // Make the actual connection.
+    RosegardenSequencer::getInstance()->setConnection(
+            m_deviceId, strtoqstr(m_oldConnection));
+
+    // Update the MidiDevice
+    midiDevice->setUserConnection(m_oldUserConnection);
+    midiDevice->setCurrentConnection(m_oldConnection);
+    midiDevice->sendChannelSetups();
+
+    //RG_DEBUG << "unexecute(): reconnected device " << m_deviceId << " to " << m_oldConnection;
 
     // ??? Instead of this kludge, we should be calling a Studio::hasChanged()
     //     which would then notify all observers (e.g. MIPP) who, in turn,
