@@ -19,18 +19,18 @@
 #ifndef RG_RECONNECTDEVICECOMMAND_H
 #define RG_RECONNECTDEVICECOMMAND_H
 
-#include "base/Device.h"
-#include <string>
-#include "document/Command.h"
+#include "document/Command.h"  // For NamedCommand
+#include "base/Device.h"  // For DeviceId
+
 #include <QString>
-#include <QCoreApplication>
-
 
+#include <string>
 
 
 namespace Rosegarden
 {
 
+
 class Studio;
 
 
@@ -47,7 +47,7 @@ public:
         m_deviceId(deviceId),
         m_newConnection(newConnection) { }
 
-    static QString getGlobalName() { return tr("Reconnect Device"); }
+    static QString getGlobalName()  { return tr("Reconnect Device"); }
 
     void execute() override;
     void unexecute() override;
@@ -56,6 +56,7 @@ protected:
     Studio *m_studio;
     DeviceId m_deviceId;
     std::string m_newConnection;
+    std::string m_oldUserConnection;
     std::string m_oldConnection;
 };
 
