@@ -1753,7 +1753,6 @@ RoseXmlHandler::startElement(const QString& namespaceURI,
                     // For softsynth and audio Instruments, just set the
                     // pan as usual.
                     m_instrument->setControllerValue(MIDI_CONTROLLER_PAN, value);
-                    m_instrument->setSendPan(true);
                 }
             }
         } else if (m_section == InBuss) {
@@ -2430,21 +2429,45 @@ RoseXmlHandler::endElement(const QString& namespaceURI,
 
     } else if (lcName == "instrument") {
 
-        // If there were no <controlchange> tags within the <instrument>
+        // If there were no <controlchange> tags within the <instrument>.
         if (!m_controlChangeEncountered) {
-            // Use the deprecated <volume> and <pan> tags instead.
+            // Fall back on the deprecated <volume> and <pan> tags if they
+            // are available.
+
+            // This only happens with MIDI instruments.  Audio instruments
+            // are taken care of immediately when their <pan> and <level>
+            // tags are encountered.
 
             if (m_volumeEncountered) {
-                m_instrument->setControllerValue(MIDI_CONTROLLER_VOLUME, m_volume);
-                m_instrument->setSendVolume(true);
+                MidiDevice *midiDevice = dynamic_cast<MidiDevice *>(m_device);
+                if (midiDevice) {
+                    // If volume has a knob in the MIPP, go ahead and set the
+                    // CC value in the Instrument.  (If we do this when there
+                    // is no knob, CCs go out when they shouldn't.)
+                    if (midiDevice->isVisibleControlParameter(
+                            MIDI_CONTROLLER_VOLUME)) {
+                        m_instrument->setControllerValue(
+                                MIDI_CONTROLLER_VOLUME, m_volume);
+                    }
+                }
             }
 
             if (m_panEncountered) {
-                m_instrument->setControllerValue(MIDI_CONTROLLER_PAN, m_pan);
-                m_instrument->setSendPan(true);
+                MidiDevice *midiDevice = dynamic_cast<MidiDevice *>(m_device);
+                if (midiDevice) {
+                    // If pan has a knob in the MIPP, go ahead and set the
+                    // CC value in the Instrument.  (If we do this when there
+                    // is no knob, CCs go out when they shouldn't.)
+                    if (midiDevice->isVisibleControlParameter(
+                            MIDI_CONTROLLER_PAN)) {
+                        m_instrument->setControllerValue(
+                                MIDI_CONTROLLER_PAN, m_pan);
+                    }
+                }
             }
         }
 
+        // Exit the <instrument> section.
         m_section = InStudio;
         m_instrument = nullptr;
 
@@ -2711,14 +2734,19 @@ RoseXmlHandler::setMIDIDeviceConnection(QString connection)
 {
     RG_DEBUG << "setMIDIDeviceConnection(" << connection << ")";
 
-    MidiDevice *md = dynamic_cast<MidiDevice *>(m_device);
-    if (!md) return;
+    MidiDevice *midiDevice = dynamic_cast<MidiDevice *>(m_device);
+    if (!midiDevice)
+        return;
 
-    RosegardenSequencer::getInstance()->setPlausibleConnection
-        (md->getId(), connection);
-    // We sync connection now, otherwise we'll confuse
-    // MidiDevice::setConnection.
-    md->setConnection(qstrtostr(connection));
+    RosegardenSequencer::getInstance()->setPlausibleConnection(
+            midiDevice->getId(), connection);
+
+    midiDevice->setUserConnection(qstrtostr(connection));
+
+    // ??? This might not be the actual connection.  I'm guessing
+    //     Studio::resyncDeviceConnections() is called at some point
+    //     and this is corrected.
+    midiDevice->setCurrentConnection(qstrtostr(connection));
 }
 
 void
