@@ -349,11 +349,6 @@ public:
      */
     void setRecordStartTime(timeT t) { m_recordStartTime = t; }
 
-    /*
-    * Sync device information with sequencer
-    */
-    void checkSequencerTimer();
-
     /*
      * Get a MappedDevice from the sequencer and add the
      * results to our Studio
@@ -445,10 +440,6 @@ public:
      */
     void setSequenceManager(SequenceManager *sm);
 
-    QStringList getTimers();
-    QString getCurrentTimer();
-    void setCurrentTimer(QString);
-
     /**
      * return the list of the views currently connected to the document
      */
