@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     This file is Copyright 2005
         Toni Arnold         <toni__arnold@bluewin.ch>
@@ -35,7 +35,7 @@
 namespace Rosegarden
 {
 
-LircClient::LircClient(void)
+LircClient::LircClient()
         : QObject()
 {
     int socketFlags;
@@ -47,7 +47,7 @@ LircClient::LircClient(void)
         throw Exception("Failed to connect to LIRC");
     }
 
-    if (lirc_readconfig(NULL, &m_config, NULL) == -1) {
+    if (lirc_readconfig(nullptr, &m_config, nullptr) == -1) {
         throw Exception("Failed reading LIRC config file");
     }
 
@@ -57,8 +57,8 @@ LircClient::LircClient(void)
         fcntl(socketFlags, F_SETFL, socketFlags | O_NONBLOCK);
     }
 
-    m_socketNotifier = new QSocketNotifier(m_socket, QSocketNotifier::Read, 0);
-    connect(m_socketNotifier, SIGNAL(activated(int)), this, SLOT(readButton()) );
+    m_socketNotifier = new QSocketNotifier(m_socket, QSocketNotifier::Read, nullptr);
+    connect(m_socketNotifier, &QSocketNotifier::activated, this, &LircClient::readButton );
 
     RG_DEBUG << "LircClient::LircClient: connected to socket: " << m_socket;
 }
@@ -79,9 +79,9 @@ void LircClient::readButton()
 
     RG_DEBUG << "LircClient::readButton";
 
-    if (lirc_nextcode(&code) == 0 && code != NULL) {   // no error && a string is available
+    if (lirc_nextcode(&code) == 0 && code != nullptr) {   // no error && a string is available
         // handle any command attached to that button
-        while ( (ret = lirc_code2char(m_config, code, &m_command)) == 0 && m_command != NULL ) 
+        while ( (ret = lirc_code2char(m_config, code, &m_command)) == 0 && m_command != nullptr ) 
         {
             emit buttonPressed(m_command);
         }
