@@ -107,8 +107,6 @@ namespace Rosegarden
 //
 static double barWidth44 = 100.0;
 
-const QWidget *RosegardenMainViewWidget::m_lastActiveMainWindow = nullptr;
-
 // This is the maximum number of matrix, event view or percussion
 // matrix editors to open in a single operation (not the maximum that
 // can be open at a time -- there isn't one)
@@ -204,8 +202,9 @@ RosegardenMainViewWidget::RosegardenMainViewWidget(bool showTrackLabels,
             m_trackEditor->getTrackButtons(),
             &TrackButtons::slotTPBInstrumentSelected);
 
-    connect(this, SIGNAL(controllerDeviceEventReceived(MappedEvent *, const void *)),
-            this, SLOT(slotControllerDeviceEventReceived(MappedEvent *, const void *)));
+    connect(ExternalController::self().data(),
+                &ExternalController::externalControllerRMVW,
+            this, &RosegardenMainViewWidget::slotExternalController);
 
     if (doc) {
         /* signal no longer exists
@@ -409,9 +408,6 @@ RosegardenMainViewWidget::createNotationView(std::vector<Segment *> segmentsToEd
     NotationView *notationView =
         new NotationView(getDocument(), segmentsToEdit, this);
 
-    connect(notationView, SIGNAL(windowActivated()),
-            this, SLOT(slotActiveMainWindowChanged()));
-
     connect(notationView, &EditViewBase::selectTrack,
             this, &RosegardenMainViewWidget::slotSelectTrackSegments);
 
@@ -554,16 +550,12 @@ void RosegardenMainViewWidget::slotEditSegmentsPitchTracker(std::vector<Segment
     }
 }
 
-//!!! copied (+ renamed vars) blindly from NotationView, but it works.  -gp
 PitchTrackerView *
 RosegardenMainViewWidget::createPitchTrackerView(std::vector<Segment *> segmentsToEdit)
 {
     PitchTrackerView *pitchTrackerView =
         new PitchTrackerView(getDocument(), segmentsToEdit, this);
 
-    connect(pitchTrackerView, SIGNAL(windowActivated()),
-            this, SLOT(slotActiveMainWindowChanged()));
-
     connect(pitchTrackerView, &EditViewBase::selectTrack,
             this, &RosegardenMainViewWidget::slotSelectTrackSegments);
 
@@ -762,9 +754,6 @@ RosegardenMainViewWidget::createMatrixView(std::vector<Segment *> segmentsToEdit
                                                   drumMode,
                                                   this);
 
-    connect(matrixView, SIGNAL(windowActivated()),
-            this, SLOT(slotActiveMainWindowChanged()));
-
     connect(matrixView, &EditViewBase::selectTrack,
             this, &RosegardenMainViewWidget::slotSelectTrackSegments);
 
@@ -1807,110 +1796,10 @@ RosegardenMainViewWidget::slotSynchroniseWithComposition()
 }
 
 void
-RosegardenMainViewWidget::windowActivationChange(bool)
+RosegardenMainViewWidget::slotExternalController(const MappedEvent *event)
 {
-    if (isActiveWindow()) {
-        slotActiveMainWindowChanged(this);
-    }
-}
+    //RG_DEBUG << "slotExternalController()...";
 
-void
-RosegardenMainViewWidget::slotActiveMainWindowChanged(const QWidget *w)
-{
-    m_lastActiveMainWindow = w;
-}
-
-void
-RosegardenMainViewWidget::slotActiveMainWindowChanged()
-{
-    const QWidget *w = dynamic_cast<const QWidget *>(sender());
-    if (w)
-        slotActiveMainWindowChanged(w);
-}
-
-void
-RosegardenMainViewWidget::slotControllerDeviceEventReceived(MappedEvent *e)
-{
-    //RG_DEBUG << "slotControllerDeviceEventReceived() - send to " << (void *)m_lastActiveMainWindow << " (I am " << this << ")";
-
-    //!!! So, what _should_ we do with these?
-
-    // -- external controller that sends e.g. volume control for each
-    // of a number of channels -> if mixer present, use control to adjust
-    // tracks on mixer
-
-    // -- external controller that sends e.g. separate controllers on
-    // the same channel for adjusting various parameters -> if IPB
-    // visible, adjust it.  Should we use the channel to select the
-    // track? maybe as an option
-
-    // do we actually need the last active main window for either of
-    // these? -- yes, to determine whether to send to mixer or to IPB
-    // in the first place.  Send to audio mixer if active, midi mixer
-    // if active, plugin dialog if active, otherwise keep it for
-    // ourselves for the IPB.  But, we'll do that by having the edit
-    // views pass it back to us.
-
-    // -- then we need to send back out to device.
-
-    //!!! special cases: controller 81 received by any window ->
-    // select window 0->main, 1->audio mix, 2->midi mix
-
-    //!!! controller 82 received by main window -> select track
-
-    //!!! these obviously should be configurable
-
-    if (e->getType() == MappedEvent::MidiController) {
-
-        if (e->getData1() == 81) {
-
-            // select window
-            int window = e->getData2();
-
-            if (window < 10) { // me
-
-                show();
-
-                // Some window managers (e.g. GNOME) do not allow the
-                // application to change focus on the user.  So, this
-                // might not work.
-                activateWindow();
-                raise();
-
-            } else if (window < 20) {
-
-                RosegardenMainWindow::self()->slotOpenAudioMixer();
-
-            } else if (window < 30) {
-
-                RosegardenMainWindow::self()->slotOpenMidiMixer();
-            }
-        }
-    }
-
-    // Delegate to the currently active track-related window.
-    // The idea here is that the user can remotely switch between the
-    // three track-related windows (rg main, MIDI Mixer, and Audio Mixer)
-    // via controller 81 (above).  Then they can control the tracks
-    // on that window via other controllers.
-
-    // The behavior is slightly different between the three windows.
-    // The main window uses controller 82 to select a track while
-    // the other two use the incoming MIDI channel to select which
-    // track will be modified.
-    emit controllerDeviceEventReceived(e, m_lastActiveMainWindow);
-}
-
-void
-RosegardenMainViewWidget::slotControllerDeviceEventReceived(MappedEvent *e, const void *preferredCustomer)
-{
-    if (preferredCustomer != this)
-        return ;
-
-    //RG_DEBUG << "slotControllerDeviceEventReceived(): this one's for me";
-
-    // Some window managers (e.g. GNOME) do not allow the application to
-    // change focus on the user.  So, this might not work.
     activateWindow();
     raise();
 
@@ -1919,129 +1808,104 @@ RosegardenMainViewWidget::slotControllerDeviceEventReceived(MappedEvent *e, cons
     Composition &comp = getDocument()->getComposition();
     Studio &studio = getDocument()->getStudio();
 
-    TrackId currentTrackId = comp.getSelectedTrack();
-    Track *track = comp.getTrackById(currentTrackId);
+    // Program Change?  Adjust Track PC to match.
+    // ??? This is odd.  I don't think control surfaces typically provide
+    //     a Program Change control.  That's more a keyboard thing.
+    //     And if we handle this, we should also handle Bank Select.
+    //     But we don't.  I suspect this can be removed.
+    if (event->getType() == MappedEvent::MidiProgramChange) {
+        const Track *track = comp.getTrackById(comp.getSelectedTrack());
+        if (!track)
+            return;
 
-    // If the event is a control change on channel n, then (if
-    // follow-channel is on) switch to the nth track of the same type
-    // as the current track -- or the first track of the given
-    // channel?, and set the control appropriately.  Any controls in
-    // IPB are supported for a MIDI device plus program and bank; only
-    // volume and pan are supported for audio/synth devices.
-    //!!! complete this
+        Instrument *instrument =
+                studio.getInstrumentById(track->getInstrument());
+        if (!instrument)
+            return;
 
-    if (e->getType() != MappedEvent::MidiController) {
+        instrument->setProgramChange(event->getData1());
+        instrument->sendChannelSetup();
+        RosegardenMainWindow::self()->getDocument()->slotDocumentModified();
 
-        if (e->getType() == MappedEvent::MidiProgramChange) {
-            int program = e->getData1();
-            if (!track)
-                return ;
-            InstrumentId ii = track->getInstrument();
-            Instrument *instrument = studio.getInstrumentById(ii);
-            if (!instrument)
-                return ;
-            instrument->setProgramChange(program);
-            instrument->sendChannelSetup();
-            RosegardenMainWindow::self()->getDocument()->slotDocumentModified();
-        }
-        return ;
+        return;
     }
 
-    // unsigned int channel = e->getRecordedChannel();
-    MidiByte controller = e->getData1();
-    MidiByte value = e->getData2();
+    if (event->getType() != MappedEvent::MidiController)
+        return;
 
-    if (controller == 82) { // !!! magic select-track controller
-        int tracks = comp.getNbTracks();
+    // We have a CC coming in...
+
+    const MidiByte controlNumber = event->getData1();
+    const MidiByte value = event->getData2();
+
+    // CONTROLLER_SELECT_TRACK
+    if (controlNumber == 82) {
+        const unsigned tracks = comp.getNbTracks();
+
+        // Get the track to select based on CC value.
         Track *track = comp.getTrackByPosition(value * tracks / 128);
-        if (track) {
-            comp.setSelectedTrack(track->getId());
-            comp.notifyTrackSelectionChanged(track->getId());
+        if (!track)
+            return;
 
-            slotSelectTrackSegments(track->getId());
+        comp.setSelectedTrack(track->getId());
+        comp.notifyTrackSelectionChanged(track->getId());
 
-            // Emit a documentModified(), but don't set the document
-            // modified flag.  This refreshes the UI but doesn't make
-            // the star appear in the titlebar.
-            RosegardenMainWindow::self()->getDocument()->emitDocumentModified();
-        }
-        return ;
+        slotSelectTrackSegments(track->getId());
+
+        // Emit a documentModified(), but don't set the document
+        // modified flag.  This refreshes the UI but doesn't make
+        // the star appear in the titlebar.
+        RosegardenMainWindow::self()->getDocument()->emitDocumentModified();
+
+        return;
     }
 
+    const Track *track = comp.getTrackById(comp.getSelectedTrack());
     if (!track)
-        return ;
-
-    InstrumentId ii = track->getInstrument();
-    Instrument *instrument = studio.getInstrumentById(ii);
+        return;
 
+    Instrument *instrument = studio.getInstrumentById(track->getInstrument());
     if (!instrument)
-        return ;
+        return;
 
-    switch (instrument->getType()) {
-
-    case Instrument::Midi: {
-            MidiDevice *md = dynamic_cast<MidiDevice *>(instrument->getDevice());
-            if (!md) {
-                RG_WARNING << "slotControllerDeviceEventReceived(): WARNING: MIDI instrument has no MIDI device in slotControllerDeviceEventReceived";
-                return ;
-            }
-
-            ControlList cl = md->getControlParameters();
-            for (ControlList::const_iterator i = cl.begin(); i != cl.end(); ++i) {
-                if ((*i).getControllerNumber() == controller) {
-                    //RG_DEBUG << "  Setting controller " << controller << " for instrument " << instrument->getId() << " to " << value;
-                    instrument->setControllerValue(controller, value);
-                    Instrument::emitControlChange(instrument, controller);
-                    getDocument()->setModified();
-
-                    break;
-                }
-            }
-            break;
-        }
-
-    case Instrument::SoftSynth:
-    case Instrument::Audio:
-
-        switch (controller) {
-
-        case MIDI_CONTROLLER_VOLUME:  {
-            //RG_DEBUG << "  Setting volume for instrument " << instrument->getId() << " to " << value;
-
-            float dB = AudioLevel::fader_to_dB(
-                    value, 127, AudioLevel::ShortFader);
-
-            instrument->setLevel(dB);
-            Instrument::emitControlChange(instrument, MIDI_CONTROLLER_VOLUME);
+    if (instrument->getType() == Instrument::Midi) {
+        // If the incoming control number is valid for the Instrument...
+        if (instrument->hasController(controlNumber)) {
+            // Adjust the Instrument and update everyone.
+            instrument->setControllerValue(controlNumber, value);
+            Instrument::emitControlChange(instrument, controlNumber);
             getDocument()->setModified();
-
-            break;
         }
 
-        case MIDI_CONTROLLER_PAN:  {
-            //RG_DEBUG << "  Setting pan for instrument " << instrument->getId() << " to " << value;
-
-            float pan = (value / 64.0) * 100.0 + 0.01;
-
-            // This wants 0 to 200.
-            instrument->setControllerValue(MIDI_CONTROLLER_PAN, MidiByte(pan));
-            Instrument::emitControlChange(instrument, MIDI_CONTROLLER_PAN);
-            getDocument()->setModified();
-
-            break;
-        }
-
-        default:
-            break;
-        }
-        break;
-
-    case Instrument::InvalidInstrument:
-    default:
-        break;
+        return;
     }
 
-    //!!! send out updates via MIDI
+    // We have an audio instrument or a softsynth...
+
+    if (controlNumber == MIDI_CONTROLLER_VOLUME) {
+        //RG_DEBUG << "  Setting volume for instrument " << instrument->getId() << " to " << value;
+
+        const float dB = AudioLevel::fader_to_dB(
+                value, 127, AudioLevel::ShortFader);
+
+        instrument->setLevel(dB);
+        Instrument::emitControlChange(instrument, MIDI_CONTROLLER_VOLUME);
+        getDocument()->setModified();
+
+        return;
+    }
+
+    if (controlNumber == MIDI_CONTROLLER_PAN) {
+        //RG_DEBUG << "  Setting pan for instrument " << instrument->getId() << " to " << value;
+
+        instrument->setControllerValue(
+                MIDI_CONTROLLER_PAN,
+                AudioLevel::AudioPanI(value));
+        Instrument::emitControlChange(instrument, MIDI_CONTROLLER_PAN);
+        getDocument()->setModified();
+
+        return;
+    }
 }
 
 void
@@ -2057,9 +1921,6 @@ RosegardenMainViewWidget::createEventView(std::vector<Segment *> segmentsToEdit)
                                          segmentsToEdit,
                                          this);
 
-    connect(eventView, SIGNAL(windowActivated()),
-        this, SLOT(slotActiveMainWindowChanged()));
-
     connect(eventView, &EditViewBase::selectTrack,
             this, &RosegardenMainViewWidget::slotSelectTrackSegments);
 
