@@ -23,7 +23,9 @@
 #include "base/Selection.h"
 #include "base/Track.h"
 #include "sound/AudioFile.h"
+#include "sound/ExternalController.h"
 #include "gui/editors/segment/TrackEditor.h"
+
 #include <QString>
 #include <QWidget>
 #include <QVBoxLayout>
@@ -44,6 +46,7 @@ class SimpleRulerScale;
 class SegmentParameterBox;
 class Segment;
 class RosegardenDocument;
+class RosegardenParameterArea;
 class RealTime;
 class NotationView;
 class PitchTrackerView;
@@ -125,13 +128,8 @@ public:
     SegmentSelection getSelection();
     void updateSelectedSegments();
 
-    static bool isMainWindowLastActive(const QWidget *w) {
-        return w == m_lastActiveMainWindow;
-    }
-
-    TrackParameterBox *getTrackParameterBox() {
-        return m_trackParameterBox;
-    }
+    TrackParameterBox *getTrackParameterBox()
+            { return m_trackParameterBox; }
 
 public slots:
     void slotEditSegment(Segment*);
@@ -233,28 +231,6 @@ public slots:
      */
     void slotSynchroniseWithComposition();
 
-    /**
-     * To indicate that an edit view, mixer, etc (something that might
-     * want to receive MIDI input) has become active.  We only send
-     * inputs such as MIDI to a single one of these, in most cases,
-     * and it's whichever was most recently made active.  (It doesn't
-     * have to still _be_ active -- we want to allow moving focus to
-     * another application entirely but still receiving MIDI etc in
-     * Rosegarden.)
-     */
-    void slotActiveMainWindowChanged(const QWidget *);
-    void slotActiveMainWindowChanged(); // uses sender()
-
-    /// Handle events from the external controller port.
-    /**
-     * This routine handles remote control events received from a
-     * device connected to the "external controller" port.
-     *
-     * This routine handles controller 81 which opens or
-     * brings to the top various windows based on the value.
-     */
-    void slotControllerDeviceEventReceived(MappedEvent *);
-
     /// Handle events from the external controller port.
     /**
      * This routine handles remote control events received from a
@@ -267,11 +243,10 @@ public slots:
      * for the current track.  For audio tracks, MIDI volume and pan
      * controllers control the track's volume and pan.
      *
-     * @see MidiMixerWindow::slotControllerDeviceEventReceived()
-     * @see AudioMixerWindow2::slotExternalControllerEvent()
+     * @see MidiMixerWindow::slotExternalController()
+     * @see AudioMixerWindow2::slotExternalController()
      */
-    void slotControllerDeviceEventReceived(
-            MappedEvent *, const void *preferredCustomer);
+    void slotExternalController(const MappedEvent *event);
 
 signals:
     void activateTool(QString toolName);
@@ -310,16 +285,12 @@ signals:
     void instrumentLevelsChanged(InstrumentId,
                                  const LevelInfo &);
 
-    void controllerDeviceEventReceived(MappedEvent *,
-                                       const void *);
+private:
 
-protected:
     NotationView *createNotationView(std::vector<Segment *>);
-    MatrixView   *createMatrixView  (std::vector<Segment *>, bool drumMode);
-    EventView    *createEventView   (std::vector<Segment *>);
-    PitchTrackerView *createPitchTrackerView (std::vector<Segment *>);
-
-    virtual void windowActivationChange(bool);
+    MatrixView *createMatrixView(std::vector<Segment *>, bool drumMode);
+    EventView *createEventView(std::vector<Segment *>);
+    PitchTrackerView *createPitchTrackerView(std::vector<Segment *>);
 
     static bool hasNonAudioSegment(const SegmentSelection &segments);
 
@@ -332,7 +303,6 @@ protected:
     InstrumentParameterBox        *m_instrumentParameterBox;
     TrackParameterBox             *m_trackParameterBox;
 
-    static const QWidget          *m_lastActiveMainWindow;
 };
 
 
