@@ -18,13 +18,16 @@
 #ifndef RG_ROSEGARDENMAINWINDOW_H
 #define RG_ROSEGARDENMAINWINDOW_H
 
+#include "gui/application/RosegardenMainViewWidget.h"
 #include "base/MidiProgram.h"
 #include "gui/dialogs/TempoDialog.h"
 #include "gui/widgets/ZoomSlider.h"
 #include "gui/general/RecentFiles.h"
 #include "base/Event.h"
 #include "base/Selection.h"
+#include "base/Typematic.h"
 #include "sound/AudioFile.h"
+#include "sound/ExternalController.h"
 #include "sound/Midi.h"
 #include "gui/general/ActionFileClient.h"
 
@@ -67,7 +70,6 @@ class StartupTester;
 class SequenceManager;
 class SegmentParameterBox;
 class RosegardenParameterArea;
-class RosegardenMainViewWidget;
 class RosegardenDocument;
 class RealTime;
 class ProgressBar;
@@ -134,16 +136,6 @@ public:
 
     ~RosegardenMainWindow() override;
 
-    /** Qt generates a QCloseEvent when the user clicks the close button on the
-     * title bar.  We also get a close event when slotQuit() calls close().
-     *
-     * Control passes here where we call queryClose() to ask if the user wants
-     * to save a modified document.  If queryClose() returns true, we accept the
-     * close event.  Otherwise we ignore it, the closing breaks, and we keep
-     * running.
-     */
-    void closeEvent(QCloseEvent *event) override;
-
     /// Global access to the single instance of this class.
     static RosegardenMainWindow *self() { return m_myself; }
     
@@ -246,30 +238,6 @@ public:
      */
     QPointer<DeviceManagerDialog> getDeviceManager()  { return m_deviceManager; }
 
-
-
-    /**
-     * Equivalents of the GUI slots, for DCOP use
-     */
-    virtual void fileNew()    { slotFileNew(); }
-    virtual void fileSave()   { slotFileSave(); }
-    virtual void fileClose()  { slotFileClose(); }
-    virtual void quit()       { slotQuit(); }
-
-    virtual void play()               { slotPlay(); }
-    virtual void stop()               { slotStop(); }
-    virtual void rewind()             { slotRewind(); }
-    virtual void fastForward()        { slotFastforward(); }
-    virtual void record()             { slotRecord(); }
-    virtual void rewindToBeginning()  { slotRewindToBeginning(); }
-    virtual void fastForwardToEnd()   { slotFastForwardToEnd(); }
-    virtual void jumpToTime(RealTime rt) { slotJumpToTime(rt); }
-    virtual void startAtTime(RealTime rt) { slotStartAtTime(rt); }
-    
-    virtual void trackUp()            { slotTrackUp(); }
-    virtual void trackDown()          { slotTrackDown(); }
-//    virtual void toggleRecordCurrentTrack() { slotToggleRecordCurrentTrack(); }
-       
     /**
      * Create some new audio files for the sequencer and return the
      * paths for them as QStrings.
@@ -355,11 +323,39 @@ public:
 
     void uiUpdateKludge();
 
+    void openWindow(ExternalController::Window window);
 
+    void toggleLoop();
 
 protected:
 
-    RosegardenDocument* newDocument(bool skipAutoload = false);
+    /// Handle activation change.
+    /**
+     * We do this to make sure external controller is connected to the
+     * current window.  Otherwise if the user clicks on the main window,
+     * external controller events might still be controlling one of the
+     * other windows.
+     */
+    void changeEvent(QEvent *event) override;
+
+    /** Qt generates a QCloseEvent when the user clicks the close button on the
+     * title bar.  We also get a close event when slotQuit() calls close().
+     *
+     * Control passes here where we call queryClose() to ask if the user wants
+     * to save a modified document.  If queryClose() returns true, we accept the
+     * close event.  Otherwise we ignore it, the closing breaks, and we keep
+     * running.
+     */
+    void closeEvent(QCloseEvent *event) override;
+
+    /// Handle Rosegarden-specific events.  Usually from the sequencer thread.
+    /**
+     * See SequencerDataBlock and slotHandleInputs() which also support
+     * communication between the threads.
+     */
+    void customEvent(QEvent *event) override;
+
+    RosegardenDocument *newDocument(bool skipAutoload = false);
 
     /**** File handling code that we don't want the outside world to use ****/
     /**/
@@ -503,7 +499,7 @@ protected:
      * Set the current document
      *
      * Do all the needed housework when the current document changes
-     * (like closing edit views, emitting documentChanged signal, etc...)
+     * (like closing edit views, emitting documentLoaded signal, etc...)
      */
     void setDocument(RosegardenDocument*);
 
@@ -543,8 +539,8 @@ signals:
     /// emitted just before the document is changed
     void documentAboutToChange();
 
-    /// emitted when the current document changes
-    void documentChanged(RosegardenDocument*);
+    /// Emitted when a new document is loaded.
+    void documentLoaded(RosegardenDocument *);
 
     /// emitted when the set of selected segments changes (relayed from RosegardenMainViewWidget)
     void segmentsSelected(const SegmentSelection &);
@@ -1311,11 +1307,8 @@ public slots:
      */
     void slotShowTip();
 
-    /*
-     * Select Track up or down
-     */
-    void slotTrackUp();
-    void slotTrackDown();
+    void slotSelectPreviousTrack();
+    void slotSelectNextTrack();
 
     /**
      * Toggle arm (record) current track
@@ -1563,6 +1556,10 @@ public slots:
 
     void slotNewerVersionAvailable(QString);
     
+    void slotAddMarker2();
+    void slotPreviousMarker();
+    void slotNextMarker();
+
     void slotSetQuickMarker();
     
     void slotJumpToQuickMarker();    
@@ -1729,6 +1726,11 @@ private:
 
     void updateTitle();
 
+    /// For the rewind button on a keyboard controller.
+    Typematic m_rewindTypematic;
+    /// For the fast-forward button on a keyboard controller.
+    Typematic m_fastForwardTypematic;
+
 private slots:
     void signalAction(int);
 
