@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -47,9 +47,9 @@ class AudioConfigurationPage : public TabbedConfigurationPage
     Q_OBJECT
 public:
     AudioConfigurationPage(RosegardenDocument *doc,
-                               QWidget *parent = 0);
+                               QWidget *parent = nullptr);
 
-    virtual void apply();
+    void apply() override;
 
     static QString iconLabel() { return tr("Audio"); }
     static QString title()     { return tr("Audio Settings"); }
