@@ -19,7 +19,6 @@
 #include "AudioPropertiesPage.h"
 #include "misc/Strings.h"
 #include "misc/Debug.h"
-#include "ConfigurationPage.h"
 #include "document/RosegardenDocument.h"
 #include "sequencer/RosegardenSequencer.h"
 #include "gui/studio/AudioPluginManager.h"
@@ -51,10 +50,10 @@
 namespace Rosegarden
 {
 
-AudioPropertiesPage::AudioPropertiesPage(RosegardenDocument *doc,  QWidget *parent)
-        : TabbedConfigurationPage(doc, parent)
+AudioPropertiesPage::AudioPropertiesPage(QWidget *parent) :
+    TabbedConfigurationPage(parent)
 {
-    AudioFileManager &afm = doc->getAudioFileManager();
+    AudioFileManager &afm = m_doc->getAudioFileManager();
 
     QFrame *frame = new QFrame(m_tabWidget);
     frame->setContentsMargins(10, 10, 10, 10);
