@@ -23,7 +23,6 @@
 #include "misc/Strings.h"
 #include "base/ColourMap.h"
 #include "commands/segment/SegmentColourMapCommand.h"
-#include "ConfigurationPage.h"
 #include "document/RosegardenDocument.h"
 #include "document/CommandHistory.h"
 #include "gui/general/GUIPalette.h"
@@ -49,8 +48,8 @@
 namespace Rosegarden
 {
 
-ColourConfigurationPage::ColourConfigurationPage(RosegardenDocument *doc, QWidget *parent)
-        : TabbedConfigurationPage(doc, parent)
+ColourConfigurationPage::ColourConfigurationPage(QWidget *parent) :
+    TabbedConfigurationPage(parent)
 {
     QFrame *frame = new QFrame(m_tabWidget);
     frame->setContentsMargins(10, 10, 10, 10);
