@@ -31,7 +31,6 @@
 #include "base/BasicQuantizer.h"
 #include "base/RealTime.h"
 #include "base/Segment.h"
-#include "ConfigurationPage.h"
 #include "document/RosegardenDocument.h"
 #include "gui/editors/notation/NotationStrings.h"
 #include "gui/configuration/HeadersConfigurationPage.h"
@@ -89,19 +88,18 @@ public:
 };
 
 DocumentMetaConfigurationPage::DocumentMetaConfigurationPage(
-        RosegardenDocument *doc,
         QWidget *parent) :
-    TabbedConfigurationPage(doc, parent)
+    TabbedConfigurationPage(parent)
 {
-    m_headersPage = new HeadersConfigurationPage(this, doc,
+    m_headersPage = new HeadersConfigurationPage(this, m_doc,
                             static_cast<ConfigureDialogBase * >(parent));
     addTab(m_headersPage, tr("Headers"));
     
-    m_commentsPage = new CommentsConfigurationPage(this, doc,
+    m_commentsPage = new CommentsConfigurationPage(this, m_doc,
                             static_cast<ConfigureDialogBase * >(parent));
     addTab(m_commentsPage, tr("Notes"));
 
-    Composition &comp = doc->getComposition();
+    Composition &comp = m_doc->getComposition();
     std::set
         <TrackId> usedTracks;
 
@@ -121,7 +119,7 @@ DocumentMetaConfigurationPage::DocumentMetaConfigurationPage(
     layout->setSpacing(5);
 
     layout->addWidget(new QLabel(tr("Filename:"), frame), 0, 0);
-    layout->addWidget(new QLabel(doc->getTitle(), frame), 0, 1);
+    layout->addWidget(new QLabel(m_doc->getTitle(), frame), 0, 1);
 
     layout->addWidget(new QLabel(tr("Formal duration (to end marker):"), frame), 1, 0);
     timeT d = comp.getEndMarker();
