@@ -349,6 +349,22 @@ GeneralConfigurationPage::GeneralConfigurationPage(QWidget *parent) :
 
     ++row;
 
+    // Track size
+    layout->addWidget(new QLabel(tr("Track size"), frame), row, 0);
+
+    m_trackSize = new QComboBox(frame);
+    m_trackSize->addItem(tr("Small"));
+    m_trackSize->addItem(tr("Medium"));
+    m_trackSize->addItem(tr("Large"));
+    m_trackSize->setCurrentIndex(
+            settings.value("track_size", 0).toInt());
+    connect(m_trackSize, static_cast<void(QComboBox::*)(int)>(
+                    &QComboBox::activated),
+            this, &GeneralConfigurationPage::slotModified);
+    layout->addWidget(m_trackSize, row, 1, 1, 3);
+
+    ++row;
+
     // Make the last row stretch to fill the rest of the space.
     layout->setRowStretch(row, 10);
 
@@ -488,13 +504,13 @@ void GeneralConfigurationPage::apply()
 
     settings.beginGroup(GeneralOptionsConfigGroup);
 
-    bool thornChanged =
+    const bool thornChanged =
             (settings.value("use_thorn_style", true).toBool() !=
              m_Thorn->isChecked());
     //RG_DEBUG << "apply(): NB. use_thorn_style = " << settings.value("use_thorn_style", true).toBool() << ", m_Thorn->isChecked() = " << m_Thorn->isChecked();
     settings.setValue("use_thorn_style", m_Thorn->isChecked());
     settings.setValue("notenamestyle", m_nameStyle->currentIndex());
-    bool mainTextureChanged =
+    const bool mainTextureChanged =
             (settings.value("backgroundtextures", true).toBool() !=
              m_backgroundTextures->isChecked());
     settings.setValue("backgroundtextures", m_backgroundTextures->isChecked());
@@ -507,6 +523,10 @@ void GeneralConfigurationPage::apply()
 
     settings.beginGroup(GeneralOptionsConfigGroup);
     settings.setValue("long_window_titles", m_longTitles->isChecked());
+    const bool trackSizeChanged =
+            (settings.value("track_size", 0).toInt() !=
+             m_trackSize->currentIndex());
+    settings.setValue("track_size", m_trackSize->currentIndex());
     settings.endGroup();
 
     // External Applications tab
@@ -529,6 +549,11 @@ void GeneralConfigurationPage::apply()
         QMessageBox::information(this, tr("Rosegarden"),
                 tr("You must restart Rosegarden for the presentation change to take effect."));
     }
+
+    if (trackSizeChanged) {
+        QMessageBox::information(this, tr("Rosegarden"),
+                tr("You must restart Rosegarden or open a file for the track size change to take effect."));
+    }
 }
 
 
