@@ -19,75 +19,77 @@
 #define RG_MIDICONFIGURATIONPAGE_H
 
 #include "TabbedConfigurationPage.h"
-#include "gui/widgets/LineEdit.h"
 
 #include <QString>
-#include <QSlider>
 #include <QCheckBox>
 
-
-class QWidget;
-class QSpinBox;
-class QSlider;
+class QComboBox;
 class QPushButton;
-class QLabel;
-class QComboBox;
-class QComboBox;
-class LineEdit;
+class QSpinBox;
+class QWidget;
 
 
 namespace Rosegarden
 {
 
+
 class RosegardenDocument;
+class LineEdit;
 
 
 class MIDIConfigurationPage : public TabbedConfigurationPage
 {
     Q_OBJECT
+
 public:
-    MIDIConfigurationPage(RosegardenDocument *doc, QWidget *parent = nullptr);
+    MIDIConfigurationPage(QWidget *parent);
 
     void apply() override;
 
-    static QString iconLabel() { return tr("MIDI"); }
-    static QString title()     { return tr("MIDI Settings"); }
+    // Info for ConfigureDialog.
+    static QString iconLabel()  { return tr("MIDI"); }
+    static QString title()  { return tr("MIDI Settings"); }
     static QString iconName()  { return "configure-midi"; }
 
-protected slots:
-    void slotSoundFontToggled(bool);
-    void slotSfxLoadPathChoose();
+private slots:
+
+    void slotLoadSoundFontClicked(bool isChecked);
+    void slotPathToLoadChoose();
     void slotSoundFontChoose();
 
-protected:
-    bool getUseDefaultStudio()      { return m_studio->isChecked(); }
+private:
 
-    //--------------- Data members ---------------------------------
+    // *** General tab
 
-    // General
+    /// Base octave number for MIDI pitch display.
+    QSpinBox *m_baseOctaveNumber;
+
+    QCheckBox *m_useDefaultStudio;
+    QCheckBox *m_externalControllerPort;
+    QComboBox *m_controllerType;
     QCheckBox *m_allowResetAllControllers;
+    QCheckBox *m_acceptTransportCCs;
+    /// Timer value at the beginning to detect changes.
+    QString m_originalTimingSource;
+    QComboBox *m_sequencerTimingSource;
 
-    QCheckBox   *m_sfxLoadEnabled;
-    LineEdit    *m_sfxLoadPath;
-    QPushButton *m_sfxLoadChoose;
-    LineEdit    *m_soundFontPath;
+    QCheckBox *m_loadSoundFont;
+    LineEdit *m_pathToLoadCommand;
+    QPushButton *m_pathToLoadChoose;
+    LineEdit *m_soundFont;
     QPushButton *m_soundFontChoose;
 
-    // Sync and timing
-    //
-    //QCheckBox *m_midiClockEnabled;
-    QComboBox *m_midiSync;
-    QString    m_origTimer;
-    QComboBox *m_timer;
-    QComboBox *m_mmcTransport;
-    QComboBox *m_mtcTransport;
-    QCheckBox *m_midiSyncAuto;
 
-    QCheckBox* m_studio;
-    QSpinBox*  m_midiPitchOctave;
+    // *** MIDI Sync tab
+
+    QComboBox *m_midiClock;
+    QComboBox *m_midiMachineControlMode;
+    QComboBox *m_midiTimeCodeMode;
+    QCheckBox *m_autoConnectSyncOut;
+
+    void updateWidgets();
 
 };
- 
 
 
 }
