@@ -15,40 +15,27 @@
     COPYING included with this distribution for more information.
 */
 
-
 #include "TabbedConfigurationPage.h"
 
-#include "ConfigurationPage.h"
-#include "document/RosegardenDocument.h"
-#include <QSettings>
+#include "gui/application/RosegardenMainWindow.h"
+
 #include <QString>
 #include <QTabWidget>
-#include <QWidget>
-#include <QLayout>
+#include <QVBoxLayout>
 
 
 namespace Rosegarden
 {
 
-TabbedConfigurationPage::TabbedConfigurationPage(RosegardenDocument *doc,
-                                                 QWidget *parent)
-    : ConfigurationPage(doc, parent)
-{
-    init();
-}
 
-TabbedConfigurationPage::TabbedConfigurationPage(QWidget *parent)
-    : ConfigurationPage(parent)
+TabbedConfigurationPage::TabbedConfigurationPage(QWidget *parent) :
+    QWidget(parent)
 {
-    init();
-}
+    m_doc = RosegardenMainWindow::self()->getDocument();
 
-void TabbedConfigurationPage::init()
-{
-//@@@    QVBoxLayout *vlay = new QVBoxLayout(this, 0, KDialog::spacingHint());
-    QVBoxLayout *vlay = new QVBoxLayout(this);
+    QVBoxLayout *layout = new QVBoxLayout(this);
     m_tabWidget = new QTabWidget(this);
-    vlay->addWidget(m_tabWidget);
+    layout->addWidget(m_tabWidget);
 }
 
 void TabbedConfigurationPage::addTab(QWidget *tab, const QString &title)
@@ -56,4 +43,5 @@ void TabbedConfigurationPage::addTab(QWidget *tab, const QString &title)
     m_tabWidget->addTab(tab, title);
 }
 
+
 }
