@@ -18,41 +18,53 @@
 #ifndef RG_TABBEDCONFIGURATIONPAGE_H
 #define RG_TABBEDCONFIGURATIONPAGE_H
 
-#include "ConfigurationPage.h"
-#include <QString>
+#include <QWidget>
 
-class QWidget;
+class QString;
 class QTabWidget;
 
 
 namespace Rosegarden
 {
 
+
 class RosegardenDocument;
 
-
-/**
- * This class borrowed from KMail
- * (c) 2000 The KMail Development Team
- */
-class TabbedConfigurationPage : public ConfigurationPage
+class TabbedConfigurationPage : public QWidget
 {
     Q_OBJECT
 
 public:
-    TabbedConfigurationPage(RosegardenDocument *doc, QWidget *parent = nullptr);
 
-    TabbedConfigurationPage(QWidget *parent = nullptr);
+    TabbedConfigurationPage(QWidget *parent);
+    virtual ~TabbedConfigurationPage() override  { }
+
+    /// Apply the changes by copying from the widgets to the .conf file.
+    /**
+     * Called by ConfigureDialogBase::slotApply() when the user presses either
+     * Apply or Ok.
+     */
+    virtual void apply() = 0;
+
+signals:
+
+    /**
+     * ConfigureDialog and DocumentConfigureDialog use this to enable
+     * the Apply button.
+     */
+    void modified();
+
+protected slots:
+
+    virtual void slotModified()  { emit modified(); }
 
-    static QString iconName() { return "misc"; }
-    
 protected:
-    void init();
-    void addTab(QWidget *tab, const QString &title);
 
-    //--------------- Data members ---------------------------------
+    // ??? Clients should get this themselves.
+    RosegardenDocument *m_doc;
 
     QTabWidget *m_tabWidget;
+    void addTab(QWidget *tab, const QString &title);
 
 };
 
