@@ -37,6 +37,7 @@
 #include "document/CommandHistory.h"
 #include "document/RosegardenDocument.h"
 #include "misc/ConfigGroups.h"
+#include "gui/application/RosegardenMainWindow.h"
 #include "gui/application/RosegardenMainViewWidget.h"
 #include "sequencer/RosegardenSequencer.h"
 #include "gui/widgets/AudioListItem.h"
@@ -107,7 +108,7 @@ AudioManagerDialog::AudioManagerDialog(QWidget *parent,
 {
     setWindowTitle(tr("Audio File Manager"));
     this->setAttribute(Qt::WA_DeleteOnClose);
-    setWindowIcon(IconLoader().loadPixmap("window-audio-manager"));
+    setWindowIcon(IconLoader::loadPixmap("window-audio-manager"));
     setMinimumWidth(800);
 
     QWidget *centralWidget = new QWidget;
