@@ -45,6 +45,7 @@ namespace Rosegarden
 {
 
 
+class AudioListView;
 class Segment;
 class RosegardenDocument;
 class RealTime;
@@ -52,7 +53,7 @@ class AudioPlayingDialog;
 class AudioFile;
 class Command;
 
-
+/// Audio File Manager
 class AudioManagerDialog : public QMainWindow, public ActionFileClient
 {
     Q_OBJECT
@@ -158,9 +159,13 @@ signals:
     void cancelPlayingAudioFile(AudioFileId);
     void deleteAllAudioFiles();
 
-    // We've selected a segment here, make the canvas select it too
-    //
+    /// We've selected a segment here, make the canvas select it too
+    /**
+     * RosegardenMainWindow::slotAudioManager() connects this to
+     * RosegardenMainViewWidget::slotPropagateSegmentSelection().
+     */
     void segmentsSelected(const SegmentSelection&);
+
     void deleteSegments(const SegmentSelection&);
     void insertAudioSegment(AudioFileId,
                             const RealTime &,
@@ -181,7 +186,7 @@ protected:
 
     //--------------- Data members ---------------------------------
 
-    QTreeWidget        *m_fileList;         // (==AudioListView)
+    AudioListView *m_fileList;
     WarningGroupBox    *m_wrongSampleRates;
     RosegardenDocument *m_doc;
 
