@@ -900,15 +900,6 @@ AudioPluginDialog::slotBypassChanged(bool bp)
     emit bypassed(m_containerId, m_index, bp);
 }
 
-void
-AudioPluginDialog::windowActivationChange(bool /*oldState*/)
-{
-    if (isActiveWindow()) {
-        emit windowActivated();
-    }
-}
-
-
 void
 AudioPluginDialog::slotCopy()
 {
