@@ -101,15 +101,11 @@ signals:
     void bypassed(InstrumentId, int pluginIndex, bool bp);
     void destroyed(InstrumentId, int index);
 
-    void windowActivated();
-
 protected slots:
     // Unused
     //virtual void slotClose();
 
 protected:
-    virtual void windowActivationChange(bool);
-
     void makePluginParamsBox(QWidget*);
     QStringList getProgramsForInstance(AudioPluginInstance *inst, int &current);
 
