@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -76,7 +76,7 @@ CheckForParallelsDialog::CheckForParallelsDialog(NotationView *p, RosegardenDocu
     pal.setColor(QPalette::Text, Qt::black);
     textBrowser->setPalette(pal);
 
-    connect(textBrowser, SIGNAL(cursorPositionChanged()), this, SLOT(onTextBrowserclicked()));
+    connect(textBrowser, &QTextEdit::cursorPositionChanged, this, &CheckForParallelsDialog::onTextBrowserclicked);
 
     ignoreCursor = true;
 
@@ -94,7 +94,7 @@ CheckForParallelsDialog::CheckForParallelsDialog(NotationView *p, RosegardenDocu
     vboxLayout->addWidget(checkForUnisonsCheckBox);
     checkForUnisonsCheckBox->setChecked( checkForUnisons );
 
-    connect(checkForUnisonsCheckBox, SIGNAL(clicked()), this, SLOT(checkForUnisonsClicked()));
+    connect(checkForUnisonsCheckBox, &QAbstractButton::clicked, this, &CheckForParallelsDialog::checkForUnisonsClicked);
 
     // we make the check for hidden parallels optional
     //
@@ -105,7 +105,7 @@ CheckForParallelsDialog::CheckForParallelsDialog(NotationView *p, RosegardenDocu
     vboxLayout->addWidget(checkForHiddenParallelsCheckBox);
     checkForHiddenParallelsCheckBox->setChecked( checkForHiddenParallels );
 
-    connect(checkForHiddenParallelsCheckBox, SIGNAL(clicked()), this, SLOT(checkForHiddenParallelsClicked()));
+    connect(checkForHiddenParallelsCheckBox, &QAbstractButton::clicked, this, &CheckForParallelsDialog::checkForHiddenParallelsClicked);
 
     // buttons
 
@@ -132,10 +132,10 @@ CheckForParallelsDialog::CheckForParallelsDialog(NotationView *p, RosegardenDocu
     settings.endGroup();
 
 
-    connect(startButton, SIGNAL(clicked()), this, SLOT(startCheck()));
-    connect(clearButton, SIGNAL(clicked()), this, SLOT(clear()));
-    connect(exportButton, SIGNAL(clicked()), this, SLOT(exportText()));
-    connect(okButton, SIGNAL(clicked()), this, SLOT(cleanUpAndLeave()));
+    connect(startButton, &QAbstractButton::clicked, this, &CheckForParallelsDialog::startCheck);
+    connect(clearButton, &QAbstractButton::clicked, this, &CheckForParallelsDialog::clear);
+    connect(exportButton, &QAbstractButton::clicked, this, &CheckForParallelsDialog::exportText);
+    connect(okButton, &QAbstractButton::clicked, this, &CheckForParallelsDialog::cleanUpAndLeave);
 
     transitionList.clear();
 }
@@ -179,7 +179,7 @@ CheckForParallelsDialog::exportText()
     static QString lastExportDirectory;
     QString name = FileDialog::getSaveFileName(
             this, label, lastExportDirectory,
-            QString(""), "*.txt", 0,
+            QString(""), "*.txt", nullptr,
             FileDialog::DontConfirmOverwrite);
 
     if (name == "")
@@ -409,7 +409,7 @@ CheckForParallelsDialog::startCheck()
     int currentTrackPosition;
     QString currentTrackLabel;
 
-    NotationStaff *currentStaff;
+    NotationStaff *currentStaff = nullptr;
 
     parallelList.clear();
 
@@ -427,7 +427,7 @@ CheckForParallelsDialog::startCheck()
     parallelLocation pl;
 
     pl.time = -1;
-    pl.staff = 0;
+    pl.staff = nullptr;
 
     locationForLine.push_back(pl);
     locationForLine.push_back(pl);
@@ -495,7 +495,7 @@ CheckForParallelsDialog::startCheck()
                     // the line numbers for the real parallels in the text browser are correct
 
                     pl.time = -1;
-                    pl.staff = 0;
+                    pl.staff = nullptr;
 
                     if ( predecessorEnd > currentTime ) {
                         int bar;
