@@ -20,7 +20,6 @@
 #include "ConfigureDialogBase.h"
 
 #include "document/RosegardenDocument.h"
-#include "gui/configuration/ConfigurationPage.h"
 #include "gui/configuration/GeneralConfigurationPage.h"
 #include "gui/configuration/NotationConfigurationPage.h"
 #include "gui/configuration/PitchTrackerConfigurationPage.h"
@@ -48,8 +47,6 @@ ConfigureDialog::ConfigureDialog(RosegardenDocument *doc,
     : ConfigureDialogBase(parent, tr("Rosegarden - Preferences"), name )
 {
     
-    IconLoader il;
-    
     // General
     GeneralConfigurationPage *generalConfigurationPage =
             new GeneralConfigurationPage(this);
@@ -60,18 +57,18 @@ ConfigureDialog::ConfigureDialog(RosegardenDocument *doc,
             this, &ConfigureDialog::updateAutoSaveInterval);
     addPage(GeneralConfigurationPage::iconLabel(),
             GeneralConfigurationPage::title(),
-            il.loadPixmap(GeneralConfigurationPage::iconName()),
+            IconLoader::loadPixmap(GeneralConfigurationPage::iconName()),
             generalConfigurationPage);
     m_configurationPages.push_back(generalConfigurationPage);
 
     // MIDI
     MIDIConfigurationPage *midiConfigurationPage =
-            new MIDIConfigurationPage(doc, this);
+            new MIDIConfigurationPage(this);
     connect(midiConfigurationPage, &MIDIConfigurationPage::modified,
             this, &ConfigureDialog::slotActivateApply);
     addPage(MIDIConfigurationPage::iconLabel(),
             MIDIConfigurationPage::title(),
-            il.loadPixmap(MIDIConfigurationPage::iconName()),
+            IconLoader::loadPixmap(MIDIConfigurationPage::iconName()),
             midiConfigurationPage);
     m_configurationPages.push_back(midiConfigurationPage);
 
@@ -82,7 +79,7 @@ ConfigureDialog::ConfigureDialog(RosegardenDocument *doc,
             this, &ConfigureDialog::slotActivateApply);
     addPage(AudioConfigurationPage::iconLabel(),
             AudioConfigurationPage::title(),
-            il.loadPixmap(AudioConfigurationPage::iconName()),
+            IconLoader::loadPixmap(AudioConfigurationPage::iconName()),
             audioConfigurationPage);
     m_configurationPages.push_back(audioConfigurationPage);
 
@@ -93,7 +90,7 @@ ConfigureDialog::ConfigureDialog(RosegardenDocument *doc,
             this, &ConfigureDialog::slotActivateApply);
     addPage(NotationConfigurationPage::iconLabel(),
             NotationConfigurationPage::title(),
-            il.loadPixmap(NotationConfigurationPage::iconName()),
+            IconLoader::loadPixmap(NotationConfigurationPage::iconName()),
             notationConfigurationPage);
     m_configurationPages.push_back(notationConfigurationPage);
 
@@ -105,7 +102,7 @@ ConfigureDialog::ConfigureDialog(RosegardenDocument *doc,
             this, &ConfigureDialog::slotActivateApply);
     addPage(PitchTrackerConfigurationPage::iconLabel(),
             PitchTrackerConfigurationPage::title(),
-            il.loadPixmap(PitchTrackerConfigurationPage::iconName()),
+            IconLoader::loadPixmap(PitchTrackerConfigurationPage::iconName()),
             pitchTrackerConfigurationPage);
     m_configurationPages.push_back(pitchTrackerConfigurationPage);
 
@@ -121,7 +118,7 @@ ConfigureDialog::setNotationPage()
 {
     int index = 0;
 
-    for (configurationpages::iterator i = m_configurationPages.begin();
+    for (ConfigurationPages::iterator i = m_configurationPages.begin();
             i != m_configurationPages.end(); ++i) {
 
         NotationConfigurationPage *page =
