@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -36,31 +36,35 @@
 namespace Rosegarden
 {
 
-DocumentConfigureDialog::DocumentConfigureDialog(RosegardenDocument *doc,
-        QWidget *parent,
-        const char *name)
-    : ConfigureDialogBase(parent, tr("Document Properties"), name )//, QMessageBox::StandardButtons buttons )
+DocumentConfigureDialog::DocumentConfigureDialog(QWidget *parent,
+                                                 const char *name) :
+    ConfigureDialogBase(parent, tr("Document Properties"), name)
 {
-    QWidget *page = 0;
-
     // Document Meta Page
     //
-    IconLoader il;
-    page = new DocumentMetaConfigurationPage(doc, this);
-    connect(page, SIGNAL(modified()), this, SLOT(slotActivateApply()));
+    DocumentMetaConfigurationPage *documentMetaConfigurationPage =
+            new DocumentMetaConfigurationPage(this);
+    connect(documentMetaConfigurationPage,
+                &DocumentMetaConfigurationPage::modified,
+            this, &DocumentConfigureDialog::slotActivateApply);
     addPage(DocumentMetaConfigurationPage::iconLabel(),
             DocumentMetaConfigurationPage::title(),
-            il.loadPixmap( DocumentMetaConfigurationPage::iconName()), page);
-    m_configurationPages.push_back((ConfigurationPage *)page);
+            IconLoader::loadPixmap( DocumentMetaConfigurationPage::iconName()),
+            documentMetaConfigurationPage);
+    m_configurationPages.push_back(
+            static_cast<TabbedConfigurationPage *>(documentMetaConfigurationPage));
 
     // Audio Page
     //
-    page = new AudioPropertiesPage(doc, this);
-    connect(page, SIGNAL(modified()), this, SLOT(slotActivateApply()));
+    AudioPropertiesPage *audioPropertiesPage = new AudioPropertiesPage(this);
+    connect(audioPropertiesPage, &AudioPropertiesPage::modified,
+            this, &DocumentConfigureDialog::slotActivateApply);
     addPage(AudioPropertiesPage::iconLabel(),
             AudioPropertiesPage::title(),
-            il.loadPixmap(AudioPropertiesPage::iconName()),page);
-    m_configurationPages.push_back((ConfigurationPage *)page);
+            IconLoader::loadPixmap(AudioPropertiesPage::iconName()),
+            audioPropertiesPage);
+    m_configurationPages.push_back(
+            static_cast<TabbedConfigurationPage *>(audioPropertiesPage));
 }
 
 void
@@ -68,7 +72,7 @@ DocumentConfigureDialog::showAudioPage()
 {
     int index = 0;
 
-    for (configurationpages::iterator i = m_configurationPages.begin();
+    for (ConfigurationPages::iterator i = m_configurationPages.begin();
             i != m_configurationPages.end(); ++i) {
 
         AudioPropertiesPage *page =
