@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -35,9 +35,8 @@ class DocumentConfigureDialog : public ConfigureDialogBase
 {
     //Q_OBJECT
 public:
-    DocumentConfigureDialog(RosegardenDocument *doc,
-                            QWidget *parent=0,
-                            const char *name=0);
+    DocumentConfigureDialog(QWidget *parent,
+                            const char *name = nullptr);
 
     void showAudioPage();
 
