@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -50,7 +50,7 @@ class ImportDeviceDialog : public QDialog
 
 public:
     ImportDeviceDialog(QWidget *parent, QUrl url);
-    virtual ~ImportDeviceDialog();
+    ~ImportDeviceDialog() override;
 
     bool doImport();
 
@@ -71,7 +71,7 @@ public:
     MidiDevice::VariationType getVariationType() const;
 
 public slots:
-    void accept();
+    void accept() override;
     void slotCancel();
 
 protected:
