@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -42,7 +42,7 @@ class PitchPickerDialog : public QDialog
 public:
 
     PitchPickerDialog(QWidget* parent, int initialPitch, QString text);
-    ~PitchPickerDialog();
+    ~PitchPickerDialog() override;
 
     int getPitch() { return m_pitch->getPitch(); }
     
