@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -39,26 +39,37 @@ QuantizeDialog::QuantizeDialog(QWidget *parent, bool inNotation) :
     QVBoxLayout *vboxLayout = new QVBoxLayout;
     setLayout(vboxLayout);
 
-    m_quantizeFrame = new QuantizeParameters(this , inNotation ?
+    m_quantizeParameters = new QuantizeParameters(this , inNotation ?
             QuantizeParameters::Notation : QuantizeParameters::Grid,
             false);
-    vboxLayout->addWidget(m_quantizeFrame);
+    vboxLayout->addWidget(m_quantizeParameters);
 
-    m_quantizeFrame->getAdvancedWidget()->show();
-    m_quantizeFrame->adjustSize();
+    m_quantizeParameters->adjustSize();
     adjustSize();
 
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
 
     vboxLayout->addWidget(buttonBox);
-    connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
-    connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &QuantizeDialog::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 }
 
 Quantizer *
 QuantizeDialog::getQuantizer() const
 {
-    return m_quantizeFrame->getQuantizer();
+    return m_quantizeParameters->getQuantizer();
+}
+
+void
+QuantizeDialog::accept()
+{
+    // Save the settings.
+    // ??? We could do this in QuantizeParameters dtor, but not sure
+    //     we want to save settings on Cancel as well as Ok.
+    m_quantizeParameters->saveSettings();
+
+    // Let the baseclass take care of the rest.
+    QDialog::accept();
 }
 
 
