@@ -26,10 +26,12 @@
 #include "gui/editors/guitar/Chord.h"
 #include "misc/Strings.h"
 #include "misc/Debug.h"
+#include "misc/ConfigGroups.h"  // for LastUsedPathsConfigGroup
 #include "PitchDialog.h"
 #include "TimeDialog.h"
 #include "gui/widgets/LineEdit.h"
 #include "gui/widgets/FileDialog.h"
+#include "sound/Midi.h"
 
 #include <QComboBox>
 #include <QDialog>
@@ -39,12 +41,14 @@
 #include <QGroupBox>
 #include <QGridLayout>
 #include <QLabel>
+#include <QMessageBox>
 #include <QPushButton>
 #include <QSpinBox>
 #include <QString>
 #include <QWidget>
 #include <QVBoxLayout>
 #include <QLayout>
+#include <QSettings>
 
 
 
@@ -511,10 +515,11 @@ SimpleEventEditDialog::setupForEvent()
         m_controllerLabel->setText(tr("Data length:"));
         m_metaLabel->setText(tr("Data:"));
         try {
-            SystemExclusive sysEx(m_event);
+            std::string datablock;
+            m_event.get<String>(SystemExclusive::DATABLOCK, datablock);
             m_controllerLabelValue->setText(QString("%1").
-                                            arg(sysEx.getRawData().length()));
-            m_metaEdit->setText(strtoqstr(sysEx.getHexData()));
+                    arg(SystemExclusive::toRaw(datablock).length()));
+            m_metaEdit->setText(strtoqstr(datablock));
         } catch (...) {
             m_controllerLabelValue->setText("0");
         }
@@ -1055,48 +1060,90 @@ SimpleEventEditDialog::slotEditPitch()
 void
 SimpleEventEditDialog::slotSysexLoad()
 {
-    QString path = FileDialog::getOpenFileName( this, tr("Load System Exclusive data in File"), QDir::currentPath(),
-                   tr("System exclusive files") + " (*.syx *.SYX)" + ";;" +
-                   tr("All files") + " (*)"); //":SYSTEMEXCLUSIVE",
+    QSettings settings;
+    settings.beginGroup(LastUsedPathsConfigGroup);
+    const QString pathKey = "load_sysex";
+    QString directory = settings.value(pathKey, QDir::homePath()).toString();
 
-    if (path.isNull())
+    QString name = FileDialog::getOpenFileName(
+            this,  // parent
+            tr("Load System Exclusive data in File"),  // caption
+            directory,  // dir
+            tr("System exclusive files") + " (*.syx *.SYX)" + ";;" +
+                tr("All files") + " (*)");  // filter
+
+    if (name.isNull())
         return ;
 
-    QFile file(path);
+    QFile file(name);
     file.open(QIODevice::ReadOnly);
     std::string s;
     char c;
-    bool ioOk;
 
-    while ((ioOk = file.getChar(&c))) {
-        if (c == static_cast<char>(0xf0)) break;
-    }
-    while (ioOk) {
-        s += c;
-        if (c == static_cast<char>(0xf7))
+    // Discard leading bytes up to and including the first SysEx Start (F0).
+    while (file.getChar(&c)) {
+        if (c == static_cast<char>(MIDI_SYSTEM_EXCLUSIVE))
             break;
-        ioOk = file.getChar(&c);
     }
+    // Copy up to but not including SysEx End (F7).
+    while (file.getChar(&c)) {
+        if (c == static_cast<char>(MIDI_END_OF_EXCLUSIVE))
+            break;
+        s += c;
+    }
+
     file.close();
+
+    if (s.empty())
+        QMessageBox::critical(this, tr("Rosegarden"), tr("Could not load SysEx file."));
+
     m_metaEdit->setText(strtoqstr(SystemExclusive::toHex(s)));
+
+    // Write the directory to the settings
+    QDir d = QFileInfo(name).dir();
+    directory = d.canonicalPath();
+    settings.setValue(pathKey, directory);
+    settings.endGroup();
 }
 
 void
 SimpleEventEditDialog::slotSysexSave()
 {
-    QString path = FileDialog::getSaveFileName( this, //":SYSTEMEXCLUSIVE",
-			tr("Save System Exclusive data to..."),
-					tr("*.syx|System exclusive files (*.syx)")
-					);
-    if (path.isNull())
-        return ;
+    QSettings settings;
+    settings.beginGroup(LastUsedPathsConfigGroup);
+    const QString pathKey = "save_sysex";
+    QString directory = settings.value(pathKey, QDir::homePath()).toString();
 
-    QFile file(path);
+    QString name = FileDialog::getSaveFileName(
+            this,  // parent
+            tr("Save System Exclusive data to..."),  // caption
+            directory,  // dir
+            "",  // defaultName
+            tr("System exclusive files") + " (*.syx *.SYX)" + ";;" +
+                tr("All files") + " (*)");  // filter
+            //tr("*.syx|System exclusive files (*.syx)"));  // filter
+    if (name.isNull())
+        return;
+
+    QFile file(name);
     file.open(QIODevice::WriteOnly);
-    SystemExclusive sysEx(m_event);
-    file.write(sysEx.getRawData().c_str(),
-               static_cast<qint64>(sysEx.getRawData().length()));
+
+    std::string datablock;
+    m_event.get<String>(SystemExclusive::DATABLOCK, datablock);
+    // Add SysEx and End SysEx status bytes.
+    datablock = "F0 " + datablock + " F7";
+    datablock = SystemExclusive::toRaw(datablock);
+    file.write(datablock.c_str(),
+               static_cast<qint64>(datablock.length()));
+
     file.close();
+
+    // Write the directory to the settings
+    QDir d = QFileInfo(name).dir();
+    directory = d.canonicalPath();
+    settings.setValue(pathKey, directory);
+    settings.endGroup();
 }
 
+
 }
