@@ -23,6 +23,7 @@
 #include <QPixmap>
 #include <QtCore>
 #include <QDialog>
+#include <QSharedPointer>
 
 #include "base/Composition.h" // for tempoT
 
@@ -155,7 +156,7 @@ signals:
     void editTempo(QWidget *);
     void editTimeSignature(QWidget *);
     void editTransportTime(QWidget *);
-    void scrollTempo(int);
+    //void scrollTempo(int);
     void panic();
 
 private:
@@ -166,7 +167,7 @@ private:
 
     //--------------- Data members ---------------------------------
 
-    Ui_RosegardenTransport* ui;
+    QSharedPointer<Ui_RosegardenTransport> ui;
 
     QHash<int, QPixmap> m_lcdList;
     QHash<int, QPixmap> m_lcdListDefault;
