@@ -90,6 +90,7 @@
 namespace Rosegarden
 {
 
+
 EventView::EventView(RosegardenDocument *doc,
                      std::vector<Segment *> segments,
                      QWidget *parent):
@@ -178,21 +179,24 @@ EventView::EventView(RosegardenDocument *doc,
         layout->addWidget(m_triggerName, 0, 1);
         QPushButton *editButton = new QPushButton(tr("edit"), frame);
         layout->addWidget(editButton, 0, 2);
-        connect(editButton, &QAbstractButton::clicked, this, &EventView::slotEditTriggerName);
+        connect(editButton, &QAbstractButton::clicked,
+                this, &EventView::slotEditTriggerName);
 
         layout->addWidget(new QLabel(tr("Base pitch:  "), frame), 1, 0);
         m_triggerPitch = new QLabel(QString("%1").arg(rec->getBasePitch()), frame);
         layout->addWidget(m_triggerPitch, 1, 1);
         editButton = new QPushButton(tr("edit"), frame);
         layout->addWidget(editButton, 1, 2);
-        connect(editButton, &QAbstractButton::clicked, this, &EventView::slotEditTriggerPitch);
+        connect(editButton, &QAbstractButton::clicked,
+                this, &EventView::slotEditTriggerPitch);
 
         layout->addWidget(new QLabel(tr("Base velocity:  "), frame), 2, 0);
         m_triggerVelocity = new QLabel(QString("%1").arg(rec->getBaseVelocity()), frame);
         layout->addWidget(m_triggerVelocity, 2, 1);
         editButton = new QPushButton(tr("edit"), frame);
         layout->addWidget(editButton, 2, 2);
-        connect(editButton, &QAbstractButton::clicked, this, &EventView::slotEditTriggerVelocity);
+        connect(editButton, &QAbstractButton::clicked,
+                this, &EventView::slotEditTriggerVelocity);
 
         /*!!! Comment out these two options, which are not yet used
           anywhere else -- intended for use with library ornaments, not
@@ -1085,20 +1089,23 @@ EventView::slotEditDelete()
 void
 EventView::slotEditInsert()
 {
-    RG_DEBUG << "EventView::slotEditInsert";
-
     timeT insertTime = m_segments[0]->getStartTime();
+    // Go with a crotchet by default.
     timeT insertDuration = 960;
 
-    QList<QTreeWidgetItem*> selection = m_eventList->selectedItems();
+    QList<QTreeWidgetItem *> selection = m_eventList->selectedItems();
 
-    if (selection.count() > 0) {
+    // If something is selected, use the time and duration from the
+    // first selected event.
+    if (!selection.isEmpty()) {
         EventViewItem *item =
-            dynamic_cast<EventViewItem*>(selection.first());
+            dynamic_cast<EventViewItem *>(selection.first());
 
         if (item) {
             insertTime = item->getEvent()->getAbsoluteTime();
             insertDuration = item->getEvent()->getDuration();
+
+            // ??? Could check for a note event and copy pitch and velocity.
         }
     }
 
@@ -1108,69 +1115,117 @@ EventView::slotEditInsert()
     event.set<Int>(BaseProperties::PITCH, 70);
     event.set<Int>(BaseProperties::VELOCITY, 100);
 
-    SimpleEventEditDialog dialog(this, getDocument(), event, true);
+    SimpleEventEditDialog dialog(
+            this,
+            getDocument(),
+            event,
+            true);  // inserting
 
-    if (dialog.exec() == QDialog::Accepted) {
-        EventInsertionCommand *command =
+    // Launch dialog.  Bail if canceled.
+    if (dialog.exec() != QDialog::Accepted)
+        return;
+
+    EventInsertionCommand *command =
             new EventInsertionCommand(
                     *m_segments[0],
                     new Event(dialog.getEvent()));
-        addCommandToHistory(command);
-    }
+
+    addCommandToHistory(command);
 }
 
 void
 EventView::slotEditEvent()
 {
-    RG_DEBUG << "EventView::slotEditEvent";
+    // See slotOpenInEventEditor().
 
-    QList<QTreeWidgetItem*> selection = m_eventList->selectedItems();
+    // ??? Why not use currentItem()?
+    QList<QTreeWidgetItem *> selection = m_eventList->selectedItems();
 
-    if (selection.count() > 0) {
-        EventViewItem *item =
-            dynamic_cast<EventViewItem*>(selection.first());
+    if (selection.isEmpty())
+        return;
 
-        if (item) {
-            Event *event = item->getEvent();
-            SimpleEventEditDialog dialog(this, getDocument(), *event, false);
+    EventViewItem *eventViewItem =
+            dynamic_cast<EventViewItem *>(selection.first());
+    if (!eventViewItem)
+        return;
 
-            if (dialog.exec() == QDialog::Accepted && dialog.isModified()) {
-                EventEditCommand *command =
-                    new EventEditCommand(*(item->getSegment()),
-                                         event,
-                                         dialog.getEvent());
+    // Get the Segment.  Have to do this before launching
+    // the dialog since eventViewItem might become invalid.
+    Segment *segment = eventViewItem->getSegment();
+    if (!segment)
+        return;
 
-                addCommandToHistory(command);
-            }
-        }
-    }
+    // Get the Event.  Have to do this before launching
+    // the dialog since eventViewItem might become invalid.
+    Event *event = eventViewItem->getEvent();
+    if (!event)
+        return;
+
+    SimpleEventEditDialog dialog(
+            this,
+            getDocument(),
+            *event,
+            false);  // inserting
+
+    // Launch dialog.  Bail if canceled.
+    if (dialog.exec() != QDialog::Accepted)
+        return;
+
+    // Not modified?  Bail.
+    if (!dialog.isModified())
+        return;
+
+    EventEditCommand *command =
+            new EventEditCommand(*segment,
+                                 event,
+                                 dialog.getEvent());
+
+    addCommandToHistory(command);
 }
 
 void
 EventView::slotEditEventAdvanced()
 {
-    RG_DEBUG << "EventView::slotEditEventAdvanced";
+    // See slotOpenInExpertEventEditor().
 
-    QList<QTreeWidgetItem*> selection = m_eventList->selectedItems();
+    QList<QTreeWidgetItem *> selection = m_eventList->selectedItems();
 
-    if (selection.count() > 0) {
-        EventViewItem *item =
-            dynamic_cast<EventViewItem*>(selection.first());
+    if (selection.isEmpty())
+        return;
 
-        if (item) {
-            Event *event = item->getEvent();
-            EventEditDialog dialog(this, *event);
+    EventViewItem *eventViewItem =
+            dynamic_cast<EventViewItem *>(selection.first());
+    if (!eventViewItem)
+        return;
 
-            if (dialog.exec() == QDialog::Accepted && dialog.isModified()) {
-                EventEditCommand *command =
-                    new EventEditCommand(*(item->getSegment()),
-                                         event,
-                                         dialog.getEvent());
+    // Get the Segment.  Have to do this before launching
+    // the dialog since eventViewItem might become invalid.
+    Segment *segment = eventViewItem->getSegment();
+    if (!segment)
+        return;
 
-                addCommandToHistory(command);
-            }
-        }
-    }
+    // Get the Event.  Have to do this before launching
+    // the dialog since eventViewItem might become invalid.
+    Event *event = eventViewItem->getEvent();
+    if (!event)
+        return;
+
+    EventEditDialog dialog(this, *event);
+
+    // Launch dialog.  Bail if canceled.
+    if (dialog.exec() != QDialog::Accepted)
+        return;
+
+    // Not modified?  Bail.
+    if (!dialog.isModified())
+        return;
+
+    EventEditCommand *command =
+            new EventEditCommand(*segment,
+                                 event,
+                                 dialog.getEvent());
+
+    addCommandToHistory(command);
 }
 
 void
@@ -1391,27 +1446,58 @@ EventView::slotRawTime()
 }
 
 void
-EventView::slotPopupEventEditor(QTreeWidgetItem *item, int)
+EventView::slotPopupEventEditor(QTreeWidgetItem *item, int /* column */)
 {
-    EventViewItem *eItem = dynamic_cast<EventViewItem*>(item);
-
-    //!!! trigger events
-
-    if (eItem) {
-        Event *event = eItem->getEvent();
-        SimpleEventEditDialog *dialog =
-            new SimpleEventEditDialog(this, getDocument(), *event, false);
-
-        if (dialog->exec() == QDialog::Accepted && dialog->isModified()) {
-            EventEditCommand *command =
-                new EventEditCommand(*(eItem->getSegment()),
-                                     event,
-                                     dialog->getEvent());
-
-            addCommandToHistory(command);
-        }
-
+    EventViewItem *eventViewItem = dynamic_cast<EventViewItem *>(item);
+    if (!eventViewItem) {
+        RG_WARNING << "slotPopupEventEditor(): WARNING: No EventViewItem.";
+        return;
     }
+
+    // Get the Segment.  Have to do this before launching
+    // the dialog since eventViewItem might become invalid.
+    // ??? Why is the QTreeWidgetItem going away?  It appears to be
+    //     happening as a result of the call to exec() below.  Is someone
+    //     refreshing the list?
+    Segment *segment = eventViewItem->getSegment();
+    if (!segment) {
+        RG_WARNING << "slotPopupEventEditor(): WARNING: No Segment.";
+        return;
+    }
+
+    // !!! trigger events
+
+    // Get the Event.  Have to do this before launching
+    // the dialog since eventViewItem might become invalid.
+    Event *event = eventViewItem->getEvent();
+    if (!event) {
+        RG_WARNING << "slotPopupEventEditor(): WARNING: No Event.";
+        return;
+    }
+
+    SimpleEventEditDialog dialog(
+                    this,  // parent
+                    getDocument(),
+                    *event,
+                    false);  // inserting
+
+    // Launch dialog.  Bail if canceled.
+    if (dialog.exec() != QDialog::Accepted)
+        return;
+
+    // Not modified?  Bail.
+    if (!dialog.isModified())
+        return;
+
+    // Note: At this point, item and eventViewItem may be invalid.
+    //       Do not use them.
+
+    EventEditCommand *command =
+            new EventEditCommand(*segment,
+                                 event,
+                                 dialog.getEvent());
+
+    addCommandToHistory(command);
 }
 
 void
@@ -1439,67 +1525,97 @@ EventView::slotPopupMenu(const QPoint& pos)
 void
 EventView::createMenu()
 {
-    //m_menu = new QPopupMenu(this);
     m_menu = new QMenu(this);
-    QAction *eventEditorAction = m_menu->addAction( tr("Open in Event Editor") );
-    QAction *expertEventEditorAction = m_menu->addAction( tr("Open in Expert Event Editor") );
 
-    QSignalMapper *signalMapper = new QSignalMapper(this);
-    signalMapper->setMapping(eventEditorAction, 0);
-    signalMapper->setMapping(expertEventEditorAction, 1);
+    QAction *eventEditorAction =
+            m_menu->addAction(tr("Open in Event Editor"));
+    connect(eventEditorAction, &QAction::triggered,
+            this, &EventView::slotOpenInEventEditor);
 
-    connect(eventEditorAction, SIGNAL(triggered()),
-            signalMapper, SLOT(map()));
-    connect(expertEventEditorAction, SIGNAL(triggered()),
-            signalMapper, SLOT(map()));
-
-    connect(signalMapper, SIGNAL(mapped(int)),
-            SLOT(slotMenuActivated(int)));
+    QAction *expertEventEditorAction =
+            m_menu->addAction(tr("Open in Expert Event Editor"));
+    connect(expertEventEditorAction, &QAction::triggered,
+            this, &EventView::slotOpenInExpertEventEditor);
 }
 
 void
-EventView::slotMenuActivated(int value)
+EventView::slotOpenInEventEditor(bool /* checked */)
 {
-    RG_DEBUG << "EventView::slotMenuActivated - value = " << value;
+    EventViewItem *eventViewItem =
+            dynamic_cast<EventViewItem *>(m_eventList->currentItem());
+    if (!eventViewItem)
+        return;
 
-    if (value == 0) {
-        EventViewItem *eItem = dynamic_cast<EventViewItem*>(m_eventList->currentItem());
+    // Get the Segment.  Have to do this before launching
+    // the dialog since eventViewItem might become invalid.
+    Segment *segment = eventViewItem->getSegment();
+    if (!segment)
+        return;
 
-        if (eItem) {
-            Event *event = eItem->getEvent();
-            SimpleEventEditDialog *dialog =
-                new SimpleEventEditDialog(this, getDocument(), *event, false);
+    // Get the Event.  Have to do this before launching
+    // the dialog since eventViewItem might become invalid.
+    Event *event = eventViewItem->getEvent();
+    if (!event)
+        return;
 
-            if (dialog->exec() == QDialog::Accepted && dialog->isModified()) {
-                EventEditCommand *command =
-                    new EventEditCommand(*(eItem->getSegment()),
-                                         event,
-                                         dialog->getEvent());
+    SimpleEventEditDialog dialog(
+            this,
+            getDocument(),
+            *event,
+            false);  // inserting
 
-                addCommandToHistory(command);
-            }
+    // Launch dialog.  Bail if canceled.
+    if (dialog.exec() != QDialog::Accepted)
+        return;
 
-        }
-    } else if (value == 1) {
-        EventViewItem *eItem = dynamic_cast<EventViewItem*>(m_eventList->currentItem());
+    // Not modified?  Bail.
+    if (!dialog.isModified())
+        return;
 
-        if (eItem) {
-            Event *event = eItem->getEvent();
-            EventEditDialog *dialog = new EventEditDialog(this, *event);
+    EventEditCommand *command =
+            new EventEditCommand(*segment,
+                                 event,
+                                 dialog.getEvent());
 
-            if (dialog->exec() == QDialog::Accepted && dialog->isModified()) {
-                EventEditCommand *command =
-                    new EventEditCommand(*(eItem->getSegment()),
-                                         event,
-                                         dialog->getEvent());
+    addCommandToHistory(command);
+}
 
-                addCommandToHistory(command);
-            }
+void
+EventView::slotOpenInExpertEventEditor(bool /* checked */)
+{
+    EventViewItem *eventViewItem =
+            dynamic_cast<EventViewItem *>(m_eventList->currentItem());
+    if (!eventViewItem)
+        return;
 
-        }
-    }
+    // Get the Segment.  Have to do this before launching
+    // the dialog since eventViewItem might become invalid.
+    Segment *segment = eventViewItem->getSegment();
+    if (!segment)
+        return;
 
-    return ;
+    // Get the Event.  Have to do this before launching
+    // the dialog since eventViewItem might become invalid.
+    Event *event = eventViewItem->getEvent();
+    if (!event)
+        return;
+
+    EventEditDialog dialog(this, *event);
+
+    // Launch dialog.  Bail if canceled.
+    if (dialog.exec() != QDialog::Accepted)
+        return;
+
+    // Not modified?  Bail.
+    if (!dialog.isModified())
+        return;
+
+    EventEditCommand *command =
+            new EventEditCommand(*segment,
+                                 event,
+                                 dialog.getEvent());
+
+    addCommandToHistory(command);
 }
 
 void
@@ -1554,7 +1670,7 @@ EventView::updateWindowTitle(bool m)
                        .arg(m_segments.size()));
     }
 
-    setWindowIcon(IconLoader().loadPixmap("window-eventlist"));
+    setWindowIcon(IconLoader::loadPixmap("window-eventlist"));
 
 }
 
