@@ -115,8 +115,6 @@ public slots:
     // other edit slots
     void slotEditDelete();
     void slotEditInsert();
-    void slotEditEvent();
-    void slotEditEventAdvanced();
 
     void slotSelectAll();
     void slotClearSelection();
@@ -125,15 +123,6 @@ public slots:
     void slotRealTime();
     void slotRawTime();
 
-    // Show RMB menu
-    //
-    void slotPopupMenu(const QPoint&);
-    void slotMenuActivated(int);
-
-    // on double click on the event list
-    //
-    void slotPopupEventEditor(QTreeWidgetItem*, int);
-
     // Change filter parameters
     //
     void slotModifyFilter();
@@ -149,9 +138,26 @@ public slots:
 signals:
     void editTriggerSegment(int);
 
-protected slots:
+private slots:
     void slotSaveOptions() override;
 
+    // Menu Handlers
+
+    /// Edit > Edit Event
+    void slotEditEvent();
+    /// Edit > Advanced Event Editor
+    void slotEditEventAdvanced();
+
+    /// Handle double-click on an event in the event list.
+    void slotPopupEventEditor(QTreeWidgetItem *item, int column);
+
+    /// Right-click context menu.
+    void slotPopupMenu(const QPoint&);
+    /// Right-click context menu handler.
+    void slotOpenInEventEditor(bool checked);
+    /// Right-click context menu handler.
+    void slotOpenInExpertEventEditor(bool checked);
+
     void slotEditTriggerName();
     void slotEditTriggerPitch();
     void slotEditTriggerVelocity();
@@ -161,7 +167,7 @@ protected slots:
     /// slot connected to signal RosegardenDocument::setModified(bool)
     void updateWindowTitle(bool m = false);
 
-protected:
+private:
 
     /// virtual function inherited from the base class, this implementation just
     /// calls updateWindowTitle() and avoids a refactoring job, even though
