@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -32,27 +32,27 @@ class ChordXmlHandler : public QXmlDefaultHandler
 {
 public:
 	ChordXmlHandler(Guitar::ChordMap&);
-    virtual ~ChordXmlHandler();
+    ~ChordXmlHandler() override;
     
     /// overloaded handler functions
-    virtual bool startDocument();
-    virtual bool startElement(const QString& namespaceURI,
+    bool startDocument() override;
+    bool startElement(const QString& namespaceURI,
                               const QString& localName,
                               const QString& qName,
-                              const QXmlAttributes& atts);
+                              const QXmlAttributes& atts) override;
 
-    virtual bool endElement(const QString& namespaceURI,
+    bool endElement(const QString& namespaceURI,
                             const QString& localName,
-                            const QString& qName);
+                            const QString& qName) override;
 
-    virtual bool characters(const QString& ch);
+    bool characters(const QString& ch) override;
 
-    virtual bool endDocument ();
+    bool endDocument () override;
 
     /// Return the error string set during the parsing (if any)
-    QString errorString() const { return m_errorString; }
-    bool error(const QXmlParseException& exception);
-    bool fatalError(const QXmlParseException& exception);
+    QString errorString() const override { return m_errorString; }
+    bool error(const QXmlParseException& exception) override;
+    bool fatalError(const QXmlParseException& exception) override;
 
 protected:
 
