@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -44,7 +44,7 @@ MatrixElement::MatrixElement(MatrixScene *scene, Event *event,
     m_scene(scene),
     m_drum(drum),
     m_current(true),
-    m_item(0),
+    m_item(nullptr),
     m_pitchOffset(pitchOffset)
 {
     reconfigure();
@@ -244,7 +244,7 @@ MatrixElement *
 MatrixElement::getMatrixElement(QGraphicsItem *item)
 {
     QVariant v = item->data(MatrixElementData);
-    if (v.isNull()) return 0;
+    if (v.isNull()) return nullptr;
     return (MatrixElement *)v.value<void *>();
 }
 
