@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -39,14 +39,14 @@ class MatrixPainter : public MatrixTool
     friend class MatrixToolBox;
 
 public:
-    virtual void handleLeftButtonPress(const MatrixMouseEvent *);
-    virtual void handleMouseDoubleClick(const MatrixMouseEvent *);
-    virtual void handleMidButtonPress(const MatrixMouseEvent *);
-    virtual FollowMode handleMouseMove(const MatrixMouseEvent *);
-    virtual void handleMouseRelease(const MatrixMouseEvent *);
+    void handleLeftButtonPress(const MatrixMouseEvent *) override;
+    void handleMouseDoubleClick(const MatrixMouseEvent *) override;
+    void handleMidButtonPress(const MatrixMouseEvent *) override;
+    FollowMode handleMouseMove(const MatrixMouseEvent *) override;
+    void handleMouseRelease(const MatrixMouseEvent *) override;
 
-    virtual void ready();
-    virtual void stow();
+    void ready() override;
+    void stow() override;
 
     static QString ToolName();
 
@@ -55,7 +55,7 @@ public slots:
      * Respond to an event being deleted -- it may be the one the tool
      * is remembering as the current event.
      */
-    virtual void handleEventRemoved(Event *event);
+    void handleEventRemoved(Event *event) override;
 
 protected slots:
     void slotMatrixScrolled(int x, int y); //!!! do we need this? probably not
