@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -41,12 +41,12 @@ class MatrixToolBox : public BaseToolBox
 
 public:
     MatrixToolBox(MatrixWidget *parent);
-    virtual ~MatrixToolBox();
+    ~MatrixToolBox() override;
 
     void setScene(MatrixScene *scene);
 
 protected:
-    virtual BaseTool *createTool(QString toolName);
+    BaseTool *createTool(QString toolName) override;
     MatrixWidget *m_widget;
     MatrixScene *m_scene;
 };
