@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -45,7 +45,7 @@ public:
                   const Clef &clef = Clef::DefaultClef,
                   const Key &key = Key::DefaultKey);
 
-    virtual ~NotationChord() { }
+    ~NotationChord() override { }
 
     virtual int getHighestNoteHeight() const {
         return getHeight(getHighestNote());
