@@ -1110,7 +1110,7 @@ NotationStaff::renderSingleElement(ViewElementList::iterator &vli,
                                     device->getControlParameters().begin();
                                 i != device->getControlParameters().end(); ++i) {
                             if (i->getType() == Controller::EventType &&
-                                    i->getControllerValue() == controlNumber) {
+                                    i->getControllerNumber() == controlNumber) {
                                 if (i->getName() == "Sustain" ||
                                         strtoqstr(i->getName()) == tr("Sustain")) {
                                     isSustain = true;
@@ -1185,8 +1185,8 @@ NotationStaff::renderSingleElement(ViewElementList::iterator &vli,
         }
 
     } catch (...) {
-        RG_WARNING << "Event lacks the proper properties: ";
-        elt->event()->dump(std::cerr);
+        RG_WARNING << "renderSingleElement(): Event lacks the proper properties:";
+        RG_WARNING << elt->event();
     }
 
     m_notePixmapFactory->setSelected(false);
