@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -32,7 +32,7 @@ NotationTool::NotationTool(QString rcFileName, QString menuName,
                            NotationWidget *widget) :
     BaseTool(menuName, widget),
     m_widget(widget),
-    m_scene(0),
+    m_scene(nullptr),
     m_rcFileName(rcFileName)
 {
 }
@@ -79,10 +79,10 @@ NotationTool::handleMouseRelease(const NotationMouseEvent *) { }
 void
 NotationTool::handleMouseDoubleClick(const NotationMouseEvent *) { }
 
-NotationTool::FollowMode
+FollowMode
 NotationTool::handleMouseMove(const NotationMouseEvent *)
 {
-    return NoFollow;
+    return NO_FOLLOW;
 }
 
 void
@@ -103,15 +103,15 @@ NotationTool::invokeInParentView(QString actionName)
 QAction *
 NotationTool::findActionInParentView(QString actionName)
 {
-    if (!m_widget) return 0;
+    if (!m_widget) return nullptr;
     QWidget *w = m_widget;
-    ActionFileClient *c = 0;
+    ActionFileClient *c = nullptr;
     while (w && !(c = dynamic_cast<ActionFileClient *>(w))) {
         w = w->parentWidget();
     }
     if (!c) {
         RG_WARNING << "NotationTool::findActionInParentView: Can't find ActionFileClient in parent widget hierarchy";
-        return 0;
+        return nullptr;
     }
     QAction *a = c->findAction(actionName);
     return a;
@@ -124,7 +124,7 @@ NotationTool::createMenu()
 
     if (!createMenusAndToolbars(m_rcFileName)) {
         RG_WARNING << "NotationTool::createMenu(" << m_rcFileName << "): menu creation failed";
-        m_menu = 0;
+        m_menu = nullptr;
         return;
     }
 
