@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -38,14 +38,14 @@ namespace Rosegarden
 NotationToolBox::NotationToolBox(NotationWidget *parent) :
     BaseToolBox(parent),
     m_widget(parent),
-    m_scene(0)
+    m_scene(nullptr)
 {
 }
 
 BaseTool *
 NotationToolBox::createTool(QString toolName)
 {
-    NotationTool *tool = 0;
+    NotationTool *tool = nullptr;
 
     QString toolNamelc = toolName.toLower();
     
@@ -82,9 +82,9 @@ NotationToolBox::createTool(QString toolName)
         tool = new NoteRestInserter(m_widget);
 
     else {
-        QMessageBox::critical(0, tr("Rosegarden"), QString("NotationToolBox::createTool : unrecognised toolname %1 (%2)")
+        QMessageBox::critical(nullptr, tr("Rosegarden"), QString("NotationToolBox::createTool : unrecognised toolname %1 (%2)")
                            .arg(toolName).arg(toolNamelc));
-        return 0;
+        return nullptr;
     }
 
     m_tools.insert(toolName, tool);
