@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -15,6 +15,7 @@
     COPYING included with this distribution for more information.
 */
 
+#define RG_MODULE_STRING "[NoteFont]"
 
 #include "NoteFont.h"
 #include "misc/Debug.h"
@@ -38,10 +39,10 @@
 namespace Rosegarden
 {
 
-NoteFont::FontPixmapMap *NoteFont::m_fontPixmapMap = 0;
+NoteFont::FontPixmapMap *NoteFont::m_fontPixmapMap = nullptr;
 
-NoteFont::DrawRepMap *NoteFont::m_drawRepMap = 0;
-QPixmap *NoteFont::m_blankPixmap = 0;
+NoteFont::DrawRepMap *NoteFont::m_drawRepMap = nullptr;
+QPixmap *NoteFont::m_blankPixmap = nullptr;
 
 
 NoteFont::NoteFont(QString fontName, int size) :
@@ -67,11 +68,11 @@ NoteFont::NoteFont(QString fontName, int size) :
 
     // Create the global font map and blank pixmap if necessary
 
-    if (m_fontPixmapMap == 0) {
+    if (m_fontPixmapMap == nullptr) {
         m_fontPixmapMap = new FontPixmapMap();
     }
 
-    if (m_blankPixmap == 0) {
+    if (m_blankPixmap == nullptr) {
         m_blankPixmap = new QPixmap(10, 10);
         m_blankPixmap->fill(Qt::transparent);
     }
@@ -154,7 +155,7 @@ NoteFont::lookup(CharName charName, bool inverted, QPixmap *&pixmap) const
         }
         return true;
     }
-    pixmap = 0;
+    pixmap = nullptr;
     return false;
 }
 
@@ -175,7 +176,7 @@ NoteFont::add
         if (inverted) {
             (*m_map)[charName] = PixmapPair(0, pixmap);
         } else {
-            (*m_map)[charName] = PixmapPair(pixmap, 0);
+            (*m_map)[charName] = PixmapPair(pixmap, nullptr);
         }
     }
 }
@@ -194,12 +195,17 @@ NoteFont::lookupDrawRep(QPixmap *pixmap) const
 
         QImage image = pixmap->toImage();
         if (image.isNull())
-            return 0;
+            return nullptr;
 
+#if 0
+// ??? Removing since this does nothing other than trigger a compiler warning.
         if (image.depth() > 1) {
 //            image = image.convertDepth(1, Qt::MonoOnly | Qt::ThresholdDither);
+              // ??? Since the return is ignored, this does nothing other
+              //     than trigger a compiler warning.
               image.convertToFormat(QImage::Format_Mono, Qt::ThresholdDither);
         }
+#endif
 
         NoteCharacterDrawRep *a = new NoteCharacterDrawRep();
 
@@ -242,7 +248,7 @@ NoteFont::lookupDrawRep(QPixmap *pixmap) const
 bool
 NoteFont::getPixmap(CharName charName, QPixmap &pixmap, bool inverted) const
 {
-    QPixmap *found = 0;
+    QPixmap *found = nullptr;
     bool ok = lookup(charName, inverted, found);
     if (ok) {
         if (found) {
@@ -296,7 +302,7 @@ NoteFont::getPixmap(CharName charName, QPixmap &pixmap, bool inverted) const
             std::cerr << "NoteFont::getPixmap: Warning: No pixmap, code, or glyph for character \""
                       << charName << "\"" << (inverted ? " (inverted)" : "")
                       << " in font \"" << m_fontMap.getName() << "\"" << std::endl;
-            add(charName, inverted, 0);
+            add(charName, inverted, nullptr);
             pixmap = *m_blankPixmap;
             return false;
         }
@@ -319,7 +325,7 @@ NoteFont::getPixmap(CharName charName, QPixmap &pixmap, bool inverted) const
                       << charName << "\"" << (inverted ? " (inverted)" : "")
                       << " in font \"" << m_fontMap.getName() << "\"" << std::endl;
 
-            add(charName, inverted, 0);
+            add(charName, inverted, nullptr);
             pixmap = *m_blankPixmap;
             return false;
         }
@@ -339,13 +345,13 @@ NoteFont::getPixmap(CharName charName, QPixmap &pixmap, bool inverted) const
             pixmap = *found;
             return true;
         } else {
-            add(charName, inverted, 0);
+            add(charName, inverted, nullptr);
             pixmap = *m_blankPixmap;
             return false;
         }
     }
 
-    add(charName, inverted, 0);
+    add(charName, inverted, nullptr);
     pixmap = *m_blankPixmap;
     return false;
 }
@@ -356,7 +362,7 @@ NoteFont::getColouredPixmap(CharName baseCharName, QPixmap &pixmap,
 {
     CharName charName(getNameWithColour(baseCharName, hue));
 
-    QPixmap *found = 0;
+    QPixmap *found = nullptr;
     bool ok = lookup(charName, inverted, found);
     if (ok) {
         if (found) {
@@ -372,7 +378,7 @@ NoteFont::getColouredPixmap(CharName baseCharName, QPixmap &pixmap,
     ok = getPixmap(baseCharName, basePixmap, inverted);
 
     if (!ok) {
-        add(charName, inverted, 0);
+        add(charName, inverted, nullptr);
         pixmap = *m_blankPixmap;
         return false;
     }
@@ -390,7 +396,7 @@ NoteFont::getShadedPixmap(CharName baseCharName, QPixmap &pixmap,
 {
     CharName charName(getNameShaded(baseCharName));
 
-    QPixmap *found = 0;
+    QPixmap *found = nullptr;
     bool ok = lookup(charName, inverted, found);
     if (ok) {
         if (found) {
@@ -406,7 +412,7 @@ NoteFont::getShadedPixmap(CharName baseCharName, QPixmap &pixmap,
     ok = getPixmap(baseCharName, basePixmap, inverted);
 
     if (!ok) {
-        add(charName, inverted, 0);
+        add(charName, inverted, nullptr);
         pixmap = *m_blankPixmap;
         return false;
     }
@@ -497,16 +503,16 @@ NoteFont::getCharacter(CharName charName,
     if (type == Screen) {
         character = NoteCharacter(pixmap,
                                   getHotspot(charName, inverted),
-                                  0);
+                                  nullptr);
     } else {
 
         // Get the pointer direct from cache (depends on earlier call
         // to getPixmap to put it in the cache if available)
 
-        QPixmap *pmapptr = 0;
+        QPixmap *pmapptr = nullptr;
         bool found = lookup(charName, inverted, pmapptr);
 
-        NoteCharacterDrawRep *rep = 0;
+        NoteCharacterDrawRep *rep = nullptr;
         if (found && pmapptr)
             rep = lookupDrawRep(pmapptr);
 
@@ -545,18 +551,18 @@ NoteFont::getCharacterColoured(CharName charName,
 
         character = NoteCharacter(pixmap,
                                   getHotspot(charName, inverted),
-                                  0);
+                                  nullptr);
 
     } else {
 
         // Get the pointer direct from cache (depends on earlier call
         // to getPixmap to put it in the cache if available)
 
-        QPixmap *pmapptr = 0;
+        QPixmap *pmapptr = nullptr;
         CharName cCharName(getNameWithColour(charName, hue));
         bool found = lookup(cCharName, inverted, pmapptr);
 
-        NoteCharacterDrawRep *rep = 0;
+        NoteCharacterDrawRep *rep = nullptr;
         if (found && pmapptr)
             rep = lookupDrawRep(pmapptr);
 
