@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -45,7 +45,7 @@ public:
     typedef Exception MappingFileReadFailed;
 
     NoteFontMap(QString name); // load and parse the XML mapping file
-    ~NoteFontMap();
+    ~NoteFontMap() override;
 
     /**
      * ok() returns false if the file read succeeded but the font
@@ -88,14 +88,14 @@ public:
 
     // Xml handler methods:
 
-    virtual bool startElement
+    bool startElement
     (const QString& namespaceURI, const QString& localName,
-     const QString& qName, const QXmlAttributes& atts);
+     const QString& qName, const QXmlAttributes& atts) override;
 
-    virtual bool characters(const QString &);
+    bool characters(const QString &) override;
 
-    bool error(const QXmlParseException& exception);
-    bool fatalError(const QXmlParseException& exception);
+    bool error(const QXmlParseException& exception) override;
+    bool fatalError(const QXmlParseException& exception) override;
 
     void dump() const;
 
