@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     This file is Copyright 2007-2009
         Yves Guillemot      <yc.guillemot@wanadoo.fr> 
@@ -70,7 +70,7 @@ public:
      */
     StaffHeader(HeadersGroup *group, TrackId trackId, int height, int ypos);
 
-    ~StaffHeader();
+    ~StaffHeader() override;
 
     /**
      * Examine staff at x position and gather data needed to draw
@@ -179,19 +179,19 @@ public:
 
 
 /** SegmentObserver methods **/
-    virtual void eventAdded(const Segment *, Event *);
+    void eventAdded(const Segment *, Event *) override;
 
-    virtual void eventRemoved(const Segment *, Event *);
+    void eventRemoved(const Segment *, Event *) override;
 
-    virtual void appearanceChanged(const Segment *);
+    void appearanceChanged(const Segment *) override;
 
-    virtual void startChanged(const Segment *, timeT);
+    void startChanged(const Segment *, timeT) override;
 
-    virtual void endMarkerTimeChanged(const Segment *, bool /*shorten*/);
+    void endMarkerTimeChanged(const Segment *, bool /*shorten*/) override;
 
-    virtual void transposeChanged(const Segment *, int);
+    void transposeChanged(const Segment *, int) override;
 
-    virtual void segmentDeleted(const Segment *);
+    void segmentDeleted(const Segment *) override;
 
 
 
@@ -201,11 +201,11 @@ signals :
     void staffModified();
 
 protected :
-    virtual void paintEvent(QPaintEvent *);
+    void paintEvent(QPaintEvent *) override;
 //    virtual bool event(QEvent *event);
-    virtual void enterEvent(QEvent *event);
-    virtual void mouseMoveEvent(QMouseEvent *event);
-    virtual void leaveEvent(QEvent *event);
+    void enterEvent(QEvent *event) override;
+    void mouseMoveEvent(QMouseEvent *event) override;
+    void leaveEvent(QEvent *event) override;
 //    virtual void mousePressEvent(QMouseEvent *event);
 
     /**
