@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -28,10 +28,10 @@ class SystemFontQt : public SystemFont
 {
 public:
     SystemFontQt(QFont &font) : m_font(font) { }
-    virtual ~SystemFontQt() { }
+    ~SystemFontQt() override { }
 
-    virtual QPixmap renderChar(CharName charName, int glyph, int code,
-			       Strategy strategy, bool &success);
+    QPixmap renderChar(CharName charName, int glyph, int code,
+			       Strategy strategy, bool &success) override;
 
 private:
     QFont m_font;
