@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -47,13 +47,17 @@ class AudioInstrumentParameterPanel : public InstrumentParameterPanel
 {
     Q_OBJECT
 public:
-    AudioInstrumentParameterPanel(RosegardenDocument* doc, QWidget* parent);
+    AudioInstrumentParameterPanel(QWidget* parent);
 
     virtual void setupForInstrument(Instrument*);
 
-    // Set the audio meter to a given level for a maximum of
-    // two channels.
-    //
+    /// Set the audio meter to a given level for a maximum of two channels.
+    /**
+     * ??? Recommend moving RMVW::updateMeters() and updateMonitorMeters()
+     *     into here.  AIPP should be responsible for sampling the levels in
+     *     SequencerDataBlock and displaying them.  This way AIPP is
+     *     autonomous and RMVW and IPB need not care.
+     */
     void setAudioMeter(float dBleft, float dBright,
                        float recDBleft, float recDBright);
 
@@ -73,18 +77,14 @@ public slots:
     // From the parameter box clicks
     void slotSetPan(float pan);
 
-    // From Plugin dialog
-    //
+    // From RosegardenMainWindow.
     void slotPluginSelected(InstrumentId id, int index, int plugin);
     void slotPluginBypassed(InstrumentId id, int pluginIndex, bool bp);
 
     void slotSynthButtonClicked();
+    /// Editor button.
     void slotSynthGUIButtonClicked();
 
-signals:
-    void selectPlugin(QWidget *, InstrumentId, int index);
-    void showPluginGUI(InstrumentId, int index);
-
 protected:
     //--------------- Data members ---------------------------------
 
@@ -93,8 +93,10 @@ protected:
 private slots:
     void slotAliasChanged();
 
-    /// Handle InstrumentStaticSignals::changed()
-    void slotInstrumentChanged(Instrument *);
+    /// Called when a new document is loaded.
+    void slotDocumentLoaded(RosegardenDocument *);
+    /// Called when the document is modified in some way.
+    void slotDocumentModified(bool);
 
     /// Connected to InstrumentStaticSignals::controlChange().
     void slotControlChange(Instrument *instrument, int cc);
