@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     This file Copyright 2006 Martin Shepherd <mcs@astro.caltech.edu>.
 
@@ -45,14 +45,14 @@ public:
 
     // Create the parameter display area.
 
-    RosegardenParameterArea(QWidget *parent = 0);
+    RosegardenParameterArea(QWidget *parent = nullptr);
 
     // Add a rosegarden parameter box to the list that are to be displayed.
 
     void addRosegardenParameterBox(RosegardenParameterBox *b);
 
 protected:
-    bool eventFilter(QObject *object, QEvent *event);
+    bool eventFilter(QObject *object, QEvent *event) override;
 
 private:
     // The list of parameter box widgets that are being displayed by this
