@@ -75,7 +75,7 @@ namespace Rosegarden
 TrackParameterBox::TrackParameterBox(QWidget *parent) :
     RosegardenParameterBox(tr("Track Parameters"), parent),
     m_doc(nullptr),
-    m_selectedTrackId(NO_TRACK),
+    m_selectedTrackId(NoTrack),
     m_lastInstrumentType(Instrument::InvalidInstrument)
 {
     setObjectName("Track Parameter Box");
@@ -425,8 +425,8 @@ TrackParameterBox::TrackParameterBox(QWidget *parent) :
     // Connections
 
     connect(RosegardenMainWindow::self(),
-                &RosegardenMainWindow::documentChanged,
-            this, &TrackParameterBox::slotNewDocument);
+                &RosegardenMainWindow::documentLoaded,
+            this, &TrackParameterBox::slotDocumentLoaded);
 
     // Layout
 
@@ -943,7 +943,7 @@ TrackParameterBox::slotBracketTypeChanged(int index)
 Track *
 TrackParameterBox::getTrack()
 {
-    if (m_selectedTrackId == NO_TRACK)
+    if (m_selectedTrackId == NoTrack)
         return nullptr;
 
     if (!m_doc)
@@ -953,7 +953,7 @@ TrackParameterBox::getTrack()
 
     // If the track is gone, bail.
     if (!comp.haveTrack(m_selectedTrackId)) {
-        m_selectedTrackId = NO_TRACK;
+        m_selectedTrackId = NoTrack;
         return nullptr;
     }
 
@@ -1053,7 +1053,7 @@ TrackParameterBox::updateInstrument(const Instrument *instrument)
 
         if (loopInstrument.getType() == Instrument::SoftSynth) {
 
-            instrumentName.replace(QObject::tr("Synth plugin"), "");
+            instrumentName.replace(tr("Synth plugin"), "");
 
             programName = "";
 
@@ -1218,7 +1218,7 @@ TrackParameterBox::updateWidgets2()
     m_archive->setChecked(track->isArchived());
 
     // If the current Instrument is an Audio Instrument...
-    if (instrument->getInstrumentType() == Instrument::Audio) {
+    if (instrument->getType() == Instrument::Audio) {
 
         // Hide irrelevant portions.
 
@@ -1332,7 +1332,7 @@ TrackParameterBox::updateWidgets2()
 }
 
 void
-TrackParameterBox::slotNewDocument(RosegardenDocument *doc)
+TrackParameterBox::slotDocumentLoaded(RosegardenDocument *doc)
 {
     connect(doc, &RosegardenDocument::documentModified,
             this, &TrackParameterBox::slotDocumentModified);
