@@ -88,7 +88,7 @@ signals:
 
 private slots:
     /// Called when a new document is loaded.
-    void slotNewDocument(RosegardenDocument *);
+    void slotDocumentLoaded(RosegardenDocument *);
     /// Called when the document is modified in some way.
     void slotDocumentModified(bool);
 
