@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -111,7 +111,7 @@ void PlayListView::mouseMoveEvent(QMouseEvent *event){
      if (!(event->buttons() & Qt::LeftButton)) return;
     
     // if no item selected, return (else it would crash)
-     if (currentItem() == NULL) return;
+     if (currentItem() == nullptr) return;
     
     QDrag *drag = new QDrag(this);
     QMimeData *mimeData = new QMimeData;
