@@ -116,8 +116,19 @@ TrackEditor::TrackEditor(RosegardenDocument *doc,
 void
 TrackEditor::init(RosegardenMainViewWidget *mainViewWidget)
 {
-    QFontMetrics fontMetrics(QApplication::font(this));
-    m_trackCellHeight = std::min(fontMetrics.height() + 9, 24);
+    QSettings settings;
+    settings.beginGroup(GeneralOptionsConfigGroup);
+    int trackSize = settings.value("track_size", 0).toInt();
+    // Write it back out so we can find it.
+    settings.setValue("track_size", trackSize);
+
+    int sizeFactor = 100;  // 0: small
+    if (trackSize == 1)  // 1: medium
+        sizeFactor = 125;
+    else if (trackSize == 2)  // 2: large
+        sizeFactor = 150;
+
+    m_trackCellHeight = 24 * sizeFactor / 100;
 
     QGridLayout *grid = new QGridLayout(this);
     grid->setMargin(0);
@@ -193,16 +204,14 @@ TrackEditor::init(RosegardenMainViewWidget *mainViewWidget)
     m_trackButtonScroll->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     grid->addWidget(m_trackButtonScroll, 3, 0);
 
-    const int trackLabelWidth = 200;
     const int canvasHeight = m_trackCellHeight *
                        std::max(40u, m_doc->getComposition().getNbTracks());
 
     m_trackButtons = new TrackButtons(m_doc,
                                       m_trackCellHeight,
-                                      trackLabelWidth,
                                       m_showTrackLabels,
-                                      canvasHeight,
-                                      m_trackButtonScroll);
+                                      canvasHeight,  // overall height
+                                      m_trackButtonScroll);  // parent
 
     m_trackButtonScroll->setWidget(m_trackButtons);
 
