@@ -33,6 +33,7 @@ namespace Rosegarden
 
 TrackLabel::TrackLabel(TrackId id,
                        int position,
+                       int trackHeight,
                        QWidget *parent) :
         QLabel(parent),
         m_mode(ShowTrack),
@@ -41,14 +42,15 @@ TrackLabel::TrackLabel(TrackId id,
         m_position(position)
 {
     setObjectName("TrackLabel");
-    
+
     QFont font;
-    font.setPointSize(font.pointSize() * 95 / 100);
-    if (font.pixelSize() > 14)
-        font.setPixelSize(14);
-    font.setBold(false);
+    font.setPixelSize(trackHeight * 85 / 100);
     setFont(font);
 
+    QFontMetrics fontMetrics(font);
+    setFixedWidth(fontMetrics.width("XXXXXXXXXXXXXXXXXX"));
+    setFixedHeight(trackHeight);
+
     setFrameShape(QFrame::NoFrame);
 
     m_pressTimer = new QTimer(this);
