@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -32,7 +32,7 @@ namespace Rosegarden
 class TrackVUMeter: public VUMeter
 {
 public:
-     TrackVUMeter(QWidget *parent = 0,
+     TrackVUMeter(QWidget *parent = nullptr,
                   VUMeterType type = Plain,
                   int width = 0,
                   int height = 0,
@@ -41,8 +41,8 @@ public:
     int getPosition() const { return m_position; }
 
 protected:
-    virtual void meterStart();
-    virtual void meterStop();
+    void meterStart() override;
+    void meterStop() override;
 
 private:
     int m_position;
