@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -37,7 +37,6 @@
 #include "misc/ConfigGroups.h"
 #include "gui/dialogs/TimeDialog.h"
 #include "gui/general/MidiPitchLabel.h"
-#include "gui/general/IconLoader.h"
 #include "gui/widgets/TmpStatusMsg.h"
 #include "gui/dialogs/AboutDialog.h"
 #include "document/Command.h"
@@ -116,17 +115,17 @@ TriggerSegmentManager::TriggerSegmentManager(QWidget *parent,
 
 
     // Whether accepted or rejected, we always just want to call slotClose()
-    connect(btnBox, SIGNAL(accepted()), this, SLOT(slotClose()));
-    connect(btnBox, SIGNAL(rejected()), this, SLOT(slotClose()));
+    connect(btnBox, &QDialogButtonBox::accepted, this, &TriggerSegmentManager::slotClose);
+    connect(btnBox, &QDialogButtonBox::rejected, this, &TriggerSegmentManager::slotClose);
     
-    connect(m_addButton, SIGNAL(released()),
-            SLOT(slotAdd()));
+    connect(m_addButton, &QAbstractButton::released,
+            this, &TriggerSegmentManager::slotAdd);
 
-    connect(m_deleteButton, SIGNAL(released()),
-            SLOT(slotDelete()));
+    connect(m_deleteButton, &QAbstractButton::released,
+            this, &TriggerSegmentManager::slotDelete);
 
-    connect(m_deleteAllButton, SIGNAL(released()),
-            SLOT(slotDeleteAll()));
+    connect(m_deleteAllButton, &QAbstractButton::released,
+            this, &TriggerSegmentManager::slotDeleteAll);
 
     setupActions();
 
@@ -135,11 +134,11 @@ TriggerSegmentManager::TriggerSegmentManager(QWidget *parent,
     connect(CommandHistory::getInstance(), SIGNAL(commandExecuted()),
             this, SLOT(slotUpdate()));
 
-    connect(m_listView, SIGNAL(itemDoubleClicked(QTreeWidgetItem *, int)),
-            SLOT(slotEdit(QTreeWidgetItem *)));
+    connect(m_listView, &QTreeWidget::itemDoubleClicked,
+            this, &TriggerSegmentManager::slotEdit);
 
-    connect(m_listView, SIGNAL(itemPressed(QTreeWidgetItem *, int)),
-            this, SLOT(slotItemClicked(QTreeWidgetItem *)));
+    connect(m_listView, &QTreeWidget::itemPressed,
+            this, &TriggerSegmentManager::slotItemClicked);
 
     // Highlight all columns - enable extended selection mode
     //
@@ -364,7 +363,7 @@ TriggerSegmentManager::slotClose()
 
 //     if (m_doc)
 //         CommandHistory::getInstance()->detachView(actionCollection());    //&&&
-    m_doc = 0;
+    m_doc = nullptr;
 
     close();
 }
