@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -50,6 +50,6 @@ CompositionColourCache* CompositionColourCache::getInstance()
     return m_instance;
 }
 
-CompositionColourCache* CompositionColourCache::m_instance = 0;
+CompositionColourCache* CompositionColourCache::m_instance = nullptr;
 
 }
