@@ -129,7 +129,7 @@ void SegmentResizer::resizeAudioSegment(
 {
     try {
         m_doc->getAudioFileManager().testAudioPath();
-    } catch (AudioFileManager::BadAudioPathException) {
+    } catch (const AudioFileManager::BadAudioPathException &) {
         if (QMessageBox::warning(nullptr, tr("Warning"), //tr("Set audio file path"),
                 tr("The audio file path does not exist or is not writable.\nYou must set the audio file path to a valid directory in Document Properties before rescaling an audio file.\nWould you like to set it now?"),
                 QMessageBox::Yes | QMessageBox::Cancel, QMessageBox::Cancel) ==
@@ -304,7 +304,7 @@ int SegmentResizer::mouseMoveEvent(QMouseEvent *e)
     setContextHelp2(e->modifiers());
 
     if (!getChangingSegment()) {
-        return RosegardenScrollView::NoFollow;
+        return NO_FOLLOW;
     }
 
     Segment* segment = getChangingSegment()->getSegment();
@@ -317,7 +317,7 @@ int SegmentResizer::mouseMoveEvent(QMouseEvent *e)
             setChangingSegment(nullptr);
             QMessageBox::information(m_canvas,
                     tr("You can't yet resize an audio segment!"));
-            return RosegardenScrollView::NoFollow;
+            return NO_FOLLOW;
         }
     */
 
@@ -390,7 +390,7 @@ int SegmentResizer::mouseMoveEvent(QMouseEvent *e)
     // Redraw the canvas
     m_canvas->slotAllNeedRefresh(getChangingSegment()->rect() | oldRect);
 
-    return RosegardenScrollView::FollowHorizontal;
+    return FOLLOW_HORIZONTAL;
 }
 
 void SegmentResizer::keyPressEvent(QKeyEvent *e)
