@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -60,7 +60,7 @@ SegmentSelector::SegmentSelector(CompositionView *c, RosegardenDocument *d) :
     m_segmentQuickCopyDone(false),
     m_selectionMoveStarted(false),
     m_changeMade(false),
-    m_dispatchTool(0)
+    m_dispatchTool(nullptr)
 {
     //RG_DEBUG << "SegmentSelector()";
 }
@@ -135,6 +135,21 @@ SegmentSelector::mousePressEvent(QMouseEvent *e)
     // ??? Should we split this into a midPress(e) and a leftPress(e)?
     //     Might improve readability a little.
 
+    // *** Resize
+
+    // if the Segment was clicked near the edge, resize
+    if (item  &&  isNearEdge(item->rect(), pos)) {
+        SegmentResizer *segmentResizer = dynamic_cast<SegmentResizer *>(
+                m_canvas->getToolBox()->getTool(SegmentResizer::ToolName()));
+
+        // Turn it over to SegmentResizer.
+        m_dispatchTool = segmentResizer;
+        m_dispatchTool->ready(); // set mouse cursor
+        m_dispatchTool->mousePressEvent(e);
+
+        return;
+    }
+
     // *** Adjust Selection
 
     // Shift key adds to selection.
@@ -167,23 +182,6 @@ SegmentSelector::mousePressEvent(QMouseEvent *e)
     // if a segment was clicked
     if (item) {
 
-        // * Resize
-
-        // if only one segment is selected and clicked near the edge, resize
-        if (m_canvas->getModel()->getSelectedSegments().size() == 1  &&
-            isNearEdge(item->rect(), pos)) {
-
-            SegmentResizer *segmentResizer = dynamic_cast<SegmentResizer *>(
-                m_canvas->getToolBox()->getTool(SegmentResizer::ToolName()));
-
-            // Turn it over to SegmentResizer.
-            m_dispatchTool = segmentResizer;
-            m_dispatchTool->ready(); // set mouse cursor
-            m_dispatchTool->mousePressEvent(e);
-
-            return;
-        }
-
         // * Move
 
         // We don't dispatch to SegmentMover because SegmentMover
@@ -264,7 +262,7 @@ SegmentSelector::mouseReleaseEvent(QMouseEvent *e)
         // Forget about the tool.
         // Note that this is not a memory leak.  There is only one instance
         // of each tool stored in BaseToolBox::m_tools.
-        m_dispatchTool = 0;
+        m_dispatchTool = nullptr;
 
         // Back to this tool.
         ready();
@@ -296,7 +294,7 @@ SegmentSelector::mouseReleaseEvent(QMouseEvent *e)
 
         if (m_changeMade) {
 
-            MacroCommand *macroCommand = 0;
+            MacroCommand *macroCommand = nullptr;
 
             CompositionModelImpl::ChangingSegmentSet &changingSegments =
                     m_canvas->getModel()->getChangingSegments();
@@ -326,7 +324,7 @@ SegmentSelector::mouseReleaseEvent(QMouseEvent *e)
                      ++it) {
                     Segment *segment = *it;
 
-                    Command *command = 0;
+                    Command *command = nullptr;
 
                     if (m_segmentCopyingAsLink) {
                         command = new SegmentQuickLinkCommand(segment);
@@ -425,7 +423,7 @@ SegmentSelector::mouseMoveEvent(QMouseEvent *e)
     //       QWidget::setMouseTracking().
     if (e->buttons() == Qt::NoButton) {
         setContextHelpFor(pos, e->modifiers());
-        return RosegardenScrollView::NoFollow;
+        return NO_FOLLOW;
     }
 
     // If another tool has taken over, delegate.
@@ -435,22 +433,21 @@ SegmentSelector::mouseMoveEvent(QMouseEvent *e)
     // We only handle the left button.  The middle button is handled by
     // the dispatch tool (segment pencil) or ignored.
     if (e->buttons() != Qt::LeftButton)
-        return RosegardenScrollView::NoFollow;
+        return NO_FOLLOW;
 
     // If we aren't moving anything, rubber band.
     if (!getChangingSegment()) {
         m_canvas->drawSelectionRectPos2(pos);
         m_canvas->getModel()->selectionHasChanged();
 
-        return RosegardenScrollView::FollowHorizontal |
-               RosegardenScrollView::FollowVertical;
+        return FOLLOW_HORIZONTAL | FOLLOW_VERTICAL;
     }
 
     // Moving
 
     // If the segment that was clicked on isn't selected, bail.
     if (!m_canvas->getModel()->isSelected(getChangingSegment()->getSegment()))
-        return RosegardenScrollView::NoFollow;
+        return NO_FOLLOW;
 
     const int dx = pos.x() - m_clickPoint.x();
     const int dy = pos.y() - m_clickPoint.y();
@@ -461,7 +458,7 @@ SegmentSelector::mouseMoveEvent(QMouseEvent *e)
     if (!m_passedInertiaEdge  &&
         abs(dx) < inertiaDistance  &&
         abs(dy) < inertiaDistance) {
-        return RosegardenScrollView::NoFollow;
+        return NO_FOLLOW;
     }
 
     m_passedInertiaEdge = true;
@@ -617,8 +614,7 @@ SegmentSelector::mouseMoveEvent(QMouseEvent *e)
 
     m_canvas->update();
 
-    return RosegardenScrollView::FollowHorizontal |
-           RosegardenScrollView::FollowVertical;
+    return FOLLOW_HORIZONTAL | FOLLOW_VERTICAL;
 }
 
 void SegmentSelector::keyPressEvent(QKeyEvent *e)
