@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -46,24 +46,24 @@ public:
     static QString ToolName();
 
     SegmentSelector(CompositionView *, RosegardenDocument *);
-    virtual ~SegmentSelector();
+    ~SegmentSelector() override;
 
     /// Called when this tool becomes the active tool.
-    virtual void ready();
-    virtual void stow()  { }
+    void ready() override;
+    void stow()  override { }
 
-    virtual void mousePressEvent(QMouseEvent *);
-    virtual int mouseMoveEvent(QMouseEvent *);
-    virtual void mouseReleaseEvent(QMouseEvent *);
-    virtual void keyPressEvent(QKeyEvent *);
-    virtual void keyReleaseEvent(QKeyEvent *);
+    void mousePressEvent(QMouseEvent *) override;
+    int mouseMoveEvent(QMouseEvent *) override;
+    void mouseReleaseEvent(QMouseEvent *) override;
+    void keyPressEvent(QKeyEvent *) override;
+    void keyReleaseEvent(QKeyEvent *) override;
 
     // Unused
     //bool isSegmentAdding() const { return m_segmentAddMode; }
     //bool isSegmentCopying() const { return m_segmentCopyMode; }
 
 private:
-    void setContextHelpFor(QPoint pos, Qt::KeyboardModifiers modifiers = 0);
+    void setContextHelpFor(QPoint pos, Qt::KeyboardModifiers modifiers = nullptr);
 
     //--------------- Data members ---------------------------------
 
