@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -39,10 +39,10 @@ class SegmentToolBox : public BaseToolBox
 public:
     SegmentToolBox(CompositionView* parent, RosegardenDocument*);
 
-    virtual SegmentTool* getTool(QString toolName);
+    SegmentTool* getTool(QString toolName) override;
     
 protected:
-    virtual SegmentTool* createTool(QString toolName);
+    SegmentTool* createTool(QString toolName) override;
 
     //--------------- Data members ---------------------------------
 
