@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -64,18 +64,18 @@ class TempoView : public ListEditView, public CompositionObserver
 
 public:
     TempoView(RosegardenDocument *doc, QWidget *parent, EditTempoController *editTempoController, timeT openTime);
-    virtual ~TempoView();
+    ~TempoView() override;
 
     virtual bool applyLayout(int staffNo = -1);
 
-    virtual void refreshSegment(Segment *segment,
+    void refreshSegment(Segment *segment,
                                 timeT startTime = 0,
-                                timeT endTime = 0);
+                                timeT endTime = 0) override;
 
-    virtual void updateView();
+    void updateView() override;
 
     virtual void setupActions();
-    virtual void initStatusBar();
+    void initStatusBar() override;
     virtual QSize getViewSize(); 
     virtual void setViewSize(QSize);
 
@@ -89,17 +89,17 @@ public:
 
     // Composition Observer callbacks
     //
-    virtual void timeSignatureChanged(const Composition *);
-    virtual void tempoChanged(const Composition *);
+    void timeSignatureChanged(const Composition *) override;
+    void tempoChanged(const Composition *) override;
 
 signals:
     void closing();
 
 public slots:
     // standard slots
-    virtual void slotEditCut();
-    virtual void slotEditCopy();
-    virtual void slotEditPaste();
+    void slotEditCut() override;
+    void slotEditCopy() override;
+    void slotEditPaste() override;
 
     // other edit slots
     void slotEditDelete();
@@ -126,17 +126,17 @@ public slots:
 
 protected slots:
 
-    virtual void slotSaveOptions();
+    void slotSaveOptions() override;
 
 protected:
-    virtual void closeEvent(QCloseEvent *);
+    void closeEvent(QCloseEvent *) override;
 
 private:
-    virtual void readOptions();
+    void readOptions() override;
     void makeInitialSelection(timeT);
     QString makeTimeString(timeT time, int timeMode);
-    virtual Segment *getCurrentSegment();
-    virtual void updateViewCaption();
+    Segment *getCurrentSegment() override;
+    void updateViewCaption() override;
 
     //--------------- Data members ---------------------------------
     EditTempoController *m_editTempoController;
