@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -34,13 +34,13 @@ class ActionCommandRegistry : public CommandRegistry
 
 public:
     ActionCommandRegistry(ActionFileClient *c);
-    virtual ~ActionCommandRegistry();
+    ~ActionCommandRegistry() override;
 
 protected:
     ActionFileClient *m_client;
 
-    virtual void addAction(QString actionName);
-    virtual void invokeCommand(QString actionName);
+    void addAction(QString actionName) override;
+    void invokeCommand(QString actionName) override;
 };
 
 }
