@@ -1,7 +1,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -27,12 +27,12 @@
 namespace Rosegarden
 {
 
-static EditTempoController *s_instance = 0;
+static EditTempoController *s_instance = nullptr;
 
 EditTempoController::EditTempoController(QObject *parent)
     : QObject(parent),
-      m_doc(0),
-      m_composition(0)
+      m_doc(nullptr),
+      m_composition(nullptr)
 {
     s_instance = this;
 }
