@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -48,7 +48,7 @@ public:
                  std::vector<Segment *> segments,
                  QWidget *parent);
 
-    virtual ~EditViewBase();
+    ~EditViewBase() override;
 
     const RosegardenDocument *getDocument() const { return m_doc; }
     RosegardenDocument *getDocument() { return m_doc; }
@@ -92,8 +92,6 @@ signals:
      */
     void toggleSolo(bool);
 
-    void windowActivated();
-
 public slots:
     /**
      * close window
@@ -180,12 +178,10 @@ public slots:
     
 protected:
 
-    virtual void windowActivationChange(bool);
-
     /**
      * @see #setInCtor
      */
-    virtual void closeEvent(QCloseEvent* e);
+    void closeEvent(QCloseEvent* e) override;
     
     /**
      * read general Options again and initialize all variables like the recent file list
@@ -235,6 +231,8 @@ protected:
     int getConfigDialogPageIndex()       { return m_configDialogPageIndex; }
 
     RosegardenDocument* m_doc;
+
+    /// The Segment(s) that are being edited.
     std::vector<Segment *> m_segments;
 
     int m_configDialogPageIndex;
