@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     This file originally from Sonic Visualiser, copyright 2007 Queen
     Mary, University of London.
@@ -77,7 +77,7 @@ public:
 
     FileSource(const FileSource &);
 
-    virtual ~FileSource();
+    ~FileSource() override;
 
     /**
      * Block on a sub-event-loop until the availability of the file or
