@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -17,10 +17,10 @@
 
 
 #include "GUIPalette.h"
-#include <QApplication>
 
-#include "base/Colour.h"
 #include "misc/ConfigGroups.h"
+
+#include <QApplication>
 #include <QSettings>
 #include <QColor>
 
@@ -50,18 +50,6 @@ QColor GUIPalette::getColour(const char* const colourName)
     return color;
 }
 
-Colour GUIPalette::convertColour(const QColor &input)
-{
-    int r, g, b;
-    input.getRgb(&r, &g, &b);
-    return Colour(r, g, b);
-}
-
-QColor GUIPalette::convertColour(const Colour& input)
-{
-    return QColor(input.getRed(), input.getGreen(), input.getBlue());
-}
-
 GUIPalette::GUIPalette()
 {
     m_defaultsMap[ActiveRecordTrack] = QColor(Qt::red);
@@ -340,7 +328,7 @@ const char* const GUIPalette::RecordFaderOutline = "recordfaderoutline";
 
 const char* const GUIPalette::PannerOverlay = "panneroverlay";
 
-GUIPalette* GUIPalette::m_instance = 0;
+GUIPalette* GUIPalette::m_instance = nullptr;
 
 // defines which index in the document's colourmap should be used as the color
 // when creating new audio segments from recordings, or inserting from the
