@@ -22,31 +22,19 @@
 #include <QPixmap>
 #include <QString>
 
-#include <map>
+// Needed because loadPixmap() is called by main().
 #include <rosegardenprivate_export.h>
 
 namespace Rosegarden {
 
-class ROSEGARDENPRIVATE_EXPORT IconLoader
+
+namespace IconLoader
 {
-public:
-    IconLoader() { }
-    virtual ~IconLoader() { }
-
     QIcon load(QString name);
-    QPixmap loadPixmap(QString name);
+    QPixmap ROSEGARDENPRIVATE_EXPORT loadPixmap(QString name);
+}
 
-    // process the given pixmap so as to try to make it visible if the
-    // background is very dark
-    QPixmap invert(QPixmap);
-
-protected:
-    QPixmap loadPixmap(QString dir, QString name);
-    std::map<QString, QPixmap> m_cache;
-};
 
 }
 
 #endif
-
-	
