@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -67,12 +67,12 @@ ListEditView::ListEditView(RosegardenDocument *doc,
     EditViewBase(doc, segments, parent),
     m_viewNumber( -1),
     m_viewLocalPropertyPrefix(makeViewLocalPropertyPrefix()),
-    m_centralFrame(0),
-    m_grid(0),
+    m_centralFrame(nullptr),
+    m_grid(nullptr),
     m_mainCol(cols - 1),
     m_compositionRefreshStatusId(doc->getComposition().getNewRefreshStatusId()),
     m_needUpdate(false),
-    m_pendingPaintEvent(0),
+    m_pendingPaintEvent(nullptr),
     m_havePendingPaintEvent(false),
     m_inCtor(true),
     m_timeSigNotifier(new EditViewTimeSigNotifier(doc))
@@ -167,7 +167,7 @@ ListEditView::paintEvent(QPaintEvent* e)
     */ 
     //!!!    m_inPaintEvent = true;
 
-    RG_DEBUG << "ListEditView::paintEvent";
+    //RG_DEBUG << "paintEvent()";
 
     if (isCompositionModified()) {
 
@@ -200,7 +200,7 @@ ListEditView::paintEvent(QPaintEvent* e)
 
     timeT updateStart = 0, updateEnd = 0;
     int segmentsToUpdate = 0;
-    Segment *singleSegment = 0;
+    Segment *singleSegment = nullptr;
 
     for (unsigned int i = 0; i < m_segments.size(); ++i) {
 
@@ -212,14 +212,14 @@ ListEditView::paintEvent(QPaintEvent* e)
         if (refreshStatus.needsRefresh() && isCompositionModified()) {
 
             // if composition is also modified, relayout everything
-            refreshSegment(0);
+            refreshSegment(nullptr);
             segmentsToUpdate = 0;
             break;
 
         } else if (m_timeSigNotifier->hasTimeSigChanged()) {
 
             // not exactly optimal!
-            refreshSegment(0);
+            refreshSegment(nullptr);
             segmentsToUpdate = 0;
             m_timeSigNotifier->reset();
             break;
@@ -244,7 +244,7 @@ ListEditView::paintEvent(QPaintEvent* e)
     }
 
     if (segmentsToUpdate > 1) {
-        refreshSegment(0, updateStart, updateEnd);
+        refreshSegment(nullptr, updateStart, updateEnd);
     } else if (segmentsToUpdate > 0) {
         refreshSegment(singleSegment, updateStart, updateEnd);
     }
@@ -257,7 +257,7 @@ ListEditView::paintEvent(QPaintEvent* e)
     // any time signatures have changed)
     setCompositionModified(false);
 
-    //!!!    m_inPaintEvent = false;
+    // !!! m_inPaintEvent = false;
     /*
         if (m_havePendingPaintEvent) {
     	e = m_pendingPaintEvent;
