@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -48,7 +48,7 @@ namespace Rosegarden
 
 PresetHandlerDialog::PresetHandlerDialog(QWidget *parent,
                                          bool fromNotation)
-        : QDialog(parent, 0),
+        : QDialog(parent, nullptr),
         m_fromNotation(fromNotation)
 {
     m_presets = new PresetGroup();
@@ -61,7 +61,7 @@ PresetHandlerDialog::PresetHandlerDialog(QWidget *parent,
 PresetHandlerDialog::~PresetHandlerDialog()
 {
     // delete m_presets
-    if (m_presets != NULL) {
+    if (m_presets != nullptr) {
         delete m_presets;
     }
 }
@@ -170,8 +170,8 @@ PresetHandlerDialog::initDialog()
     vboxLayout->addWidget(buttonBox);
 
     connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
-    connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
-    connect(buttonBox, SIGNAL(helpRequested()), this, SLOT(help()));
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
+    connect(buttonBox, &QDialogButtonBox::helpRequested, this, &PresetHandlerDialog::help);
 }
 
 void
