@@ -65,13 +65,13 @@ RG_DEBUG << "ProjectPackager::ProjectPackager():  mode: " << mode <<
 
     this->setModal(false);
 
-    setWindowIcon(IconLoader().loadPixmap("window-packager"));
+    setWindowIcon(IconLoader::loadPixmap("window-packager"));
 
     QGridLayout *layout = new QGridLayout;
     this->setLayout(layout);
 
     QLabel *icon = new QLabel(this);
-    icon->setPixmap(IconLoader().loadPixmap("rosegarden-packager"));
+    icon->setPixmap(IconLoader::loadPixmap("rosegarden-packager"));
     layout->addWidget(icon, 0, 0);
 
     QString modeStr;
