@@ -19,22 +19,18 @@
 #ifndef RG_SPLINE_H
 #define RG_SPLINE_H
 
-#include "base/FastVector.h"
-
+#include <vector>
 
 class QPoint;
 class PointList;
 
-
 namespace Rosegarden
 {
 
-
-
 class Spline
 {
 public:
-    typedef FastVector<QPoint> PointList;
+    typedef std::vector<QPoint> PointList;
 
     /**
      * Calculate a set of polyline points to approximate
