@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     This file originally from Sonic Visualiser, copyright 2006 Chris
     Cannam.
@@ -119,12 +119,14 @@ TempDirectory::createTempDirectoryIn(QString dir)
     // to do this for us, and mkdtemp is not standard.  This method is
     // based on the way glibc does mkdtemp.
 
+    // NOTE: Qt 5 has QTemporaryDir for this
+
     static QString chars =
         "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
 
     QString suffix;
     int padlen = 6, attempts = 100;
-    unsigned int r = time(0) ^ getpid();
+    unsigned int r = time(nullptr) ^ getpid();
 
     for (int i = 0; i < padlen; ++i) {
         suffix += "X";
