@@ -19,32 +19,33 @@
 
 #include "ThornStyle.h"
 
-#include "ResourceFinder.h"
 #include "gui/general/IconLoader.h"
 #include "misc/Debug.h"
 
-#include <QApplication>
+#include <QApplication>  // qApp
 #include <QAbstractItemView>
+#include <QAbstractSpinBox>
 #include <QCheckBox>
+#include <QColor>
+#include <QComboBox>
 #include <QDebug>
-#include <qdrawutil.h>
+#include <QDialogButtonBox>
 #include <QEvent>
-#include <QFile>
 #include <QFileDialog>
 #include <QLabel>
-#include <QLayout>
+#include <QLinearGradient>
+#include <QObject>
 #include <QPainter>
+#include <QPainterPath>
+#include <QPen>
+#include <QPoint>
+#include <QPushButton>
 #include <QRadioButton>
+#include <QRect>
 #include <QStyleFactory>
-#include <QStyleOption>
+#include <QStyleOption>  // QStyleOption* classes
 #include <QToolBar>
 #include <QWidget>
-#include <QDialogButtonBox>
-#include <QPushButton>
-#include <QComboBox>
-#include <QSpinBox>
-#include <QScrollBar>
-#include <QAbstractScrollArea>
 
 using namespace Rosegarden;
 
@@ -290,6 +291,8 @@ ThornStyle::ThornStyle()
     const QColor buttonColor = QColor(0xEE, 0xEE, 0xEE);
     m_standardPalette.setColor(QPalette::Button, buttonColor);
     m_standardPalette.setColor(QPalette::ButtonText, Qt::black); // enabled button texts and menu items
+    m_standardPalette.setColor(
+            QPalette::Disabled, QPalette::ButtonText, Qt::darkGray);
 
     // alternate-background-color: #EEEEFF;
     m_standardPalette.setColor(QPalette::AlternateBase, QColor(0xEE, 0xEE, 0xFF));
@@ -311,16 +314,16 @@ QIcon ThornStyle::standardIcon(QStyle::StandardPixmap standardIcon, const QStyle
 
     // custom icons for QMessageBox
     case SP_MessageBoxInformation:
-        return m_iconLoader.loadPixmap("messagebox-information");
+        return IconLoader::loadPixmap("messagebox-information");
 
     case SP_MessageBoxWarning:
-        return m_iconLoader.loadPixmap("warning");
+        return IconLoader::loadPixmap("warning");
 
     case SP_MessageBoxCritical:
-        return m_iconLoader.loadPixmap("messagebox-critical");
+        return IconLoader::loadPixmap("messagebox-critical");
 
     case SP_MessageBoxQuestion:
-        return m_iconLoader.loadPixmap("messagebox-question");
+        return IconLoader::loadPixmap("messagebox-question");
 
     case SP_TitleBarNormalButton:
         return m_titleUndockPixmap;
