@@ -18,10 +18,18 @@
 #ifndef RG_THORN_STYLE_H
 #define RG_THORN_STYLE_H
 
-#include "IconLoader.h"
-
-#include <QProxyStyle>
 #include <QIcon>
+#include <QPalette>
+#include <QPixmap>
+#include <QProxyStyle>
+#include <QSize>
+#include <QStyle>
+
+class QPainter;
+class QStyleOption;
+class QStyleOptionComplex;
+class QWidget;
+
 #include <rosegardenprivate_export.h>
 
 namespace Rosegarden
@@ -64,7 +72,6 @@ private:
     QSize pixmapSize(const QPixmap &pixmap) const;
 
 
-    mutable IconLoader m_iconLoader;
     QPalette m_standardPalette;
 
     QPixmap m_horizontalToolbarSeparatorPixmap;
