@@ -56,7 +56,8 @@ ControlEraser::handleLeftButtonPress(const ControlMouseEvent *e)
     if (!e->itemList.size()) return;
 
     ControllerEventsRuler *ruler = static_cast <ControllerEventsRuler*> (m_ruler);
-    std::vector <ControlItem*>::const_iterator it;
+    ControlItemVector::const_iterator it;
+
     // If any of the covered items is selected, delete entire selection
     for (it = e->itemList.begin(); it != e->itemList.end(); ++it) {
         if ((*it)->isSelected()) {
