@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -29,10 +29,13 @@ const unsigned int ControlItem::DefaultWidth    = 20;
 
 ControlItem::ControlItem(ControlRuler *controlRuler,
         Event *event,
-        QPolygonF polygon)
-: QPolygonF(polygon),
+        QPolygonF polygon) :
+    QPolygonF(polygon),
     m_xstart(-1.0),
+    m_xend(0),
+    m_lastxstart(0),
     m_y(0),
+    m_handlingMouseMove(false),
     m_selected(false),
     m_data(0),
     m_controlRuler(controlRuler),
