@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -38,11 +38,11 @@ public:
                                    Segment &segment,
 				    timeT duration=0);
 
-    virtual ~ControlRulerEventInsertCommand() {;}
+    ~ControlRulerEventInsertCommand() override {;}
 
 protected:
 
-    virtual void modifySegment();
+    void modifySegment() override;
 
     std::string m_type;
     long m_number;
