@@ -331,7 +331,11 @@ ControlRulerWidget::slotAddPropertyRuler(const PropertyName &propertyName)
 {
     if (!m_viewSegment) return;
 
-    PropertyControlRuler *controlruler = new PropertyControlRuler(propertyName, m_viewSegment, m_scale, this);
+    PropertyControlRuler *controlruler = new PropertyControlRuler(
+            propertyName,
+            m_viewSegment,  // viewSegment
+            m_scale,  // scale
+            this);  // parent
 
     connect(controlruler, &ControlRuler::rulerSelectionChanged,
             this, &ControlRulerWidget::slotChildRulerSelectionChanged);
@@ -340,7 +344,7 @@ ControlRulerWidget::slotAddPropertyRuler(const PropertyName &propertyName)
             this,  &ControlRulerWidget::showContextHelp);
 
     controlruler->setXOffset(m_gutter);
-    controlruler->updateSelection(&m_selectedElements);
+    controlruler->updateSelection(m_selectedElements);
 
     // little kludge here, we only have the one property ruler, and the string
     // "velocity" wasn't already in a context (any context) where it could be
@@ -416,7 +420,7 @@ ControlRulerWidget::slotSelectionChanged(EventSelection *s)
         for (it = m_controlRulerList.begin(); it != m_controlRulerList.end(); ++it) {
             PropertyControlRuler *pr = dynamic_cast <PropertyControlRuler *> (*it);
             if (pr) {
-                pr->updateSelection(&m_selectedElements);
+                pr->updateSelection(m_selectedElements);
             }
         }
     }
@@ -443,11 +447,15 @@ ControlRulerWidget::slotHoveredOverNoteChanged()
 void
 ControlRulerWidget::slotUpdateRulers(timeT startTime, timeT endTime)
 {
-    if (m_controlRulerList.size()) {
-        ControlRulerList::iterator it;
-        for (it = m_controlRulerList.begin(); it != m_controlRulerList.end(); ++it) {
-            (*it)->notationLayoutUpdated(startTime,endTime);
-        }
+    // No rulers to update?  Bail.
+    if (m_controlRulerList.empty())
+        return;
+
+    // For each ruler, ask for an update.
+    for (ControlRulerList::iterator it = m_controlRulerList.begin();
+         it != m_controlRulerList.end();
+         ++it) {
+        (*it)->notationLayoutUpdated(startTime, endTime);
     }
 }
 
