@@ -116,7 +116,9 @@ ControlSelector::handleMouseRelease(const ControlMouseEvent *e)
         m_ruler->setSelectionRect(nullptr);
 
         // Add the selected items to the current selection
-        for (ControlItemList::iterator it = m_addedItems.begin(); it != m_addedItems.end(); ++it) {
+        for (ControlItemList::iterator it = m_addedItems.begin();
+             it != m_addedItems.end();
+             ++it) {
             m_ruler->addToSelection(*it);
         }
     }
