@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -40,7 +40,7 @@ ControlToolBox::ControlToolBox(ControlRuler *parent) :
 BaseTool *
 ControlToolBox::createTool(QString toolName)
 {
-    ControlTool *tool = 0;
+    ControlTool *tool = nullptr;
 
     QString toolNamelc = toolName.toLower();
 
@@ -56,9 +56,9 @@ ControlToolBox::createTool(QString toolName)
         tool = new ControlMover(m_ruler);
     else
     {
-        QMessageBox::critical(0, tr("Rosegarden"), QString("ControlToolBox::createTool : unrecognised toolname %1 (%2)")
+        QMessageBox::critical(nullptr, tr("Rosegarden"), QString("ControlToolBox::createTool : unrecognised toolname %1 (%2)")
                            .arg(toolName).arg(toolNamelc));
-        return 0;
+        return nullptr;
     }
 
     m_tools.insert(toolName, tool);
