@@ -19,6 +19,7 @@
 
 #include "ControllerEventsRuler.h"
 #include "ControlRuler.h"
+#include "ControlItem.h"
 #include "EventControlItem.h"
 #include "ControlTool.h"
 #include "ControlToolBox.h"
@@ -54,6 +55,9 @@
 #include <QWidget>
 #include <QPainter>
 
+#include <utility>  // for std::swap()
+
+#include <cmath>  // For lround()
 
 namespace Rosegarden
 {
@@ -92,6 +96,12 @@ ControllerEventsRuler::~ControllerEventsRuler()
     RG_DEBUG << "dtor";
 
     if (m_segment) m_segment->removeObserver(this);
+
+    delete m_controller;
+    m_controller = nullptr;
+
+    delete m_rubberBand;
+    m_rubberBand = nullptr;
 }
 
 bool ControllerEventsRuler::isOnThisRuler(Event *event)
@@ -101,7 +111,7 @@ bool ControllerEventsRuler::isOnThisRuler(Event *event)
     if (event->getType() == m_controller->getType()) {
         if (event->getType() == Controller::EventType) {
             try {
-                if (event->get<Int>(Controller::NUMBER) == m_controller->getControllerValue()) result = true;
+                if (event->get<Int>(Controller::NUMBER) == m_controller->getControllerNumber()) result = true;
             } catch (...) {
                 //
             }
@@ -165,10 +175,10 @@ void ControllerEventsRuler::paintEvent(QPaintEvent *event)
     //  come out the right size
     ///@TODO Only reconfigure all items if zoom has changed
     if (m_lastDrawnRect != m_pannedRect) {
-        EventControlItem *item;
-        for (ControlItemMap::iterator it = m_controlItemMap.begin(); it != m_controlItemMap.end(); ++it) {
-            item = static_cast <EventControlItem *> (it->second);
-            item->reconfigure();
+        for (ControlItemMap::iterator it = m_controlItemMap.begin();
+             it != m_controlItemMap.end();
+             ++it) {
+            it->second->reconfigure();
         }
         m_lastDrawnRect = m_pannedRect;
     }
@@ -191,15 +201,15 @@ void ControllerEventsRuler::paintEvent(QPaintEvent *event)
     lastX = m_rulerScale->getXForTime(m_segment->getStartTime())*m_xScale;
 
     if (m_nextItemLeft != m_controlItemMap.end()) {
-        EventControlItem *item = static_cast<EventControlItem*> (m_nextItemLeft->second);
-        lastY = item->y();
+        lastY = m_nextItemLeft->second->y();
     } else {
         lastY = valueToY(m_controller->getDefault());
     }
     
     mapIt = m_firstVisibleItem;
     while (mapIt != m_controlItemMap.end()) {
-        EventControlItem *item = static_cast<EventControlItem*> (mapIt->second);
+        QSharedPointer<ControlItem> item = mapIt->second;
+
         painter.drawLine(mapXToWidget(lastX),mapYToWidget(lastY),
                 mapXToWidget(item->xStart()),mapYToWidget(lastY));
         painter.drawLine(mapXToWidget(item->xStart()),mapYToWidget(lastY),
@@ -219,13 +229,13 @@ void ControllerEventsRuler::paintEvent(QPaintEvent *event)
     
     // Use a fast vector list to record selected items that are currently visible so that they
     // can be drawn last - can't use m_selectedItems as this covers all selected, visible or not
-    std::vector<ControlItem*> selectedvector;
+    ControlItemVector selectedVector;
 
     for (ControlItemList::iterator it = m_visibleItems.begin(); it != m_visibleItems.end(); ++it) {
         if (!(*it)->isSelected()) {
             painter.drawPolygon(mapItemToWidget(*it));
         } else {
-            selectedvector.push_back(*it);
+            selectedVector.push_back(*it);
         }
     }
 
@@ -236,7 +246,9 @@ void ControllerEventsRuler::paintEvent(QPaintEvent *event)
     int fontHeight = fontMetrics.height();
     int fontOffset = fontMetrics.width('+');
     
-    for (std::vector<ControlItem*>::iterator it = selectedvector.begin(); it != selectedvector.end(); ++it)
+    for (ControlItemVector::iterator it = selectedVector.begin();
+         it != selectedVector.end();
+         ++it)
     {
         // Draw the marker
         painter.drawPolygon(mapItemToWidget(*it));
@@ -267,7 +279,7 @@ void ControllerEventsRuler::paintEvent(QPaintEvent *event)
         painter.setPen(pen);
         brush.setStyle(Qt::NoBrush);
         painter.setBrush(brush);
-        painter.drawRect(mapItemToWidget(m_selectionRect));
+        painter.drawRect(mapRectToWidget(m_selectionRect));
     }
 
     // draw the rubber band indicating where a line of controllers will go
@@ -288,10 +300,10 @@ QString ControllerEventsRuler::getName()
 
         if (m_controller->getType() == Controller::EventType) {
             QString hexValue;
-            hexValue.sprintf("0x%x", m_controller->getControllerValue());
+            hexValue.sprintf("0x%x", m_controller->getControllerNumber());
 
             name = QString("%1 (%2 / %3)").arg(strtoqstr(m_controller->getName()))
-                   .arg(int(m_controller->getControllerValue()))
+                   .arg(int(m_controller->getControllerNumber()))
                    .arg(hexValue);
         } else if (m_controller->getType() == PitchBend::EventType) {
             name = tr("Pitch Bend");
@@ -304,25 +316,41 @@ QString ControllerEventsRuler::getName()
 
 void ControllerEventsRuler::eventAdded(const Segment*, Event *event)
 {
+    // Avoid handling this while we are adding events.
+    // Otherwise when moving an event, this might creating a duplicate.
+    if (m_moddingSegment)
+        return;
+
     // Segment observer call that an event has been added
     // If it should be on this ruler and it isn't already there
     //  add a ControlItem to display it
     // Note that ControlPainter will (01/08/09) add events directly
     //  these should not be replicated by this observer mechanism
-    if (isOnThisRuler(event) && !m_moddingSegment) addControlItem2(event);
+    if (isOnThisRuler(event))
+        addControlItem2(event);
 }
 
 void ControllerEventsRuler::eventRemoved(const Segment*, Event *event)
 {
+    // Avoid handling this while we are deleting events.
+    // Otherwise when moving an event, this would cause the event to
+    // disappear.  See bug #1573.
+    if (m_moddingSegment)
+        return;
+
     // Segment observer notification of a removed event
     // Could be an erase action on the ruler or an undo/redo event
 
     // Old code did this ... not sure why
     //    clearSelectedItems();
     //
-    if (isOnThisRuler(event) && !m_moddingSegment) {
+    if (isOnThisRuler(event)) {
         eraseControlItem(event);
-        update();
+
+        // If we are doing this, an update is coming.  No need to
+        // do an update for every delete.
+        if (!m_moddingSegment)
+            update();
     }
 }
 
@@ -331,189 +359,144 @@ void ControllerEventsRuler::segmentDeleted(const Segment *)
     m_segment = nullptr;
 }
 
-ControlItem* ControllerEventsRuler::addControlItem2(Event *event)
+QSharedPointer<ControlItem>
+ControllerEventsRuler::addControlItem2(Event *event)
 {
-    EventControlItem *controlItem = new EventControlItem(this, new ControllerEventAdapter(event), QPolygonF());
+    ControllerEventAdapter *controllerEventAdapter =
+            new ControllerEventAdapter(event);
+
+    QSharedPointer<EventControlItem> controlItem(new EventControlItem(
+            this,
+            controllerEventAdapter,
+            QPolygonF()));
+
     controlItem->updateFromEvent();
 
     ControlRuler::addControlItem(controlItem);
+
+    // ??? Neither caller actually does anything with this.
     return controlItem;
 }
 
-ControlItem* ControllerEventsRuler::addControlItem2(float x, float y)
+QSharedPointer<ControlItem>
+ControllerEventsRuler::addControlItem2(float x, float y)
 {
     // Adds a ControlItem in the absence of an event (used by ControlPainter)
     clearSelectedItems();
-    EventControlItem *item = new EventControlItem(this, new ControllerEventAdapter(nullptr), QPolygonF());
+
+    QSharedPointer<EventControlItem> item(new EventControlItem(
+            this, new ControllerEventAdapter(nullptr), QPolygonF()));
     item->reconfigure(x,y);
     item->setSelected(true);
+
     ControlRuler::addControlItem(item);
     
     return item;
 }
 
 void
-ControllerEventsRuler::addControlLine(float x1, float y1, float x2, float y2, bool eraseExistingControllers)
+ControllerEventsRuler::addControlLine(
+        double x1, double y1,
+        double x2, double y2,
+        bool eraseExistingControllers)
 {
-    RG_DEBUG << "addControlLine()";
-
     clearSelectedItems();
 
-    // get a timeT for one end point of our line
-    timeT originTime = m_rulerScale->getTimeForX(x1);
-
-    // get a timeT for the other end point of our line
-    timeT destinationTime = m_rulerScale->getTimeForX(x2);
-
-    // get a value for one end point of our line
-    long originValue = yToValue(y1);
-    
-    // get a value for the other end point
-    long destinationValue = yToValue(y2);
-
-    if (originTime == destinationTime || originValue == destinationValue) return;
-
-    // If the "anchor point" was to the right of the newly clicked destination
-    // point, we're drawing a line from right to left.  We simply swap origin
-    // for destination and calculate all lines as drawn from left to right, for
-    // convenience and sanity.
-    if (originTime > destinationTime) {
-        timeT swapTime = originTime;
-        originTime = destinationTime;
-        destinationTime = swapTime;
-
-        long swapValue = originValue;
-        originValue = destinationValue;
-        destinationValue = swapValue;
-    }
-
-    // save a list of existing events that occur within the span of the new line
-    // for later deletion, if desired
-    std::vector<Event*> eventsToClear;
-
-    if (eraseExistingControllers) {
-        for (Segment::iterator si = m_segment->begin();
-             si != m_segment->end(); ++si) {
-
-            timeT t = (*si)->getNotationAbsoluteTime();
-            if (t >= originTime && t <= destinationTime) {
-                eventsToClear.push_back(*si);
-            }
-        }
-    }
-
-    // rise and run
-    long rise = destinationValue - originValue;
-    timeT run = destinationTime - originTime;
-
-    RG_DEBUG << "addControlLine(): Drawing a line from origin time: " << originTime << " to " << destinationTime
-             << " rising from: " << originValue << " to " << destinationValue
-             << " with a rise of: " << rise << " and run of: " << run;
-
-    // avoid divide by 0 potential, rise is always at least 1
-    if (rise == 0) rise = 1;
-
-    // are we rising or falling?
-    bool rising = (rise > 0);
-
-    // always calculate step on a positive value for rise, and make sure it's at
-    // least 1
-    float step = run / (float)(rising ? rise : rise * -1);
-
-    // Trying this with pitch bend with a rise approaching the maximum over a
-    // span of around four bars generated over 15,000 pitch bend events!  That's
-    // super duper fine resolution, but it's too much for anything to handle.
-    // Let's try to do some sensible thinning without getting too complicated...
-    // bool isPitchBend = (m_controller->getType() == Rosegarden::PitchBend::EventType);
-    int thinningHackCounter = 1;
-    
-    long intermediateValue = originValue;    
-    long controllerNumber = 0;
-
-    if (m_controller) {
-        controllerNumber = m_controller->getControllerValue();
-    } else {
-        RG_WARNING << "addControlLine(): No controller number set.  Time to panic!  Line drawing aborted.";
+    if (!m_controller) {
+        RG_WARNING << "addControlLine(): No controller number set.  Line drawing aborted.";
         return;
     }
 
+    timeT startTime = m_rulerScale->getTimeForX(x1);
+    timeT stopTime = m_rulerScale->getTimeForX(x2);
+
+    long startValue = yToValue(y1);
+    long stopValue = yToValue(y2);
+
+    // If there's nothing to do, bail.
+    if (startTime == stopTime  ||  startValue == stopValue)
+        return;
+
+    // Make sure start is before stop.
+    if (startTime > stopTime) {
+        std::swap(startTime, stopTime);
+        std::swap(startValue, stopValue);
+    }
+
+    const long deltaValue = stopValue - startValue;
+    const timeT duration = stopTime - startTime;
+
+    double timeStep = 30;
+
+    // If it's going to take more than 200 steps, adjust the step so that
+    // there will be no more than 200 steps.
+    if (duration / timeStep > 200)
+        timeStep = duration / 200;
+
+    const double totalSteps = duration / timeStep;
+    const double valueStep = deltaValue / totalSteps;
+
     MacroCommand *macro = new MacroCommand(tr("Insert Line of Controllers"));
 
-    bool failsafe = false;
+    // If Ctrl was not pressed
+    if (eraseExistingControllers) {
 
-    // if we're clearing existing events, add that to the macro command
-    for (std::vector<Event*>::iterator ei = eventsToClear.begin();
-         ei != eventsToClear.end(); ++ei) {
+        // ??? MEMORY LEAK (confirmed)  EraseCommand doesn't take ownership.
+        EventSelection *selection = new EventSelection(*m_segment);
 
-        // if the event was a controller or pitch bend, and it is on this ruler,
-        // add it to the list
-        if (((*ei)->isa(Controller::EventType) || (*ei)->isa(PitchBend::EventType))
-            && isOnThisRuler(*ei)) {
+        // For each event in the time range
+        for (Segment::const_iterator i = m_segment->findTime(startTime);
+             i != m_segment->findTime(stopTime);
+             ++i) {
+            Event *e = *i;
 
-            bool collapseRests = true;
-            macro->addCommand(new EraseEventCommand(*m_segment,
-                                                    *ei,
-                                                    collapseRests));
-       }
-    }
-
-    if (macro->haveCommands()) {
-        CommandHistory::getInstance()->addCommand(macro);
-        macro = new MacroCommand(tr("Insert Line of Controllers"));
-    }
-
-    for (float i = originTime; i <= destinationTime; i += step) {
-
-        if (failsafe) continue;
-
-        if (rising) intermediateValue++;
-        else intermediateValue--;
-
-        if (rising && intermediateValue > destinationValue) failsafe = true;
-        else if (!rising && intermediateValue < destinationValue) failsafe = true;
-
-//        RG_DEBUG << "addControlLine(): creating event at time: " << i << " of value: " << intermediateValue;
-//        continue;
-
-        Event *controllerEvent = new Event(m_controller->getType(), (timeT) i);
-
-        if (m_controller->getType() == Rosegarden::Controller::EventType) {
-
-            controllerEvent->set<Rosegarden::Int>(Rosegarden::Controller::VALUE, intermediateValue);
-            controllerEvent->set<Rosegarden::Int>(Rosegarden::Controller::NUMBER, controllerNumber);
-
-        } else if (m_controller->getType() == Rosegarden::PitchBend::EventType)   {
-
-            // always set the first and last events, then only set every 25th,
-            // 50th, and 75th event for pitch bend
-            if (thinningHackCounter++ > 100) thinningHackCounter = 1;
-            if (thinningHackCounter != 25 &&
-                thinningHackCounter != 50 &&
-                thinningHackCounter != 75 &&
-                i != originTime           &&
-                i != destinationTime) continue;
-
-            RG_DEBUG << "addControlLine(): intermediate value: " << intermediateValue;
-
-            // Convert to PitchBend MSB/LSB
-            int lsb = intermediateValue & 0x7f;
-            int msb = (intermediateValue >> 7) & 0x7f;
-            controllerEvent->set<Rosegarden::Int>(Rosegarden::PitchBend::MSB, msb);
-            controllerEvent->set<Rosegarden::Int>(Rosegarden::PitchBend::LSB, lsb);
+            // If this is a relevant event, add it to the selection.
+            if (m_controller->matches(e))
+                selection->addEvent(e, false);
         }
 
-        if (failsafe) RG_DEBUG << "addControlLine(): intermediate value: " << intermediateValue << " exceeded target: " << destinationValue;
+        // If there is something in the selection, add the EraseCommand.
+        // For some reason, if we perform the erase with an empty selection,
+        // we end up with the segment expanded to the beginning of the
+        // composition.
+        if (selection->getAddedEvents() != 0)
+            macro->addCommand(new EraseCommand(*selection));
+        else
+            delete selection;
+
+    }
+
+    // Pick something outrageous to make sure the first event is always added.
+    long lastValue = 999999;
+
+    // For each time step
+    for (int i = 0; /* see break below */; ++i) {
+
+        timeT time2 = std::lround(startTime + i * timeStep);
+        if (time2 > stopTime)
+            break;
+
+        long value = startValue + i * valueStep;
+
+        // No change?  Try the next time step.
+        if (value == lastValue)
+            continue;
+
+        lastValue = value;
+
+        // Add an Event to the MacroCommand
+        macro->addCommand(new EventInsertionCommand(
+                *m_segment,
+                m_controller->newEvent(time2, value)));
 
-        macro->addCommand(new EventInsertionCommand (*m_segment, controllerEvent));
     }
 
-    m_moddingSegment = true;
     CommandHistory::getInstance()->addCommand(macro);
-    m_moddingSegment = false;
-    
+
     // How else to re-initialize and bring things into view?  I'm missing
     // something, but this works...
     init();
+
 }
 
 void
@@ -563,7 +546,7 @@ Event *ControllerEventsRuler::insertEvent(float x, float y)
     long number = 0;
 
     if (m_controller) {
-        number = m_controller->getControllerValue();
+        number = m_controller->getControllerNumber();
     } else {
 
         //!!!
