@@ -36,9 +36,9 @@ class Event;
 class ControlParameter;
 class ControlItem;
 
-
+/// Controller Ruler (volume, pan, pitchbend, etc...)
 /**
- * ControllerEventsRuler : edit Controller events
+ * ??? rename: ControllerRuler
  */
 class ControllerEventsRuler : public ControlRuler, public SegmentObserver
 {
@@ -67,8 +67,8 @@ public:
     void eventRemoved(const Segment *, Event *) override;
     void segmentDeleted(const Segment *) override;
 
-    virtual ControlItem* addControlItem2(float, float);
-    virtual ControlItem* addControlItem2(Event *);
+    virtual QSharedPointer<ControlItem> addControlItem2(float, float);
+    virtual QSharedPointer<ControlItem> addControlItem2(Event *);
 
     /** Draw a line of controllers from (x1, y1) to (x2, y2).  If
      * eraseExistingControllers is true, any existing controllers falling within
@@ -77,7 +77,10 @@ public:
      * Does not return anything yet, as whether it should or not has yet to be
      * determined.
      */
-    virtual void addControlLine(float x1, float y1, float x2, float y2, bool eraseExistingContollers);
+    virtual void addControlLine(
+            double x1, double y1,
+            double x2, double y2,
+            bool eraseExistingContollers);
 
     /** Draw a rubber band indicating the controller line that will be drawn if
      * the user clicks another event into existence while moving the pencil
@@ -107,6 +110,7 @@ protected:
 
     ControlParameter  *m_controller;
     QRectF m_lastDrawnRect;
+    // ??? See if we can remove this.
     bool m_moddingSegment;
     QLineF *m_rubberBand;
     bool m_rubberBandVisible;
