@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -34,14 +34,14 @@ public:
                 ControllerEventAdapter* eventAdapter,
                 QPolygonF polygon);
 
-    ~EventControlItem();
+    ~EventControlItem() override;
     
-    virtual void update();
+    void update() override;
     virtual void updateFromEvent();
 
     void setY(float y);
-    void updateSegment();
-    void reconfigure();
+    void updateSegment() override;
+    void reconfigure() override;
     void reconfigure(float x,float y);
 
 protected:
