@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -37,13 +37,13 @@ public:
                 ViewElement* element,
                 QPolygonF polygon);
 
-    ~PropertyControlItem();
+    ~PropertyControlItem() override;
 
-    virtual void update();
+    void update() override;
     ViewElement* getElement() { return m_element; }
 
-    void setValue(float y);
-    void updateSegment();
+    void setValue(float y) override;
+    void updateSegment() override;
 
 protected:
     using ControlItem::reconfigure;
