@@ -50,18 +50,22 @@
 namespace Rosegarden
 {
 
+
 PropertyControlRuler::PropertyControlRuler(PropertyName propertyName,
-                                           ViewSegment *segment,
+                                           ViewSegment *viewSegment,
                                            RulerScale *rulerScale,
-                                           QWidget *parent,
-                                           const char */* name */) :
-    ControlRuler(segment, rulerScale,
-                 parent),
+                                           QWidget *parent) :
+    ControlRuler(viewSegment, rulerScale, parent),
     m_propertyName(propertyName)
 {
-
     setMenuName("property_ruler_menu");
-    setViewSegment(segment);
+    setViewSegment(viewSegment);
+}
+
+PropertyControlRuler::~PropertyControlRuler()
+{
+    if (m_viewSegment)
+        m_viewSegment->removeObserver(this);
 }
 
 void PropertyControlRuler::update()
@@ -105,15 +109,18 @@ void PropertyControlRuler::paintEvent(QPaintEvent *event)
     // or not
     ControlItemVector selectedVector;
 
+    // For each visible control item, draw the unselected ones.
     for (ControlItemList::iterator it = m_visibleItems.begin();
          it != m_visibleItems.end();
          ++it) {
         if (!(*it)->isSelected()) {
+            // Draw the inside.
             brush.setColor((*it)->getColour().lighter());
             painter.setBrush(brush);
             painter.setPen(Qt::NoPen);
             painter.drawPolygon(mapItemToWidget(*it));
 
+            // Draw the outline.
             painter.setPen(pen);
             painter.drawPolyline(mapItemToWidget(*it));
         } else {
@@ -121,15 +128,18 @@ void PropertyControlRuler::paintEvent(QPaintEvent *event)
         }
     }
 
+    // For each selected control item, draw it.
     for (ControlItemVector::iterator it = selectedVector.begin();
          it != selectedVector.end();
          ++it)
     {
+        // Draw the inside.
         brush.setColor(((*it)->getColour()));
         painter.setBrush(brush);
         painter.setPen(Qt::NoPen);
         painter.drawPolygon(mapItemToWidget(*it));
 
+        // Draw the outline.
         painter.setPen(highlightPen);
         painter.drawPolyline(mapItemToWidget(*it));
     }
@@ -146,13 +156,6 @@ PropertyControlRuler::setViewSegment(ViewSegment *segment)
     init();
 }
 
-PropertyControlRuler::~PropertyControlRuler()
-{
-    if (m_viewSegment) {
-        m_viewSegment->removeObserver(this);
-    }
-}
-
 QString PropertyControlRuler::getName()
 {
     return strtoqstr(getPropertyName());
@@ -232,42 +235,34 @@ void PropertyControlRuler::init()
     update();
 }
 
-void PropertyControlRuler::updateSelection(std::vector <ViewElement*> *elementList)
+void PropertyControlRuler::updateSelection(
+        const std::vector<ViewElement *> &elementList)
 {
-    // Use base class fcn to set each item as not selected, clear the m_selectedItems lsit
-    //  and create a new m_eventSelection member
+    // For now, simply clear the selected items list and build it afresh
+
+    // Set each item as not selected, clear m_selectedItems and create a new
+    // m_eventSelection member.
     clearSelectedItems();
 
-    // For now, simply clear the selected items list and build it afresh
-    QSharedPointer<PropertyControlItem> item;
+    // For each item in the new selection
+    for (const ViewElement *element : elementList) {
+        // For each item on the ruler
+        for (ControlItemMap::value_type &rControlItemPair : m_controlItemMap) {
+            // Downcast so we can call getElement().
+            QSharedPointer<PropertyControlItem> item =
+                    qSharedPointerDynamicCast<PropertyControlItem>(
+                            rControlItemPair.second);
 
-//    for (ControlItemList::iterator it = m_selectedItems.begin(); it != m_selectedItems.end(); ++it) {
-//        item = dynamic_cast <PropertyControlItem *> (*it);
-//        if (item) item->setSelected(false);
-//    }
-//
-//    m_selectedItems.clear();
-    for (std::vector<ViewElement*>::iterator elit = elementList->begin();
-         elit != elementList->end();
-         ++elit) {
-        for (ControlItemMap::iterator it = m_controlItemMap.begin();
-             it != m_controlItemMap.end();
-             ++it) {
-            item = qSharedPointerDynamicCast<PropertyControlItem>(it->second);
+            // If we found a match, select it.
+            if (item  &&  item->getElement() == element) {
+                item->setSelected(true);
+                m_selectedItems.push_back(item);
+                m_eventSelection->addEvent(item->getEvent());
 
-            if (item) {
-                if (item->getElement() == (*elit)) {
-                    break;
-                } else {
-                    item = nullptr;
-                }
+                // Move on to the next selected item.
+                break;
             }
         }
-        if (!item) continue;
-
-        item->setSelected(true);
-        m_selectedItems.push_back(item);
-        m_eventSelection->addEvent(item->getEvent());
     }
 
     update();
