@@ -49,14 +49,14 @@ class PropertyControlRuler :  public ControlRuler, public ViewSegmentObserver
 {
 public:
     PropertyControlRuler(PropertyName propertyName,
-                        ViewSegment*,
-                        RulerScale*,
-                        QWidget* parent=nullptr, const char* name=nullptr);
+                        ViewSegment *viewSegment,
+                        RulerScale *scale,
+                        QWidget *parent);
 
     ~PropertyControlRuler() override;
 
     virtual void update();
-    
+
     void paintEvent(QPaintEvent *) override;
 
     QString getName() override;
@@ -78,7 +78,8 @@ public:
     /// SegmentObserver interface
     virtual void endMarkerTimeChanged(const Segment *, bool shorten);
 
-    void updateSelection(std::vector<ViewElement*>*);
+    /// Keep selection in sync with the matrix and notation editors.
+    void updateSelection(const std::vector<ViewElement *> &elementList);
     void updateSelectedItems();
 
 public slots:
