@@ -32,10 +32,68 @@
 
 namespace
 {
-    // Config settings
-    // Keeping these at the file level since one of the users is static.
-    bool allowReset;
-    bool forceChannelSetups;
+    bool allowReset()
+    {
+        static bool available = false;
+        static bool allowReset = true;
+
+        // Read only once when needed since QSettings is very slow.
+        // See bug #1589.
+
+        if (available)
+            return allowReset;
+
+        // Delayed read.  We can't do this in the ChannelManager ctor
+        // because there is a static instance in StudioControl and
+        // QSettings doesn't work right at static construction time.
+
+        QSettings settings;
+        settings.beginGroup(Rosegarden::SequencerOptionsConfigGroup);
+
+        // Allow CC 121 to be sent out to clear out CCs.
+        // Edit > Preferences... > MIDI > General > Allow Reset All Controllers
+        allowReset =
+                settings.value("allowresetallcontrollers", "true").toBool();
+        // Write back out so it is easy to find.
+        settings.setValue("allowresetallcontrollers", allowReset);
+
+        RG_DEBUG << "getSettings(): allowReset: " << allowReset;
+
+        available = true;
+
+        return allowReset;
+    }
+
+    bool forceChannelSetups()
+    {
+        static bool available = false;
+        static bool forceChannelSetups = false;
+
+        // Read only once when needed since QSettings is very slow.
+        // See bug #1589.
+
+        if (available)
+            return forceChannelSetups;
+
+        // Delayed read.  We can't do this in the ChannelManager ctor
+        // because there is a static instance in StudioControl and
+        // QSettings doesn't work right at static construction time.
+
+        QSettings settings;
+        settings.beginGroup(Rosegarden::SequencerOptionsConfigGroup);
+
+        // Related to Bug #1560
+        // When set to true, this causes MIPP channel setups to be sent at the
+        // beginning of each Segment for fixed channel Segments.
+        forceChannelSetups =
+                settings.value("forceChannelSetups", "false").toBool();
+        // Write back out so it is easy to find.
+        settings.setValue("forceChannelSetups", forceChannelSetups);
+
+        available = true;
+
+        return forceChannelSetups;
+    }
 }
 
 namespace Rosegarden
@@ -55,25 +113,6 @@ ChannelManager::ChannelManager(Instrument *instrument) :
 {
     // Safe even for nullptr.
     connectInstrument(instrument);
-
-    QSettings settings;
-    settings.beginGroup(SequencerOptionsConfigGroup);
-
-    // Allow CC 121 to be sent out to clear out CCs.
-    // Edit > Preferences... > MIDI > General > Allow Reset All Controllers
-    allowReset =
-            settings.value("allowresetallcontrollers", "true").toBool();
-    // Write back out so it is easy to find.
-    settings.setValue("allowresetallcontrollers", allowReset);
-
-    // Related to Bug #1560
-    // When set to true, this causes MIPP channel setups to be sent at the
-    // beginning of each Segment for fixed channel Segments.
-    forceChannelSetups =
-            settings.value("forceChannelSetups", "false").toBool();
-    // Write back out so it is easy to find.
-    settings.setValue("forceChannelSetups", forceChannelSetups);
-
 }
 
 void
@@ -174,7 +213,7 @@ void ChannelManager::insertChannelSetup(
 
     // Reset All Controllers
 
-    if (allowReset) {
+    if (allowReset()) {
         // In case some controllers are on that we don't know about, turn
         // all controllers off.  (Reset All Controllers)
         try {
@@ -311,7 +350,7 @@ bool ChannelManager::makeReady(
 
     // If this instrument is in auto channels mode or we are starting
     // in the middle of a Segment.
-    if (!m_instrument->hasFixedChannel()  ||  forceChannelSetups  ||
+    if (!m_instrument->hasFixedChannel()  ||  forceChannelSetups()  ||
         startingInMiddle) {
 
         insertChannelSetup(
