@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -35,12 +35,12 @@ public:
 
 protected:
     // override from MappedEventBuffer
-    virtual int calculateSize();
+    int calculateSize() override;
 
     // override from MappedEventBuffer
-    virtual void fillBuffer();
+    void fillBuffer() override;
 
-    virtual bool shouldPlay(MappedEvent *evt, RealTime /*startTime*/);
+    bool shouldPlay(MappedEvent *evt, RealTime /*startTime*/) override;
 };
 
 }
