@@ -18,13 +18,14 @@
 #ifndef RG_SEGMENTMAPPER_H
 #define RG_SEGMENTMAPPER_H
 
-#include <QString>
-#include "base/Event.h"
 #include "gui/seqmanager/MappedEventBuffer.h"
 
+#include <QString>
+
 namespace Rosegarden
 {
 
+
 class Segment;
 class RosegardenDocument;
 
@@ -35,22 +36,21 @@ public:
     ~SegmentMapper() override;
 
     /// Create the appropriate mapper for the segment type.  Factory function.
-    static QSharedPointer<SegmentMapper> makeMapperForSegment(RosegardenDocument *, Segment *);
+    static QSharedPointer<SegmentMapper> makeMapperForSegment(
+            RosegardenDocument *, Segment *);
 
-    int getSegmentRepeatCount() override;
+    // MappedEventBuffer override
     TrackId getTrackID() const override;
 
-    void initSpecial() override;
-
 protected:
     SegmentMapper(RosegardenDocument *, Segment *);
 
-    bool mutedEtc();
-
-    //--------------- Data members ---------------------------------
     Segment *m_segment;
-};
 
+    int getSegmentRepeatCount();
+
+    bool mutedEtc();
+};
 
 
 }
