@@ -23,6 +23,7 @@
 
 #include "sound/Midi.h"  // for MIDI_SYSTEM_RESET
 #include "sound/ControlBlock.h"
+#include "sound/ExternalController.h"
 #include "misc/Debug.h"
 #include "misc/Strings.h"  // for qStrToBool()
 #include "misc/ConfigGroups.h"
@@ -712,7 +713,7 @@ SequenceManager::processAsynchronousMidi(const MappedEventList &mC,
          it != mC.end();
          ++it) {
         // Skip events destined for the "external controller" port.
-        if ((*it)->getRecordedDevice() == Device::CONTROL_DEVICE)
+        if ((*it)->getRecordedDevice() == Device::EXTERNAL_CONTROLLER)
             continue;
 
         // Skip events that are filtered.
@@ -1013,9 +1014,9 @@ SequenceManager::processAsynchronousMidi(const MappedEventList &mC,
                 }
             }
         }
-        if ((*i)->getRecordedDevice() == Device::CONTROL_DEVICE) {
-            RG_DEBUG << "processAsynchronousMidi(): Emitting controllerDeviceEventReceived()...";
-            emit controllerDeviceEventReceived(*i);
+        if ((*i)->getRecordedDevice() == Device::EXTERNAL_CONTROLLER) {
+            RG_DEBUG << "processAsynchronousMidi(): Calling ExternalController::processEvent()...";
+            ExternalController::self()->processEvent(*i);
         }
     }
 }
@@ -1078,38 +1079,31 @@ bool SequenceManager::inCountIn(const RealTime &time) const
 void
 SequenceManager::checkSoundDriverStatus(bool warnUser)
 {
-    // Update local copy of status.
-    // ??? Can we get rid of this member?  Only record() uses it.  Why
-    //     not just let record() call getSoundDriverStatus(VERSION) directly?
-    //     Then we can get rid of all the callers that call this with warnUser
-    //     set to false.  Then we can get rid of warnUser.  No, it's worse
-    //     than that.  There's also a getSoundDriverStatus() in here that
-    //     provides access to this copy.  We would have to that over to
-    //     providing RosegardenSequencer::getSoundDriverStatus().  Then
-    //     probably inline that into each caller.  It's doable, but a bit
-    //     more involved than it appears at first glance.  I'm also a little
-    //     worried that this local status has more values than the
-    //     RosegardenSequencer one.  Or perhaps it is out of sync and there's
-    //     a reason.
-    m_soundDriverStatus = RosegardenSequencer::getInstance()->
-        getSoundDriverStatus(VERSION);
+    // Keep a local copy of the status to avoid calling
+    // RosegardenSequencer::getSoundDriverStatus() which uses a lock.
+    m_soundDriverStatus =
+            RosegardenSequencer::getInstance()->getSoundDriverStatus();
 
     RG_DEBUG << "checkSoundDriverStatus(): Sound driver status:" <<
             "MIDI" << (((m_soundDriverStatus & MIDI_OK) != 0) ? "ok" : "NOT OK") << "|" <<
-            "Audio" << (((m_soundDriverStatus & AUDIO_OK) != 0) ? "ok" : "NOT OK") << "|" <<
-            "Version" << (((m_soundDriverStatus & VERSION_OK) != 0) ? "ok" : "NOT OK");
+            "Audio" << (((m_soundDriverStatus & AUDIO_OK) != 0) ? "ok" : "NOT OK");
 
     if (!warnUser)
         return;
 
 #ifdef HAVE_LIBJACK
-    if ((m_soundDriverStatus & (AUDIO_OK | MIDI_OK | VERSION_OK)) ==
-        (AUDIO_OK | MIDI_OK | VERSION_OK)) return;
+    // Audio and MIDI ok?  Bail.
+    if ((m_soundDriverStatus & AUDIO_OK)  &&
+        (m_soundDriverStatus & MIDI_OK))
+        return;
 #else
-    if ((m_soundDriverStatus & (MIDI_OK | VERSION_OK)) ==
-        (MIDI_OK | VERSION_OK)) return;
+    // MIDI ok?  Bail.
+    if (m_soundDriverStatus & MIDI_OK)
+        return;
 #endif
 
+    // Either MIDI or Audio are not ok...
+
     StartupLogo::hideIfStillThere();
 
     QString text;
@@ -1129,13 +1123,15 @@ SequenceManager::checkSoundDriverStatus(bool warnUser)
     } 
 
 #ifdef HAVE_LIBJACK
-
+    // If audio driver is not ok...
     if (!(m_soundDriverStatus & AUDIO_OK)) {
         // This is to avoid us ever showing the same dialog more than
         // once during a single run of the program -- it's quite
         // separate from the suppression function
-        // ??? But this routine is only ever called with "true" once.  From
-        //     RMW's ctor.  There is no need for this.
+        // ??? But this routine is only ever called once.  From
+        //     RMW's ctor.  There is no need for this.  Plus the warning dialogs
+        //     are now hidden in the warning button in the WarningWidget in
+        //     the status bar.
         static bool showJackWarning = true;
 
         if (showJackWarning) {
@@ -1857,14 +1853,14 @@ SequenceManager::getSampleRate() const
 bool
 SequenceManager::shouldWarnForImpreciseTimer()
 {
-    QSettings settings;
-    settings.beginGroup( SequencerOptionsConfigGroup );
+    const QString timer =
+            RosegardenSequencer::getInstance()->getCurrentTimer();
 
-    QString timer = settings.value("timer").toString();
-    settings.endGroup();
-
-    if (timer == "(auto)" || timer == "") return true;
-    else return false; // if the user has chosen the timer, leave them alone
+    // If no specific timer has been chosen by the user, do warnings
+    if (timer == "(auto)"  ||  timer == "")
+        return true;
+    else  // The user has chosen a specific timer, leave them alone.
+        return false;
 }
 
 // Return a new metaiterator on the current composition (suitable
