@@ -92,7 +92,7 @@ public:
      * SequenceManager is not designed to operate without a document;
      * you must call setDocument() before you do anything with it.
      *
-     * ??? Subscribe for RMW::documentChanged() instead of this.
+     * ??? Subscribe for RMW::documentLoaded() instead of this.
      *     parentWidget is just RMW::self().  No need to pass it in.
      */
     void setDocument(RosegardenDocument *doc);
@@ -180,8 +180,6 @@ public:
      *     -> NotationView::slotInsertableNoteOnReceived()
      *     -> PitchTrackerView::slotInsertableNoteOnReceived()
      *     -> MatrixView::slotInsertableNoteOnReceived()
-     *   - controllerDeviceEventReceived()
-     *     -> RMVW::slotControllerDeviceEventReceived()
      *
      * This routine also performs extensive error checking and displays
      * error messages when a problem is detected.
@@ -317,16 +315,6 @@ signals:
      */
     void insertableNoteOffReceived(int pitch, int velocity);
 
-    /// An event was received from the "external controller" port.
-    /**
-     * Emitted by processAsynchronousMidi().
-     *
-     * Connected to
-     * RosegardenMainViewWindow::slotControllerDeviceEventReceived().  These
-     * are events from the "external controller" port.
-     */
-    void controllerDeviceEventReceived(MappedEvent *event);
-
     /// Signal RosegardenMainWindow to display a warning.
     /**
      * Connected to RosegardenMainWindow::slotDisplayWarning().
@@ -369,9 +357,15 @@ private slots:
     void slotScheduledCompositionMapperReset();
     
 private:
-    // ??? Get rid of this and go through RMW.
+    /// Cache to avoid lock?
+    /**
+     * ??? Get rid of this and go through RMW.  Or is that dangerous since
+     *     that would cross thread boundaries and require a lock which is
+     *     not there at the moment?
+     */
     RosegardenDocument *m_doc;
 
+    /// Cache to avoid lock.
     /**
      * @see RosegardenSequencer::getSoundDriverStatus()
      */
@@ -379,7 +373,7 @@ private:
 
     // *** CompositionMapper
 
-    QSharedPointer<CompositionMapper> m_compositionMapper;  // owned
+    QSharedPointer<CompositionMapper> m_compositionMapper;
     /// Add each Segment from the Composition to the CompositionMapper.
     void populateCompositionMapper();
     /**
@@ -401,13 +395,13 @@ private:
 
     // *** Other Mappers
 
-    QSharedPointer<MetronomeMapper> m_metronomeMapper;  // owned
+    QSharedPointer<MetronomeMapper> m_metronomeMapper;
     void resetMetronomeMapper();
 
-    QSharedPointer<TempoSegmentMapper> m_tempoSegmentMapper;  // owned
+    QSharedPointer<TempoSegmentMapper> m_tempoSegmentMapper;
     void resetTempoSegmentMapper();
 
-    QSharedPointer<TimeSigSegmentMapper> m_timeSigSegmentMapper;  // owned
+    QSharedPointer<TimeSigSegmentMapper> m_timeSigSegmentMapper;
     void resetTimeSigSegmentMapper();
 
     // *** Refresh Mappers and RosegardenSequencer
