@@ -50,7 +50,7 @@ AudioMixerWindow2::AudioMixerWindow2(QWidget *parent) :
     setObjectName("AudioMixerWindow2");
 
     setWindowTitle(tr("Audio Mixer"));
-    setWindowIcon(IconLoader().loadPixmap("window-audiomixer"));
+    setWindowIcon(IconLoader::loadPixmap("window-audiomixer"));
 
     // This avoids using CPU when we're "closed".  Normally with Qt,
     // "closed" really just means "hidden".
@@ -64,14 +64,10 @@ AudioMixerWindow2::AudioMixerWindow2(QWidget *parent) :
                 &RosegardenDocument::documentModified,
             this, &AudioMixerWindow2::slotDocumentModified);
     // Connect for "external controller" events.
-    connect(RosegardenMainWindow::self()->getView(),
-                &RosegardenMainViewWidget::controllerDeviceEventReceived,
-            this, &AudioMixerWindow2::slotExternalControllerEvent);
-    // Connect to make sure "external controller" events get here when
-    // we are the active window.
-    connect(this, SIGNAL(windowActivated()),
-            RosegardenMainWindow::self()->getView(),
-                SLOT(slotActiveMainWindowChanged()));
+    connect(ExternalController::self().data(),
+                &ExternalController::externalControllerAMW2,
+            this, &AudioMixerWindow2::slotExternalController);
+
     // Connect for high-frequency control change notifications.
     connect(Instrument::getStaticSignals().data(),
                 &InstrumentStaticSignals::controlChange,
@@ -516,14 +512,9 @@ AudioMixerWindow2::slotAboutRosegarden()
 }
 
 void
-AudioMixerWindow2::slotExternalControllerEvent(
-        MappedEvent *event,
-        const void *preferredCustomer)
+AudioMixerWindow2::slotExternalController(const MappedEvent *event)
 {
-    if (preferredCustomer != this)
-        return;
-
-    //RG_DEBUG << "slotExternalControllerEvent(): this one's for me";
+    //RG_DEBUG << "slotExternalController()...";
 
     // Some window managers (e.g. GNOME) do not allow the application to
     // change focus on the user.  So, this might not work.
@@ -555,27 +546,8 @@ AudioMixerWindow2::slotExternalControllerEvent(
 
     case MIDI_CONTROLLER_PAN:
         {
-            // Convert to approximately (-100, 100).
-            // ??? Why the epsilon (.01)?  To avoid -100?
-            double pan = static_cast<double>(value) / 64 * 100 + .01 - 100;
-
-            // ??? This gives -100 to 100:
-            //
-            //      double pan = 0;
-            //      if (value <= 64)
-            //          pan = static_cast<double>(value) / 64 * 100 - 100;
-            //      else
-            //          pan = (static_cast<double>(value) - 64) / 63 * 100;
-            //
-            //     Might be a good idea to factor out some standard
-            //     pan math functions to be reused everywhere.  The AudioLevel
-            //     class might be a good place to put them.
-            //
-            //     // Normal is [-1,1].  -1 = left, 0 = center, 1 = right.
-            //     MidiByte panNormalToMidi(double pan);
-            //     double panMidiToNormal(MidiByte pan);
-
-            m_inputStrips[channel]->panChanged(static_cast<float>(pan));
+            m_inputStrips[channel]->panChanged(
+                    static_cast<float>(AudioLevel::AudioPanD(value) - 100.0));
 
             break;
         }
@@ -607,20 +579,29 @@ AudioMixerWindow2::changeEvent(QEvent *event)
     // Let baseclass handle first.
     QWidget::changeEvent(event);
 
-    if (event->type() == QEvent::ActivationChange) {
-        //RG_DEBUG << "changeEvent(): Received activation change.";
-        if (isActiveWindow()) {
-            emit windowActivated();
+    // Only handle this for Rosegarden native mode.
+    if (!ExternalController::self()->isNative())
+        return;
 
-            size_t count = m_inputStrips.size();
-            if (count > 16)
-                count = 16;
+    // ??? Double updates seem to go out so we might want to be a little
+    //     more picky about the event we react to.
 
-            // For each strip, send vol/pan to the external controller port.
-            for (unsigned i = 0; i < count; i++)
-                m_inputStrips[i]->updateExternalController();
-        }
-    }
+    if (event->type() != QEvent::ActivationChange)
+        return;
+
+    if (!isActiveWindow())
+        return;
+
+    ExternalController::self()->activeWindow =
+            ExternalController::AudioMixer;
+
+    size_t count = m_inputStrips.size();
+    if (count > 16)
+        count = 16;
+
+    // For each strip, send vol/pan to the external controller port.
+    for (unsigned i = 0; i < count; i++)
+        m_inputStrips[i]->updateExternalController();
 }
 
 
