@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -47,11 +47,11 @@ namespace Rosegarden
 static void osc_error(int num, const char *msg, const char *path)
 {
     std::cerr << "Rosegarden: ERROR: liblo server error " << num
-	      << " in path " << path << ": " << msg << std::endl;
+              << " in path " << path << ": " << msg << std::endl;
 }
 
 static int osc_message_handler(const char *path, const char *types, lo_arg **argv,
-			       int argc, lo_message, void *user_data)
+                               int argc, lo_message, void *user_data)
 {
     AudioPluginOSCGUIManager *manager = (AudioPluginOSCGUIManager *)user_data;
 
@@ -60,7 +60,7 @@ static int osc_message_handler(const char *path, const char *types, lo_arg **arg
     QString method;
 
     if (!manager->parseOSCPath(path, instrument, position, method)) {
-	return 1;
+        return 1;
     }
 
     OSCMessage *message = new OSCMessage();
@@ -70,8 +70,8 @@ static int osc_message_handler(const char *path, const char *types, lo_arg **arg
 
     int arg = 0;
     while (types && arg < argc && types[arg]) {
-	message->addArg(types[arg], argv[arg]);
-	++arg;
+        message->addArg(types[arg], argv[arg]);
+        ++arg;
     }
 
     manager->postMessage(message);
@@ -80,10 +80,10 @@ static int osc_message_handler(const char *path, const char *types, lo_arg **arg
 
 AudioPluginOSCGUIManager::AudioPluginOSCGUIManager(RosegardenMainWindow *mainWindow) :
         m_mainWindow(mainWindow),
-        m_studio(0),
+        m_studio(nullptr),
         m_haveOSCThread(false),
         m_oscBuffer(1023),
-        m_dispatchTimer(0)
+        m_dispatchTimer(nullptr)
 {}
 
 AudioPluginOSCGUIManager::~AudioPluginOSCGUIManager()
@@ -108,15 +108,14 @@ AudioPluginOSCGUIManager::checkOSCThread()
     if (m_haveOSCThread)
         return ;
 
-    m_serverThread = lo_server_thread_new(NULL, osc_error);
+    m_serverThread = lo_server_thread_new(nullptr, osc_error);
 
-    lo_server_thread_add_method(m_serverThread, NULL, NULL,
+    lo_server_thread_add_method(m_serverThread, nullptr, nullptr,
                                 osc_message_handler, this);
 
     lo_server_thread_start(m_serverThread);
 
-    RG_DEBUG << "AudioPluginOSCGUIManager: Base OSC URL is "
-    << lo_server_thread_get_url(m_serverThread) << endl;
+    RG_DEBUG << "checkOSCThread(): Base OSC URL is " << lo_server_thread_get_url(m_serverThread);
 
     m_dispatchTimer = new TimerCallbackAssistant(20, timerCallback, this);
 
@@ -126,7 +125,7 @@ AudioPluginOSCGUIManager::checkOSCThread()
 bool
 AudioPluginOSCGUIManager::hasGUI(InstrumentId instrument, int position)
 {
-    PluginContainer *container = 0;
+    PluginContainer *container = nullptr;
     container = m_studio->getContainerById(instrument);
     if (!container) return false;
 
@@ -137,7 +136,7 @@ AudioPluginOSCGUIManager::hasGUI(InstrumentId instrument, int position)
         QString filePath = AudioPluginOSCGUI::getGUIFilePath
                            (strtoqstr(pluginInstance->getIdentifier()));
         return ( !filePath.isEmpty() );
-    } catch (Exception e) { // that's OK
+    } catch (const Exception &e) { // that's OK
         return false;
     }
 }
@@ -145,30 +144,27 @@ AudioPluginOSCGUIManager::hasGUI(InstrumentId instrument, int position)
 void
 AudioPluginOSCGUIManager::startGUI(InstrumentId instrument, int position)
 {
-    RG_DEBUG << "AudioPluginOSCGUIManager::startGUI: " << instrument << "," << position
-    << endl;
+    RG_DEBUG << "startGUI(): " << instrument << "," << position;
 
     checkOSCThread();
 
     if (m_guis.find(instrument) != m_guis.end() &&
             m_guis[instrument].find(position) != m_guis[instrument].end()) {
-        RG_DEBUG << "stopping GUI first";
+        RG_DEBUG << "startGUI(): stopping GUI first";
         stopGUI(instrument, position);
     }
 
     // check the label
-    PluginContainer *container = 0;
+    PluginContainer *container = nullptr;
     container = m_studio->getContainerById(instrument);
     if (!container) {
-        RG_DEBUG << "AudioPluginOSCGUIManager::startGUI: no such instrument or buss as "
-                 << instrument << endl;
+        RG_WARNING << "startGUI(): no such instrument or buss as " << instrument;
         return;
     }
 
     AudioPluginInstance *pluginInstance = container->getPlugin(position);
     if (!pluginInstance) {
-        RG_DEBUG << "AudioPluginOSCGUIManager::startGUI: no plugin at position "
-        << position << " for instrument " << instrument << endl;
+        RG_WARNING << "startGUI(): no plugin at position " << position << " for instrument " << instrument;
         return ;
     }
 
@@ -183,18 +179,16 @@ AudioPluginOSCGUIManager::startGUI(InstrumentId instrument, int position)
                                                   strtoqstr(pluginInstance->getIdentifier())));
         m_guis[instrument][position] = gui;
 
-    } catch (Exception e) {
+    } catch (const Exception &e) {
 
-        RG_DEBUG << "AudioPluginOSCGUIManager::startGUI: failed to start GUI: "
-        << e.getMessage() << endl;
+        RG_WARNING << "startGUI(): failed to start GUI: " << e.getMessage();
     }
 }
 
 void
 AudioPluginOSCGUIManager::showGUI(InstrumentId instrument, int position)
 {
-    RG_DEBUG << "AudioPluginOSCGUIManager::showGUI: " << instrument << "," << position
-    << endl;
+    RG_DEBUG << "showGUI(): " << instrument << "," << position;
 
     if (m_guis.find(instrument) != m_guis.end() &&
         m_guis[instrument].find(position) != m_guis[instrument].end()) {
@@ -231,21 +225,21 @@ AudioPluginOSCGUIManager::stopAllGUIs()
 void
 AudioPluginOSCGUIManager::postMessage(OSCMessage *message)
 {
-    RG_DEBUG << "AudioPluginOSCGUIManager::postMessage";
+    RG_DEBUG << "postMessage()";
+
     m_oscBuffer.write(&message, 1);
 }
 
 void
 AudioPluginOSCGUIManager::updateProgram(InstrumentId instrument, int position)
 {
-    RG_DEBUG << "AudioPluginOSCGUIManager::updateProgram(" << instrument << ","
-    << position << ")" << endl;
+    RG_DEBUG << "updateProgram(" << instrument << "," << position << ")";
 
     if (m_guis.find(instrument) == m_guis.end() ||
         m_guis[instrument].find(position) == m_guis[instrument].end())
         return ;
 
-    PluginContainer *container = 0;
+    PluginContainer *container = nullptr;
     container = m_studio->getContainerById(instrument);
     if (!container) return;
 
@@ -259,8 +253,7 @@ AudioPluginOSCGUIManager::updateProgram(InstrumentId instrument, int position)
     int bank = rv >> 16;
     int program = rv - (bank << 16);
 
-    RG_DEBUG << "AudioPluginOSCGUIManager::updateProgram(" << instrument << ","
-    << position << "): rv " << rv << ", bank " << bank << ", program " << program << endl;
+    RG_DEBUG << "updateProgram(" << instrument << "," << position << "): rv " << rv << ", bank " << bank << ", program " << program;
 
     m_guis[instrument][position]->sendProgram(bank, program);
 }
@@ -269,14 +262,13 @@ void
 AudioPluginOSCGUIManager::updatePort(InstrumentId instrument, int position,
                                      int port)
 {
-    RG_DEBUG << "AudioPluginOSCGUIManager::updatePort(" << instrument << ","
-    << position << "," << port << ")" << endl;
+    RG_DEBUG << "updatePort(" << instrument << "," << position << "," << port << ")";
 
     if (m_guis.find(instrument) == m_guis.end() ||
         m_guis[instrument].find(position) == m_guis[instrument].end())
         return ;
 
-    PluginContainer *container = 0;
+    PluginContainer *container = nullptr;
     container = m_studio->getContainerById(instrument);
     if (!container) return;
 
@@ -288,8 +280,7 @@ AudioPluginOSCGUIManager::updatePort(InstrumentId instrument, int position,
     if (!porti)
         return ;
 
-    RG_DEBUG << "AudioPluginOSCGUIManager::updatePort(" << instrument << ","
-    << position << "," << port << "): value " << porti->value << endl;
+    RG_DEBUG << "updatePort(" << instrument << "," << position << "," << port << "): value " << porti->value;
 
     m_guis[instrument][position]->sendPortValue(port, porti->value);
 }
@@ -298,8 +289,7 @@ void
 AudioPluginOSCGUIManager::updateConfiguration(InstrumentId instrument, int position,
         QString key)
 {
-    RG_DEBUG << "AudioPluginOSCGUIManager::updateConfiguration(" << instrument << ","
-    << position << "," << key << ")" << endl;
+    RG_DEBUG << "updateConfiguration(" << instrument << "," << position << "," << key << ")";
 
     if (m_guis.find(instrument) == m_guis.end() ||
             m_guis[instrument].find(position) == m_guis[instrument].end())
@@ -313,8 +303,7 @@ AudioPluginOSCGUIManager::updateConfiguration(InstrumentId instrument, int posit
 
     QString value = strtoqstr(pluginInstance->getConfigurationValue(qstrtostr(key)));
 
-    RG_DEBUG << "AudioPluginOSCGUIManager::updatePort(" << instrument << ","
-    << position << "," << key << "): value " << value << endl;
+    RG_DEBUG << "updateConfiguration(" << instrument << "," << position << "," << key << "): value " << value;
 
     m_guis[instrument][position]->sendConfiguration(key, value);
 }
@@ -355,7 +344,8 @@ bool
 AudioPluginOSCGUIManager::parseOSCPath(QString path, InstrumentId &instrument,
                                        int &position, QString &method)
 {
-    RG_DEBUG << "AudioPluginOSCGUIManager::parseOSCPath(" << path << ")";
+    RG_DEBUG << "parseOSCPath(" << path << ")";
+
     if (!m_studio)
         return false;
 
@@ -366,8 +356,7 @@ AudioPluginOSCGUIManager::parseOSCPath(QString path, InstrumentId &instrument,
     }
 
     if (!path.startsWith(pluginStr)) {
-        RG_DEBUG << "AudioPluginOSCGUIManager::parseOSCPath: malformed path "
-        << path << endl;
+        RG_WARNING << "parseOSCPath(): malformed path " << path;
         return false;
     }
 
@@ -380,7 +369,7 @@ AudioPluginOSCGUIManager::parseOSCPath(QString path, InstrumentId &instrument,
     method = path.section('/', -1, -1);
 
     if (instrumentStr.isEmpty() || positionStr.isEmpty() ) {
-        RG_DEBUG << "AudioPluginOSCGUIManager::parseOSCPath: no instrument or position in " << path;
+        RG_WARNING << "parseOSCPath(): no instrument or position in " << path;
         return false;
     }
 
@@ -395,16 +384,13 @@ AudioPluginOSCGUIManager::parseOSCPath(QString path, InstrumentId &instrument,
     // check the label
     PluginContainer *container = m_studio->getContainerById(instrument);
     if (!container) {
-        RG_DEBUG << "AudioPluginOSCGUIManager::parseOSCPath: no such instrument or buss as "
-        << instrument << " in path " << path << endl;
+        RG_WARNING << "parseOSCPath(): no such instrument or buss as " << instrument << " in path " << path;
         return false;
     }
 
     AudioPluginInstance *pluginInstance = container->getPlugin(position);
     if (!pluginInstance) {
-        RG_DEBUG << "AudioPluginOSCGUIManager::parseOSCPath: no plugin at position "
-        << position << " for instrument " << instrument << " in path "
-        << path << endl;
+        RG_WARNING << "parseOSCPath(): no plugin at position " << position << " for instrument " << instrument << " in path " << path;
         return false;
     }
 
@@ -412,15 +398,11 @@ AudioPluginOSCGUIManager::parseOSCPath(QString path, InstrumentId &instrument,
     QString iType, iSoName, iLabel;
     PluginIdentifier::parseIdentifier(identifier, iType, iSoName, iLabel);
     if (iLabel != label) {
-        RG_DEBUG << "AudioPluginOSCGUIManager::parseOSCPath: wrong label for plugin"
-        << " at position " << position << " for instrument " << instrument
-        << " in path " << path << " (actual label is " << iLabel
-        << ")" << endl;
+        RG_WARNING << "parseOSCPath(): wrong label for plugin at position " << position << " for instrument " << instrument << " in path " << path << " (actual label is " << iLabel << ")";
         return false;
     }
 
-    RG_DEBUG << "AudioPluginOSCGUIManager::parseOSCPath: good path " << path
-    << ", got mapped id " << pluginInstance->getMappedId() << endl;
+    RG_DEBUG << "parseOSCPath(): good path " << path << ", got mapped id " << pluginInstance->getMappedId();
 
     return true;
 }
@@ -457,7 +439,7 @@ AudioPluginOSCGUIManager::dispatch()
 
     while (m_oscBuffer.getReadSpace() > 0) {
 
-        OSCMessage *message = 0;
+        OSCMessage *message = nullptr;
         m_oscBuffer.read(&message, 1);
 
         int instrument = message->getTarget();
@@ -469,14 +451,12 @@ AudioPluginOSCGUIManager::dispatch()
         AudioPluginInstance *pluginInstance = container->getPlugin(position);
         if (!pluginInstance) continue;
 
-        AudioPluginOSCGUI *gui = 0;
+        AudioPluginOSCGUI *gui = nullptr;
 
         if (m_guis.find(instrument) == m_guis.end()) {
-            RG_DEBUG << "AudioPluginOSCGUIManager: no GUI for instrument "
-            << instrument << endl;
+            RG_DEBUG << "dispatch(): no GUI for instrument " << instrument;
         } else if (m_guis[instrument].find(position) == m_guis[instrument].end()) {
-            RG_DEBUG << "AudioPluginOSCGUIManager: no GUI for instrument "
-            << instrument << ", position " << position << endl;
+            RG_DEBUG << "dispatch(): no GUI for instrument " << instrument << ", position " << position;
         } else {
             gui = m_guis[instrument][position];
         }
@@ -493,46 +473,37 @@ AudioPluginOSCGUIManager::dispatch()
         if (method == "control") {
 
             if (message->getArgCount() != 2) {
-                RG_DEBUG << "AudioPluginOSCGUIManager: wrong number of args ("
-                << message->getArgCount() << ") for control method"
-                << endl;
+                RG_WARNING << "dispatch(): wrong number of args (" << message->getArgCount() << ") for control method";
                 goto done;
             }
             if (!(arg = message->getArg(0, type)) || type != 'i') {
-                RG_DEBUG << "AudioPluginOSCGUIManager: failed to get port number"
-                << endl;
+                RG_WARNING << "dispatch(): failed to get port number";
                 goto done;
             }
             int port = arg->i;
             if (!(arg = message->getArg(1, type)) || type != 'f') {
-                RG_DEBUG << "AudioPluginOSCGUIManager: failed to get port value"
-                << endl;
+                RG_WARNING << "dispatch(): failed to get port value";
                 goto done;
             }
             float value = arg->f;
 
-            RG_DEBUG << "AudioPluginOSCGUIManager: setting port " << port
-            << " to value " << value << endl;
+            RG_DEBUG << "dispatch(): setting port " << port << " to value " << value;
 
             m_mainWindow->slotChangePluginPort(instrument, position, port, value);
 
         } else if (method == "program") {
 
             if (message->getArgCount() != 2) {
-                RG_DEBUG << "AudioPluginOSCGUIManager: wrong number of args ("
-                << message->getArgCount() << ") for program method"
-                << endl;
+                RG_WARNING << "dispatch(): wrong number of args (" << message->getArgCount() << ") for program method";
                 goto done;
             }
             if (!(arg = message->getArg(0, type)) || type != 'i') {
-                RG_DEBUG << "AudioPluginOSCGUIManager: failed to get bank number"
-                << endl;
+                RG_WARNING << "dispatch(): failed to get bank number";
                 goto done;
             }
             int bank = arg->i;
             if (!(arg = message->getArg(1, type)) || type != 'i') {
-                RG_DEBUG << "AudioPluginOSCGUIManager: failed to get program number"
-                << endl;
+                RG_WARNING << "dispatch(): failed to get program number";
                 goto done;
             }
             int program = arg->i;
@@ -545,21 +516,17 @@ AudioPluginOSCGUIManager::dispatch()
         } else if (method == "update") {
 
             if (message->getArgCount() != 1) {
-                RG_DEBUG << "AudioPluginOSCGUIManager: wrong number of args ("
-                << message->getArgCount() << ") for update method"
-                << endl;
+                RG_WARNING << "dispatch(): wrong number of args (" << message->getArgCount() << ") for update method";
                 goto done;
             }
             if (!(arg = message->getArg(0, type)) || type != 's') {
-                RG_DEBUG << "AudioPluginOSCGUIManager: failed to get GUI URL"
-                << endl;
+                RG_WARNING << "dispatch(): failed to get GUI URL";
                 goto done;
             }
             QString url = &arg->s;
 
             if (!gui) {
-                RG_DEBUG << "AudioPluginOSCGUIManager: no GUI for update method"
-                << endl;
+                RG_WARNING << "dispatch(): no GUI for update method";
                 goto done;
             }
 
@@ -579,8 +546,7 @@ AudioPluginOSCGUIManager::dispatch()
                 }
 #endif
 
-                RG_DEBUG << "update: configuration: " << key << " -> "
-                << value << endl;
+                RG_DEBUG << "dispatch(): update: configuration: " << key << " -> " << value;
 
                 gui->sendConfiguration(key, value);
             }
@@ -606,22 +572,18 @@ AudioPluginOSCGUIManager::dispatch()
         } else if (method == "configure") {
 
             if (message->getArgCount() != 2) {
-                RG_DEBUG << "AudioPluginOSCGUIManager: wrong number of args ("
-                << message->getArgCount() << ") for configure method"
-                << endl;
+                RG_WARNING << "dispatch(): wrong number of args (" << message->getArgCount() << ") for configure method";
                 goto done;
             }
 
             if (!(arg = message->getArg(0, type)) || type != 's') {
-                RG_DEBUG << "AudioPluginOSCGUIManager: failed to get configure key"
-                << endl;
+                RG_WARNING << "dispatch(): failed to get configure key";
                 goto done;
             }
             QString key = &arg->s;
 
             if (!(arg = message->getArg(1, type)) || type != 's') {
-                RG_DEBUG << "AudioPluginOSCGUIManager: failed to get configure value"
-                << endl;
+                RG_WARNING << "dispatch(): failed to get configure value";
                 goto done;
             }
             QString value = &arg->s;
@@ -630,13 +592,12 @@ AudioPluginOSCGUIManager::dispatch()
 
             if (key.startsWith(DSSI_RESERVED_CONFIGURE_PREFIX) ||
                     key == PluginIdentifier::RESERVED_PROJECT_DIRECTORY_KEY) {
-                RG_DEBUG << "AudioPluginOSCGUIManager: illegal reserved configure call from gui: " << key << " -> " << value;
+                RG_WARNING << "dispatch(): illegal reserved configure call from gui: " << key << " -> " << value;
                 goto done;
             }
 #endif
 
-            RG_DEBUG << "AudioPluginOSCGUIManager: configure(" << key << "," << value
-            << ")" << endl;
+            RG_DEBUG << "dispatch(): configure(" << key << "," << value << ")";
 
             m_mainWindow->slotChangePluginConfiguration(instrument, position,
 #ifdef DSSI_GLOBAL_CONFIGURE_PREFIX
@@ -649,46 +610,53 @@ AudioPluginOSCGUIManager::dispatch()
         } else if (method == "midi") {
 
             if (message->getArgCount() != 1) {
-                RG_DEBUG << "AudioPluginOSCGUIManager: wrong number of args ("
-                << message->getArgCount() << ") for midi method"
-                << endl;
+                RG_WARNING << "dispatch(): wrong number of args (" << message->getArgCount() << ") for midi method";
                 goto done;
             }
             if (!(arg = message->getArg(0, type)) || type != 'm') {
-                RG_DEBUG << "AudioPluginOSCGUIManager: failed to get MIDI event"
-                << endl;
+                RG_WARNING << "dispatch(): failed to get MIDI event";
                 goto done;
             }
 
-            RG_DEBUG << "AudioPluginOSCGUIManager: handling MIDI message";
+            RG_DEBUG << "dispatch(): handling MIDI message...";
 
-            // let's only handle note on and note off
+            int eventType = arg->m[1] & MIDI_MESSAGE_TYPE_MASK;
 
-            int eventCode = arg->m[1];
-            int eventType = eventCode & MIDI_MESSAGE_TYPE_MASK;
-            if (eventType == MIDI_NOTE_ON ||
-                    eventType == MIDI_NOTE_OFF) {
-                MappedEvent ev(instrument,
-                               MappedEvent::MidiNote,
-                               MidiByte(arg->m[2]),
-                               MidiByte(arg->m[3]),
-                               RealTime::zeroTime,
-                               RealTime::zeroTime,
-                               RealTime::zeroTime);
-                if (eventType == MIDI_NOTE_OFF)
-                    ev.setVelocity(0);
-                StudioControl::sendMappedEvent(ev);
+            if (eventType == MIDI_NOTE_ON) {
+
+                // ??? The note will not be heard until a Track is
+                //     configured with this Instrument.  Why?  Can
+                //     this be fixed?
+
+                // Send a NOTE ON.
+                // We use a special duration (-1) to indicate no NOTE OFF.
+                StudioControl::playPreviewNote(
+                        m_studio->getInstrumentById(instrument),  // instrument
+                        MidiByte(arg->m[2]),  // pitch
+                        MidiByte(arg->m[3]),  // velocity
+                        RealTime(-1, 0),  // duration, -1 => NOTE ON ONLY
+                        false);  // oneshot
+
+            } else if (eventType == MIDI_NOTE_OFF) {
+
+                // Send a NOTE OFF.
+                StudioControl::playPreviewNote(
+                        m_studio->getInstrumentById(instrument),  // instrument
+                        MidiByte(arg->m[2]),  // pitch
+                        0,  // velocity, 0 => NOTE OFF
+                        RealTime(0, 1),  // duration, (shortest)
+                        false);  // oneshot
             }
 
         } else if (method == "exiting") {
 
-            RG_DEBUG << "AudioPluginOSCGUIManager: GUI exiting";
+            RG_DEBUG << "dispatch(): GUI exiting";
             stopGUI(instrument, position);
             m_mainWindow->slotPluginGUIExited(instrument, position);
 
         } else {
 
-            RG_DEBUG << "AudioPluginOSCGUIManager: unknown method " << method;
+            RG_DEBUG << "dispatch(): unknown method " << method;
         }
 
 done:
