@@ -230,9 +230,8 @@ void AudioStrip::createWidgets()
 
     if (isInput()) {
 
-        IconLoader iconLoader;
-        m_monoPixmap = iconLoader.loadPixmap("mono-tiny");
-        m_stereoPixmap = iconLoader.loadPixmap("stereo-tiny");
+        m_monoPixmap = IconLoader::loadPixmap("mono-tiny");
+        m_stereoPixmap = IconLoader::loadPixmap("stereo-tiny");
 
         m_stereoButton = new QPushButton(this);
         m_stereoButton->setIcon(m_monoPixmap);
@@ -540,18 +539,14 @@ AudioStrip::slotFaderLevelChanged(float dB)
         //     a waste.  Especially with a potentially very frequent
         //     update such as this.
 
-        if (m_externalControllerChannel < 16) {
+        if (ExternalController::self()->isNative()  &&
+            m_externalControllerChannel < 16) {
             int value = AudioLevel::dB_to_fader(
                     dB, 127, AudioLevel::LongFader);
 
-            MappedEvent mE(m_id,
-                           MappedEvent::MidiController,
-                           MIDI_CONTROLLER_VOLUME,
-                           MidiByte(value));
-            mE.setRecordedChannel(m_externalControllerChannel);
-            mE.setRecordedDevice(Device::CONTROL_DEVICE);
-
-            StudioControl::sendMappedEvent(mE);
+            ExternalController::send(
+                    m_externalControllerChannel,
+                    MIDI_CONTROLLER_VOLUME, MidiByte(value));
         }
 
         return;
@@ -590,7 +585,7 @@ AudioStrip::slotPanChanged(float pan)
         if (!instrument)
             return;
 
-        instrument->setPan(MidiByte(pan + 100.0));
+        instrument->setPan(MidiByte(lround(pan + 100.0)));
         Instrument::emitControlChange(instrument, MIDI_CONTROLLER_PAN);
         doc->setModified();
 
@@ -600,21 +595,15 @@ AudioStrip::slotPanChanged(float pan)
         //     a waste.  Especially with a potentially very frequent
         //     update such as this.
 
-        if (m_externalControllerChannel < 16) {
-            int ipan = (int(instrument->getPan()) * 64) / 100;
-            if (ipan < 0)
-                ipan = 0;
-            if (ipan > 127)
-                ipan = 127;
+        if (ExternalController::self()->isNative()  &&
+            m_externalControllerChannel < 16) {
+            MidiByte pan = AudioLevel::MIDIPanI(instrument->getPan());
+            if (pan > 127)
+                pan = 127;
 
-            MappedEvent mE(m_id,
-                           MappedEvent::MidiController,
-                           MIDI_CONTROLLER_PAN,
-                           MidiByte(ipan));
-            mE.setRecordedChannel(m_externalControllerChannel);
-            mE.setRecordedDevice(Device::CONTROL_DEVICE);
-
-            StudioControl::sendMappedEvent(mE);
+            ExternalController::send(
+                    m_externalControllerChannel,
+                    MIDI_CONTROLLER_PAN, pan);
         }
 
         return;
@@ -654,38 +643,7 @@ AudioStrip::updateExternalController()
     if (!instrument)
         return;
 
-    // Send a volume controller message to the external controller port.
-
-    float dB = instrument->getLevel();
-
-    int value = AudioLevel::dB_to_fader(
-            dB, 127, AudioLevel::LongFader);
-
-    MappedEvent volumeEvent(m_id,
-                            MappedEvent::MidiController,
-                            MIDI_CONTROLLER_VOLUME,
-                            MidiByte(value));
-    volumeEvent.setRecordedChannel(m_externalControllerChannel);
-    volumeEvent.setRecordedDevice(Device::CONTROL_DEVICE);
-
-    StudioControl::sendMappedEvent(volumeEvent);
-
-    // Send a pan controller message to the external controller port.
-
-    int ipan = (int(instrument->getPan()) * 64) / 100;
-    if (ipan < 0)
-        ipan = 0;
-    if (ipan > 127)
-        ipan = 127;
-
-    MappedEvent panEvent(m_id,
-                         MappedEvent::MidiController,
-                         MIDI_CONTROLLER_PAN,
-                         MidiByte(ipan));
-    panEvent.setRecordedChannel(m_externalControllerChannel);
-    panEvent.setRecordedDevice(Device::CONTROL_DEVICE);
-
-    StudioControl::sendMappedEvent(panEvent);
+    ExternalController::sendAllCCs(instrument, m_externalControllerChannel);
 }
 
 void
