@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -63,7 +63,7 @@ public:
                      DeviceId defaultDevice =
                      Device::NO_DEVICE);
 
-    ~BankEditorDialog();
+    ~BankEditorDialog() override;
 
     // Initialize the devices/banks and programs - the whole lot
     //
@@ -128,7 +128,7 @@ signals:
     void deviceNamesChanged();
 
 protected:
-    virtual void closeEvent(QCloseEvent*);
+    void closeEvent(QCloseEvent*) override;
 
     void resetProgramList();
     void setProgramList(MidiDevice *device);
