@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -20,14 +20,11 @@
 #include "ControlEditorDialog.h"
 
 #include "misc/Debug.h"
-#include "misc/Strings.h"
-#include "base/Colour.h"
+#include "misc/Strings.h"  // for strtoqstr() etc...
 #include "base/Composition.h"
 #include "base/ControlParameter.h"
-#include "base/Device.h"
-#include "base/Event.h"
 #include "base/MidiDevice.h"
-#include "base/MidiTypes.h"
+#include "base/MidiTypes.h"  // for PitchBend::EventType
 #include "base/Studio.h"
 #include "commands/studio/AddControlParameterCommand.h"
 #include "commands/studio/ModifyControlParameterCommand.h"
@@ -35,30 +32,22 @@
 #include "ControlParameterEditDialog.h"
 #include "ControlParameterItem.h"
 #include "document/RosegardenDocument.h"
-#include "misc/ConfigGroups.h"
+#include "misc/ConfigGroups.h"  // for WindowGeometryConfigGroup
 #include "document/Command.h"
 #include "document/CommandHistory.h"
 #include "gui/dialogs/AboutDialog.h"
 
-#include <QShortcut>
-#include <QMainWindow>
-#include <QLayout>
-#include <QApplication>
-#include <QAction>
 #include <QTreeWidget>
 #include <QColor>
 #include <QDialog>
 #include <QFrame>
 #include <QLabel>
-#include <QTreeWidget>
 #include <QPixmap>
 #include <QPushButton>
 #include <QSizePolicy>
 #include <QString>
-#include <QToolTip>
 #include <QWidget>
 #include <QVBoxLayout>
-#include <QList>
 #include <QSettings>
 #include <QDesktopServices>
 
@@ -67,17 +56,14 @@ namespace Rosegarden
 {
 
 
-ControlEditorDialog::ControlEditorDialog
-        (
-            QWidget *parent,
-            RosegardenDocument *doc,
-            DeviceId device
-       ):
-        QMainWindow(parent),
-        m_studio(&doc->getStudio()),
-        m_doc(doc),
-        m_device(device),
-        m_modified(false)
+ControlEditorDialog::ControlEditorDialog(QWidget *parent,
+                                         RosegardenDocument *doc,
+                                         DeviceId device) :
+    QMainWindow(parent),
+    m_doc(doc),
+    m_studio(&doc->getStudio()),
+    m_device(device),
+    m_modified(false)
 {
     RG_DEBUG << "ControlEditorDialog::ControlEditorDialog: device is " << m_device;
 
@@ -154,19 +140,19 @@ ControlEditorDialog::ControlEditorDialog
     layout->addWidget(m_closeButton);
     layout->addSpacing(5);
 
-    connect(m_addButton, SIGNAL(released()),
-            SLOT(slotAdd()));
+    connect(m_addButton, &QAbstractButton::released,
+            this, &ControlEditorDialog::slotAdd);
 
-    connect(m_deleteButton, SIGNAL(released()),
-            SLOT(slotDelete()));
+    connect(m_deleteButton, &QAbstractButton::released,
+            this, &ControlEditorDialog::slotDelete);
 
     setupActions();
 
     connect(CommandHistory::getInstance(), SIGNAL(commandExecuted()),
             this, SLOT(slotUpdate()));
 
-    connect(m_treeWidget, SIGNAL(itemDoubleClicked(QTreeWidgetItem *, int)),
-            SLOT(slotEdit(QTreeWidgetItem *, int)));
+    connect(m_treeWidget, &QTreeWidget::itemDoubleClicked,
+            this, &ControlEditorDialog::slotEdit);
 
     // Highlight all columns - enable extended selection mode
     //
@@ -221,7 +207,7 @@ ControlEditorDialog::slotUpdate(bool added)
         return ;
 
     ControlList::const_iterator it = md->beginControllers();
-    ControlParameterItem *item = 0;
+    ControlParameterItem *item = nullptr;
     int i = 0;
 
     // Attempt to track last controller selected so we can reselect it
@@ -237,7 +223,7 @@ ControlEditorDialog::slotUpdate(bool added)
         Composition &comp = m_doc->getComposition();
 
         QString colour =
-            strtoqstr(comp.getGeneralColourMap().getNameByIndex(it->getColourIndex()));
+            strtoqstr(comp.getGeneralColourMap().getName(it->getColourIndex()));
 
         if (colour == "")
             colour = tr("<default>");
@@ -247,8 +233,8 @@ ControlEditorDialog::slotUpdate(bool added)
             position = tr("<not showing>");
 
         QString value;
-        value.sprintf("%d (0x%x)", it->getControllerValue(),
-                      it->getControllerValue());
+        value.sprintf("%d (0x%x)", it->getControllerNumber(),
+                      it->getControllerNumber());
 
         if (it->getType() == PitchBend::EventType) {
             item = new ControlParameterItem(
@@ -290,8 +276,8 @@ ControlEditorDialog::slotUpdate(bool added)
         // create and set a colour pixmap
         //
         QPixmap colourPixmap(16, 16);
-        Colour c = comp.getGeneralColourMap().getColourByIndex(it->getColourIndex());
-        colourPixmap.fill(QColor(c.getRed(), c.getGreen(), c.getBlue()));
+        QColor c = comp.getGeneralColourMap().getColour(it->getColourIndex());
+        colourPixmap.fill(QColor(c.red(), c.green(), c.blue()));
         
         item->setIcon(7, QIcon(colourPixmap));
 
@@ -335,20 +321,6 @@ ControlEditorDialog::slotUpdate(bool added)
     }
 }
 
-/*
-void
-ControlEditorDialog::slotEditCopy()
-{
-    RG_DEBUG << "ControlEditorDialog::slotEditCopy";
-}
-
-void
-ControlEditorDialog::slotEditPaste()
-{
-    RG_DEBUG << "ControlEditorDialog::slotEditPaste";
-}
-*/
-
 void
 ControlEditorDialog::slotAdd()
 {
@@ -386,7 +358,7 @@ ControlEditorDialog::slotClose()
 {
     RG_DEBUG << "ControlEditorDialog::slotClose";
 
-    m_doc = 0;
+    m_doc = nullptr;
 
     close();
 }
@@ -396,7 +368,7 @@ ControlEditorDialog::setupActions()
 {
     createAction("file_close", SLOT(slotClose()));
     m_closeButton->setText(tr("Close"));
-    connect(m_closeButton, SIGNAL(released()), this, SLOT(slotClose()));
+    connect(m_closeButton, &QAbstractButton::released, this, &ControlEditorDialog::slotClose);
     createAction("control_help", SLOT(slotHelpRequested()));
     createAction("help_about_app", SLOT(slotHelpAbout()));
 
@@ -421,14 +393,6 @@ ControlEditorDialog::setModified(bool modified)
     m_modified = modified;
 }
 
-void
-ControlEditorDialog::checkModified()
-{
-    RG_DEBUG << "ControlEditorDialog::checkModified(" << m_modified << ")"
-    << endl;
-
-}
-
 void
 ControlEditorDialog::slotEdit(QTreeWidgetItem *i, int)
 {
@@ -464,18 +428,6 @@ ControlEditorDialog::closeEvent(QCloseEvent*)
     close();
 }
 
-void
-ControlEditorDialog::setDocument(RosegardenDocument *doc)
-{
-    // reset our pointers
-    m_doc = doc;
-    m_studio = &doc->getStudio();
-    m_modified = false;
-
-    slotUpdate();
-}
-
-
 void
 ControlEditorDialog::slotHelpRequested()
 {
