@@ -22,7 +22,6 @@
 #include "gui/widgets/LineEdit.h"
 #include "misc/Debug.h"
 #include "misc/Strings.h"
-#include "base/Colour.h"
 #include "base/ColourMap.h"
 #include "base/ControlParameter.h"
 #include "base/Event.h"
@@ -177,13 +176,15 @@ ControlParameterEditDialog::ControlParameterEditDialog(
     //
     //
     ColourMap &colourMap = m_doc->getComposition().getGeneralColourMap();
-    RCMap::const_iterator it;
+    ColourMap::MapType::const_iterator it;
     QPixmap colourPixmap(16, 16);
 
-    for (it = colourMap.begin(); it != colourMap.end(); ++it) {
-        Colour c = it->second.first;
-        colourPixmap.fill(QColor(c.getRed(), c.getGreen(), c.getBlue()));
-        m_colourCombo->addItem(colourPixmap, strtoqstr(it->second.second));
+    for (it = colourMap.colours.begin();
+         it != colourMap.colours.end();
+         ++it) {
+        QColor c = it->second.colour;
+        colourPixmap.fill(QColor(c.red(), c.green(), c.blue()));
+        m_colourCombo->addItem(colourPixmap, strtoqstr(it->second.name));
     }
 
     // Populate IPB position combo
@@ -222,10 +223,10 @@ ControlParameterEditDialog::populate()
     m_nameEdit->setText(strtoqstr(m_control->getName()));
 
     m_description->setText(strtoqstr(m_control->getDescription()));
-    m_controllerBox->setValue(int(m_control->getControllerValue()));
+    m_controllerBox->setValue(int(m_control->getControllerNumber()));
 
     QString hexValue;
-    hexValue.sprintf("(0x%x)", m_control->getControllerValue());
+    hexValue.sprintf("(0x%x)", m_control->getControllerNumber());
     m_hexValue->setText(hexValue);
 
     m_minBox->setValue(m_control->getMin());
@@ -234,13 +235,15 @@ ControlParameterEditDialog::populate()
 
     int pos = 0, setItem = 0;
     ColourMap &colourMap = m_doc->getComposition().getGeneralColourMap();
-    RCMap::const_iterator it;
+    ColourMap::MapType::const_iterator it;
 
     // I can't believe we never fixed this in all these years.  The way this was
     // structured, it was impossible for setItem to increment in order to arrive
     // at any useful value, so the color always came out "Default" 100% of the
     // time.
-    for (it = colourMap.begin(); it != colourMap.end(); ++it) {
+    for (it = colourMap.colours.begin();
+         it != colourMap.colours.end();
+         ++it) {
         pos++;
         if (m_control->getColourIndex() == it->first) setItem = (pos - 1);
     }
@@ -302,7 +305,7 @@ void
 ControlParameterEditDialog::slotControllerChanged(int value)
 {
     RG_DEBUG << "ControlParameterEditDialog::slotControllerChanged";
-    m_dialogControl.setControllerValue(value);
+    m_dialogControl.setControllerNumber(value);
 
     // set hex value
     QString hexValue;
