@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -39,7 +39,7 @@ public:
     MidiKeyMapTreeWidgetItem(DeviceId deviceId,
                            QTreeWidgetItem* parent, QString name);
 
-    virtual int compare(QTreeWidgetItem *i, int col, bool ascending) const;
+    int compare(QTreeWidgetItem *i, int col, bool ascending) const override;
 
     QString getName() const { return m_name; }
 
