@@ -4,7 +4,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -33,14 +33,14 @@ namespace Rosegarden
 class MidiMixerVUMeter : public VUMeter
 {
 public:
-    MidiMixerVUMeter(QWidget *parent = 0,
+    MidiMixerVUMeter(QWidget *parent = nullptr,
                      VUMeterType type = Plain,
                      int width = 0,
                      int height = 0);
 
 protected:
-     virtual void meterStart();
-     virtual void meterStop();
+     void meterStart() override;
+     void meterStop() override;
 
 private:
      int m_textHeight;
