@@ -22,7 +22,7 @@
 
 #include "MidiMixerWindow.h"
 
-#include "sound/Midi.h"
+#include "sound/Midi.h"  // For MIDI_CONTROLLER_VOLUME, etc...
 #include "misc/Debug.h"
 #include "misc/Strings.h"
 #include "base/Device.h"
@@ -44,7 +44,6 @@
 #include "MixerWindow.h"
 #include "sound/MappedEvent.h"
 #include "sound/SequencerDataBlock.h"
-#include "StudioControl.h"
 
 #include <QAction>
 #include <QColor>
@@ -96,6 +95,11 @@ MidiMixerWindow::MidiMixerWindow(QWidget *parent,
     connect(Instrument::getStaticSignals().data(),
                 &InstrumentStaticSignals::controlChange,
             this, &MidiMixerWindow::slotControlChange);
+
+    connect(ExternalController::self().data(),
+                &ExternalController::externalControllerMMW,
+            this, &MidiMixerWindow::slotExternalController);
+
 }
 
 void
@@ -125,7 +129,7 @@ MidiMixerWindow::setupTabs()
             this, &MidiMixerWindow::slotCurrentTabChanged);
     m_tabWidget->setTabPosition(QTabWidget::South);
     setWindowTitle(tr("MIDI Mixer"));
-    setWindowIcon(IconLoader().loadPixmap("window-midimixer"));
+    setWindowIcon(IconLoader::loadPixmap("window-midimixer"));
 
 
     for (it = m_studio->begin(); it != m_studio->end(); ++it) {
@@ -309,7 +313,8 @@ MidiMixerWindow::slotFaderLevelChanged(float value)
                 Instrument::emitControlChange(instrument, MIDI_CONTROLLER_VOLUME);
                 m_document->setModified();
 
-                if (instrument->hasFixedChannel())
+                if (ExternalController::self()->isNative()  &&
+                    instrument->hasFixedChannel())
                 {
                     // Send out the external controller port as well.
                     
@@ -331,14 +336,9 @@ MidiMixerWindow::slotFaderLevelChanged(float value)
                         if (instrument->getDevice()->getId() == (*dit)->getId()) {
                             RG_DEBUG << "slotFaderLevelChanged: sending control device mapped event for channel " << instrument->getNaturalChannel();
 
-                            MappedEvent mE((*it)->m_id,
-                                           MappedEvent::MidiController,
-                                           MIDI_CONTROLLER_VOLUME,
-                                           MidiByte(value));
-
-                            mE.setRecordedChannel(instrument->getNaturalChannel());
-                            mE.setRecordedDevice(Device::CONTROL_DEVICE);
-                            StudioControl::sendMappedEvent(mE);
+                            ExternalController::send(
+                                    instrument->getNaturalChannel(),
+                                    MIDI_CONTROLLER_VOLUME, MidiByte(value));
                         }
                         break;
                     }
@@ -392,7 +392,8 @@ MidiMixerWindow::slotControllerChanged(float value)
         Instrument::emitControlChange(instrument, cc);
         m_document->setModified();
 
-        if (instrument->hasFixedChannel()) {
+        if (ExternalController::self()->isNative()  &&
+            instrument->hasFixedChannel()) {
 
             // Send out the external controller port as well.
 
@@ -412,15 +413,12 @@ MidiMixerWindow::slotControllerChanged(float value)
                 RG_DEBUG << "slotControllerChanged: device id = " << instrument->getDevice()->getId() << ", visible device id " << (*dit)->getId();
                 if (instrument->getDevice()->getId() == (*dit)->getId()) {
                     RG_DEBUG << "slotControllerChanged: sending control device mapped event for channel " << instrument->getNaturalChannel();
-                    // send out to external controllers as well.
-                    //!!! really want some notification of whether we have any!
-                    MappedEvent mE(m_faders[i]->m_id,
-                                   MappedEvent::MidiController,
-                                   m_faders[i]->m_controllerRotaries[j].first,
-                                   MidiByte(value));
-                    mE.setRecordedChannel(instrument->getNaturalChannel());
-                    mE.setRecordedDevice(Device::CONTROL_DEVICE);
-                    StudioControl::sendMappedEvent(mE);
+                    // send out to external controller port as well.
+                    // !!! really want some notification of whether we have any!
+                    ExternalController::send(
+                            instrument->getNaturalChannel(),
+                            m_faders[i]->m_controllerRotaries[j].first,
+                            MidiByte(value));
                 }
             }
         }
@@ -642,13 +640,9 @@ MidiMixerWindow::updateMonitorMeter()
 }
 
 void
-MidiMixerWindow::slotControllerDeviceEventReceived(MappedEvent *e,
-        const void *preferredCustomer)
+MidiMixerWindow::slotExternalController(const MappedEvent *e)
 {
-    if (preferredCustomer != this)
-        return ;
-
-    RG_DEBUG << "slotControllerDeviceEventReceived(): this one's for me";
+    //RG_DEBUG << "slotExternalController()...";
 
     // Some window managers (e.g. GNOME) do not allow the application to
     // change focus on the user.  So, this might not work.
@@ -695,7 +689,7 @@ MidiMixerWindow::slotControllerDeviceEventReceived(MappedEvent *e,
             for (ControlList::const_iterator controlIter = cl.begin();
                     controlIter != cl.end(); ++controlIter) {
                 if ((*controlIter).getControllerNumber() == controller) {
-                    RG_DEBUG << "slotControllerDeviceEventReceived(): Setting controller " << controller << " for instrument " << instrument->getId() << " to " << value;
+                    RG_DEBUG << "slotExternalController(): Setting controller " << controller << " for instrument " << instrument->getId() << " to " << value;
                     instrument->setControllerValue(controller, value);
                     Instrument::emitControlChange(instrument, controller);
                     m_document->setModified();
@@ -718,6 +712,11 @@ MidiMixerWindow::slotCurrentTabChanged(int)
 void
 MidiMixerWindow::sendControllerRefresh()
 {
+    // We only do this if the external controller port is
+    // in Rosegarden native mode.
+    if (!ExternalController::self()->isNative())
+        return;
+
     // To keep the device connected to the "external controller" port in
     // sync with the "MIDI Mixer" window, send out MIDI volume and pan
     // messages to it.
@@ -739,57 +738,34 @@ MidiMixerWindow::sendControllerRefresh()
             dit != m_studio->end(); ++dit) {
 
         MidiDevice *dev = dynamic_cast<MidiDevice*>(*dit);
+
         RG_DEBUG << "device is " << (*dit)->getId() << ", dev " << dev;
 
+        // Not a MIDI device?  Then try the next.
         if (!dev)
             continue;
+
         if (i != tabIndex) {
+            // Keep count of the MidiDevice's.
             ++i;
             continue;
         }
 
+        // Found the MidiDevice for this tab.
+
         InstrumentList instruments = dev->getPresentationInstruments();
-        ControlList controls = getIPBForMidiMixer(dev);
 
         RG_DEBUG << "device has" << instruments.size() << "presentation instruments," << dev->getAllInstruments().size() << " instruments";
 
-        for (InstrumentList::const_iterator iIt =
-                    instruments.begin(); iIt != instruments.end(); ++iIt) {
+        // For each Instrument
+        for (const Instrument *instrument : instruments) {
 
-            Instrument *instrument = *iIt;
-            if (!instrument->hasFixedChannel()) { continue; }
-            int channel = instrument->getNaturalChannel();
+            // No fixed channel?  Try the next.
+            if (!instrument->hasFixedChannel())
+                continue;
 
-            RG_DEBUG << "instrument is " << instrument->getId();
+            ExternalController::sendAllCCs(instrument);
 
-            for (ControlList::const_iterator cIt =
-                        controls.begin(); cIt != controls.end(); ++cIt) {
-
-                int controller = (*cIt).getControllerNumber();
-                int value;
-                try {
-                    value = instrument->getControllerValue(controller);
-                } catch (std::string s) {
-                    RG_WARNING << "Exception in MidiMixerWindow::currentChanged: " << s << " (controller " << controller << ", instrument " << instrument->getId() << ")";
-                    value = 0;
-                }
-
-                MappedEvent mE(instrument->getId(),
-                               MappedEvent::MidiController,
-                               controller, value);
-                mE.setRecordedChannel(channel);
-                mE.setRecordedDevice(Device::CONTROL_DEVICE);
-                StudioControl::sendMappedEvent(mE);
-            }
-
-            MappedEvent mE(instrument->getId(),
-                           MappedEvent::MidiController,
-                           MIDI_CONTROLLER_VOLUME,
-                           instrument->getVolume());
-            mE.setRecordedChannel(channel);
-            mE.setRecordedDevice(Device::CONTROL_DEVICE);
-            RG_DEBUG << "sending controller mapped event for channel " << channel << ", volume " << instrument->getVolume();
-            StudioControl::sendMappedEvent(mE);
         }
 
         break;
@@ -826,11 +802,12 @@ MidiMixerWindow::slotHelpAbout()
 ControlList
 MidiMixerWindow::getIPBForMidiMixer(MidiDevice *dev) const
 {
+    // ??? Instrument::getStaticControllers() might simplify all
+    //     this quite a bit.  See RosegardenMainWindow::changeEvent().
+
     ControlList controlList = dev->getIPBControlParameters();
     ControlList retList;
 
-    Rosegarden::MidiByte MIDI_CONTROLLER_VOLUME = 0x07;
-
     for (ControlList::const_iterator it = controlList.begin();
          it != controlList.end(); ++it)
     {
@@ -842,5 +819,31 @@ MidiMixerWindow::getIPBForMidiMixer(MidiDevice *dev) const
     return retList;
 }
 
+void
+MidiMixerWindow::changeEvent(QEvent *event)
+{
+    // Let baseclass handle first.
+    QWidget::changeEvent(event);
+
+    // We only care about this if the external controller port is
+    // in Rosegarden native mode.
+    if (!ExternalController::self()->isNative())
+        return;
+
+    // ??? Double updates seem to go out so we might want to be a little
+    //     more picky about the event we react to.
+
+    if (event->type() != QEvent::ActivationChange)
+        return;
+
+    if (!isActiveWindow())
+        return;
+
+    ExternalController::self()->activeWindow =
+            ExternalController::MidiMixer;
+
+    sendControllerRefresh();
+}
+
 
 }
