@@ -51,15 +51,6 @@ MixerWindow::closeEvent(QCloseEvent *e)
     QMainWindow::closeEvent(e);
 }
 
-void
-MixerWindow::windowActivationChange(bool)
-{
-    if (isActiveWindow()) {
-        emit windowActivated();
-        sendControllerRefresh();
-    }
-}
-
 void
 MixerWindow::slotClose()
 {
