@@ -20,6 +20,7 @@
 
 #include "base/Instrument.h"
 #include "base/MidiProgram.h"
+#include "gui/application/RosegardenMainViewWidget.h"
 
 #include <QMainWindow>
 
@@ -46,14 +47,12 @@ public:
 
 signals:
     void closing();
-    void windowActivated();
 
 protected slots:
     void slotClose();
 
 protected:
     void closeEvent(QCloseEvent *) override;
-    virtual void windowActivationChange(bool);
 
     /// Send MIDI volume and pan messages to the "external controller" port.
     /**
