@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -41,7 +41,7 @@ OSCMessage::clearArgs()
 void
 OSCMessage::addArg(char type, lo_arg *arg)
 {
-    lo_arg *newarg = 0;
+    lo_arg *newarg = nullptr;
 
     if (type == 's') {
 
