@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -18,9 +18,11 @@
 #ifndef RG_STUDIOCONTROL_H
 #define RG_STUDIOCONTROL_H
 
+#include "gui/seqmanager/ChannelManager.h"
 #include "base/MidiProgram.h"
 #include "sound/MappedCommon.h"
 #include "sound/MappedStudio.h"
+#include "base/RealTime.h"
 
 #include <QMutex>
 #include <QString>
@@ -30,12 +32,10 @@ namespace Rosegarden
 {
 
 
-class RealTime;
 class MappedInstrument;
 class MappedEvent;
 class MappedEventList;
 class Instrument;
-class ImmediateNote;
 
 
 /// Global interface for plugin, audio, and MIDI configuration.
@@ -187,18 +187,13 @@ public:
                                MidiByte controller, MidiByte value);
 
  private:
-    /// Creates the m_immediateNoteFiller in a thread-safe way and returns it.
-    /**
-     * Used by playPreviewNote() to generate the necessary events.
-     */
-    static ImmediateNote *getFiller(void);
-    /**
-     * Used by getFiller() to make sure creation of m_immediateNoteFiller
-     * is thread safe.
-     */
-    static QMutex m_instanceMutex;
-    /// Created and returned by getFiller().
-    static ImmediateNote *m_immediateNoteFiller;
+    static ChannelManager m_channelManager;
+
+    /// Used by playPreviewNote() to insert a note into a MappedEventList.
+    static void fillWithImmediateNote(
+            MappedEventList &mappedEventList, Instrument *instrument,
+            int pitch, int velocity, RealTime duration, bool oneshot);
+
 };
 
 }
