@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -40,7 +40,7 @@ namespace Rosegarden
 BaseTextFloat::BaseTextFloat(QWidget *parent) :
     QWidget(parent, Qt::ToolTip),
     m_text(""),
-    m_timer(0),
+    m_timer(nullptr),
     m_widget(parent),
     m_totalPos(QPoint(0, 0)),
     m_width(20),
@@ -52,7 +52,7 @@ BaseTextFloat::BaseTextFloat(QWidget *parent) :
 
     m_timer = new QTimer(this);
     m_timer->setSingleShot(true);
-    connect(m_timer, SIGNAL(timeout()), this, SLOT(slotTimeout()));
+    connect(m_timer, &QTimer::timeout, this, &BaseTextFloat::slotTimeout);
 }
 
 void
