@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -53,9 +53,9 @@ public:
      * Buttons that don't take the memory effect are always created in a checked
      * state initially.
      */
-    CheckButton(QString iconName, bool wantsMemory = true,  QWidget *parent = 0);
+    CheckButton(QString iconName, bool wantsMemory = true,  QWidget *parent = nullptr);
 
-    ~CheckButton();
+    ~CheckButton() override;
 };
 
 
