@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -35,11 +35,11 @@ InstrumentAliasButton::InstrumentAliasButton(QWidget *parent,
         QPushButton(parent),
         m_instrument(instrument)
 {
-    connect(this, SIGNAL(clicked()), this, SLOT(slotPressed()));
+    connect(this, &QAbstractButton::clicked, this, &InstrumentAliasButton::slotPressed);
     if (instrument) {
         // Make instrument tell us if it gets destroyed.
-        connect(instrument, SIGNAL(destroyed()),
-                this, SLOT(slotInstrumentGone()));
+        connect(instrument, &QObject::destroyed,
+                this, &InstrumentAliasButton::slotInstrumentGone);
     }
 }
 
@@ -64,9 +64,9 @@ InstrumentAliasButton::slotPressed()
 
 void
 InstrumentAliasButton::
-slotInstrumentGone(void)
+slotInstrumentGone()
 {
-    m_instrument = 0;
+    m_instrument = nullptr;
 }
 
 }
