@@ -39,8 +39,8 @@ namespace Rosegarden
 
 PluginControl::PluginControl(QWidget *parent,
                              ControlType type,
-                             PluginPort *port,
-                             AudioPluginManager *aPM,
+                             QSharedPointer<PluginPort> port,
+                             QSharedPointer<AudioPluginManager> aPM,
                              int index,
                              float initialValue,
                              bool showBounds):
