@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -34,7 +34,7 @@ ProgressBar::ProgressBar(/*int totalSteps, */
 {
 /*    setRange(0, totalSteps); */
 
-    connect (this, SIGNAL(valueChanged(int)), this, SLOT(WTF(int)));
+    connect (this, &QProgressBar::valueChanged, this, &ProgressBar::WTF);
 }
 
 ProgressBar::ProgressBar(int totalSteps,
@@ -43,7 +43,7 @@ ProgressBar::ProgressBar(int totalSteps,
 {
     setRange(0, totalSteps);
 
-    connect (this, SIGNAL(valueChanged(int)), this, SLOT(WTF(int)));
+    connect (this, &QProgressBar::valueChanged, this, &ProgressBar::WTF);
 }
 
 void
