@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -37,10 +37,10 @@ class ProgressBar : public QProgressBar
     Q_OBJECT
 
 public:
-    ProgressBar(QWidget *parent = 0);
+    ProgressBar(QWidget *parent = nullptr);
 
     ProgressBar(int totalSteps,
-                QWidget *parent = 0);
+                QWidget *parent = nullptr);
 
 public slots:
     void WTF(int);
