@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -15,6 +15,7 @@
     COPYING included with this distribution for more information.
 */
 
+#define RG_MODULE_STRING "[Rotary]"
 
 #include "Rotary.h"
 
@@ -119,8 +120,6 @@ Rotary::Rotary(QWidget *parent,
 
     this->setToolTip(tr("<qt><p>Click and drag up and down or left and right to modify.</p><p>Double click to edit value directly.</p></qt>"));
     setFixedSize(size, size);
-
-    emit valueChanged(m_snapPosition);
 }
 
 Rotary::~Rotary()
@@ -622,9 +621,12 @@ Rotary::mouseMoveEvent(QMouseEvent *e)
 void
 Rotary::wheelEvent(QWheelEvent *e)
 {
-    if (e->delta() > 0)
+    // We'll handle this.  Don't pass to parent.
+    e->accept();
+
+    if (e->angleDelta().y() > 0)
         m_position -= m_pageStep;
-    else
+    else if (e->angleDelta().y() < 0)
         m_position += m_pageStep;
 
     if (m_position > m_maximum)
