@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -25,11 +25,6 @@
 namespace Rosegarden
 {
 
-void
-TristateCheckBox::mouseReleaseEvent(QMouseEvent *)
-{}
-
-TristateCheckBox::~TristateCheckBox()
-{}
+// It's all already in the header.  Delete this file.
 
 }
