@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -57,13 +57,12 @@ public:
      * MIDI, audio, and the system timer are all functioning correctly.  This
      * widget is intended to be displayed on the status bar in the main window.
      */
-    WarningWidget(QWidget *parent = 0);
-    ~WarningWidget();
+    WarningWidget(QWidget *parent = nullptr);
+    ~WarningWidget() override;
 
     void setMidiWarning(const bool status);
     void setAudioWarning(const bool status);
     void setTimerWarning(const bool status);
-    void setGraphicsAdvisory(const bool status);
 
     /** Add a message (consisting of a text and an informative text) to the
      * queue.  These will be displayed via displayMessageQueue() when the user
@@ -83,7 +82,6 @@ protected:
     QLabel *m_timerIcon;
 
     QToolButton *m_warningButton;
-    QToolButton *m_graphicsButton;
     QToolButton *m_infoButton;
 
     QString m_text;
@@ -100,13 +98,6 @@ protected slots:
     /** Display the message queue in a suitable dialog, on demand
      */
     void displayMessageQueue();
-
-    /** Display the graphics advisory.  This is not treated as a warning, and
-     * not added to the queue, because running in "safe" (native) graphics mode
-     * is not considered a real "performance problem" in the same way as a slow
-     * kernel timer and so on.
-     */
-    void displayGraphicsAdvisory();
 };
 
 
