@@ -35,6 +35,7 @@
 #include "sound/SoundDriverFactory.h"
 #include "sound/MappedInstrument.h"
 #include "sound/MappedEventInserter.h"
+#include "sound/SequencerDataBlock.h"
 #include "gui/seqmanager/MEBIterator.h"
 #include "base/Profiler.h"
 #include "sound/PluginFactory.h"
@@ -104,7 +105,9 @@ RosegardenSequencer::RosegardenSequencer() :
     m_driver->setAudioBufferSizes(m_audioMix, m_audioRead, m_audioWrite,
                                   m_smallFileSize);
 
-    m_driver->setExternalTransportControl(this);
+    // Pass the RosegardenSequencer to AlsaDriver to avoid the need to
+    // call getInstance() and incur the overhead of a mutex.
+    m_driver->setSequencer(this);
 
     // Connect for high-frequency control change notifications.
     // Note that we must use a DirectConnection or else the signals may
@@ -138,14 +141,12 @@ RosegardenSequencer::cleanup()
 RosegardenSequencer *
 RosegardenSequencer::getInstance()
 {
+    // Lock required as both threads might get in here at the same time.
     m_instanceMutex.lock();
-    if (!m_instance) {
-#ifdef DEBUG_ROSEGARDEN_SEQUENCER        
-        SEQUENCER_DEBUG << "RosegardenSequencer::getInstance: Creating";
-#endif
+    if (!m_instance)
         m_instance = new RosegardenSequencer();
-    }
     m_instanceMutex.unlock();
+
     return m_instance;
 }
 
@@ -273,18 +274,22 @@ RosegardenSequencer::record(const RealTime &time,
         QVector<InstrumentId> armedInstruments =
             RosegardenMainWindow::self()->getArmedInstruments();
 
+        // Compute the list of armed audio instruments.
+        // ??? rename: armedAudioIntruments
         QVector<InstrumentId> audioInstruments;
         for (int i = 0; i < armedInstruments.size(); ++i) {
-            if (armedInstruments[i] >= AudioInstrumentBase &&
-                armedInstruments[i] < MidiInstrumentBase) {
+            // Audio Instrument?  Add to audioInstruments.
+            if (armedInstruments[i] >= AudioInstrumentBase  &&
+                armedInstruments[i] < MidiInstrumentBase)
                 audioInstruments.push_back(armedInstruments[i]);
-            }
         }
 
         QVector<QString> audioFileNames;
 
+        // If there are armed audio Instruments
         if (audioInstruments.size() > 0) {
 
+            // Create record audio files for each armed audio Instrument.
             audioFileNames =
                 RosegardenMainWindow::self()->createRecordAudioFiles
                 (audioInstruments);
@@ -298,11 +303,18 @@ RosegardenSequencer::record(const RealTime &time,
             }
         }
 
+        // Convert from QVector to std::vector.
+        // ??? We can probably convert the above functions to use std::vector
+        //     and avoid this conversion.
         std::vector<InstrumentId> armedInstrumentsVec;
-        std::vector<QString> audioFileNamesVec;
         for (int i = 0; i < armedInstruments.size(); ++i) {
             armedInstrumentsVec.push_back(armedInstruments[i]);
         }
+
+        // Convert from QVector to std::vector.
+        // ??? We can probably convert the above functions to use std::vector
+        //     and avoid this conversion.
+        std::vector<QString> audioFileNamesVec;
         for (int i = 0; i < audioFileNames.size(); ++i) {
             audioFileNamesVec.push_back(audioFileNames[i]);
         }
@@ -311,8 +323,8 @@ RosegardenSequencer::record(const RealTime &time,
         // this fails we stop.
         //
         if (m_driver->record(RECORD_ON,
-                             &armedInstrumentsVec,
-                             &audioFileNamesVec) == false) {
+                             armedInstrumentsVec,
+                             audioFileNamesVec) == false) {
             stop();
             return false;
         }
@@ -445,27 +457,12 @@ RosegardenSequencer::setLoop(const RealTime &loopStart,
 
 
 
-// Return the status of the sound systems (audio and MIDI)
-//
-unsigned int
-RosegardenSequencer::getSoundDriverStatus(const QString &guiVersion)
+unsigned
+RosegardenSequencer::getSoundDriverStatus()
 {
     LOCKED;
 
-    unsigned int driverStatus = m_driver->getStatus();
-    // ??? How would it ever be possible for these versions to mismatch?
-    //     They both come from the exact same place.  This might have been
-    //     an attempt at separating the GUI and Sequencer into .so files
-    //     or something.  I say remove this check.  Version is always OK.
-    if (guiVersion == VERSION)
-        driverStatus |= VERSION_OK;
-    else {
-        SEQUENCER_DEBUG << "WARNING: RosegardenSequencer::getSoundDriverStatus: "
-        << "GUI version \"" << guiVersion
-        << "\" does not match sequencer version \"" << VERSION
-        << "\"";
-    }
-    return driverStatus;
+    return m_driver->getStatus();
 }
 
 
@@ -518,14 +515,6 @@ RosegardenSequencer::processMappedEvent(MappedEvent mE)
 //                    << " events in async out queue" << endl;
 }
 
-int
-RosegardenSequencer::canReconnect(Device::DeviceType type)
-{
-    LOCKED;
-
-    return m_driver->canReconnect(type);
-}
-
 bool
 RosegardenSequencer::addDevice(Device::DeviceType type,
                                DeviceId id,
@@ -599,12 +588,14 @@ RosegardenSequencer::setConnection(unsigned int deviceId,
 
 void
 RosegardenSequencer::setPlausibleConnection(unsigned int deviceId,
-                                            QString connection)
+                                            QString idealConnection)
 {
     LOCKED;
 
-    bool recordDevice = false; // we only want this from connectSomething()
-    m_driver->setPlausibleConnection(deviceId, connection, recordDevice);
+    m_driver->setPlausibleConnection(
+            deviceId,
+            idealConnection,
+            false);  // recordDevice
 }
 
 void
@@ -997,15 +988,6 @@ RosegardenSequencer::setQuarterNoteLength(RealTime rt)
     m_driver->setMIDIClockInterval(rt / 24);
 }
 
-QString
-RosegardenSequencer::getStatusLog()
-{
-    LOCKED;
-
-    return m_driver->getStatusLog();
-}
-
-
 void RosegardenSequencer::dumpFirstSegment()
 {
     LOCKED;
@@ -1414,41 +1396,58 @@ RosegardenSequencer::processRecordedAudio()
 void
 RosegardenSequencer::processAsynchronousEvents()
 {
-    // outgoing ad-hoc async events
-    std::deque<MappedEvent *> q;
+    // *** Outgoing ad-hoc async events
+
+    std::deque<MappedEvent *> outQueue;
+
     m_asyncQueueMutex.lock();
+
+    // If there's something to send out
     if (!m_asyncOutQueue.empty()) {
-        q = m_asyncOutQueue;
+        // MOVE to local queue.
+        // ??? std::move() should be faster.
+        outQueue = m_asyncOutQueue;
         m_asyncOutQueue.clear();
-#ifdef DEBUG_ROSEGARDEN_SEQUENCER        
-        SEQUENCER_DEBUG << "processAsynchronousEvents: Have " << q.size()
-                        << " events in async out queue" << endl;
-#endif
-    }
-    m_asyncQueueMutex.unlock();
-    MappedEventList mC;
-    while (!q.empty()) {
-        mC.insert(q.front());
-        m_driver->processEventsOut(mC);
-        q.pop_front();
-        mC.clear();
+
+        //RG_DEBUG << "processAsynchronousEvents(): Have " << outQueue.size() << " events in async out queue";
     }
 
-    // incoming ad-hoc async events
-    m_driver->getMappedEventList(mC);
-    if (!mC.empty()) {
+    m_asyncQueueMutex.unlock();
+
+    MappedEventList mappedEventList;
+
+    // For each event, send to AlsaDriver
+    while (!outQueue.empty()) {
+        // ??? Why one at a time?  This is a lot of processing.
+        mappedEventList.insert(outQueue.front());
+        m_driver->processEventsOut(mappedEventList);
+        outQueue.pop_front();
+        mappedEventList.clear();
+    }
+
+    // *** Incoming ad-hoc async events
+
+    m_driver->getMappedEventList(mappedEventList);
+
+    if (!mappedEventList.empty()) {
         m_asyncQueueMutex.lock();
-        m_asyncInQueue.merge(mC);
+        m_asyncInQueue.merge(mappedEventList);
         m_asyncQueueMutex.unlock();
-        applyFiltering(&mC, ControlBlock::getInstance()->getThruFilter(), true);
+
+        // MIDI THRU handling
+
+        applyFiltering(
+                &mappedEventList,
+                ControlBlock::getInstance()->getThruFilter(),  // filter
+                true);  // filterControlDevice
+
         // Send the incoming events back out using the instrument and
         // track for the selected track.
-        routeEvents(&mC, false);
+        routeEvents(&mappedEventList,
+                    false);  // recording
     }
 
-    // Process any pending events (Note Offs or Audio) as part of same
-    // procedure.
-    //
+    // Process any pending events (Note Offs or Audio).
     m_driver->processPending();
 }
 
@@ -1470,7 +1469,7 @@ RosegardenSequencer::applyFiltering(MappedEventList *mC,
         // If this event matches the filter, erase it from the list
         if (((*j)->getType() & filter) ||
                 (filterControlDevice && ((*j)->getRecordedDevice() ==
-                                         Device::CONTROL_DEVICE))) {
+                                         Device::EXTERNAL_CONTROLLER))) {
             mC->erase(j);
         }
     }
@@ -1498,11 +1497,7 @@ RosegardenSequencer::checkForNewClients()
         m_transportStatus == RECORDING)
         return ;
 
-    if (m_driver->checkForNewClients()) {
-#ifdef DEBUG_ROSEGARDEN_SEQUENCER        
-        SEQUENCER_DEBUG << "client list changed";
-#endif
-    }
+    m_driver->checkForNewClients();
 }
 
 
@@ -1515,7 +1510,7 @@ RosegardenSequencer::rationalisePlayingAudio()
 }
 
 
-ExternalTransport::TransportToken
+RosegardenSequencer::TransportToken
 RosegardenSequencer::transportChange(TransportRequest request)
 {
     QMutexLocker locker(&m_transportRequestMutex);
@@ -1532,7 +1527,7 @@ RosegardenSequencer::transportChange(TransportRequest request)
         return m_transportToken + 1;
 }
 
-ExternalTransport::TransportToken
+RosegardenSequencer::TransportToken
 RosegardenSequencer::transportJump(TransportRequest request,
                                       RealTime rt)
 {
