@@ -19,7 +19,6 @@
 
 #include "sound/MappedEventList.h"
 #include "sound/MappedStudio.h"
-#include "sound/ExternalTransport.h"
 #include "sound/MappedBufMetaIterator.h"
 
 #include "base/MidiDevice.h"
@@ -43,10 +42,10 @@ class SoundDriver;
  *
  * RosegardenSequencer owns a SoundDriver object (m_driver) which wraps the
  * ALSA and JACK functionality.  At this level we deal with communication with
- * the Rosegarden GUI application, the high level marshalling of data,
+ * the Rosegarden GUI application, the high level marshaling of data,
  * and the main event loop of the sequencer.
  */
-class RosegardenSequencer : public QObject, public ExternalTransport
+class RosegardenSequencer : public QObject
 {
     Q_OBJECT
 
@@ -59,7 +58,7 @@ public:
     /// Locking mechanism used throughout.  See the LOCKED #define.
     void lock();
     void unlock();
-	
+
     /// Close the sequencer.
     void quit();
     
@@ -89,7 +88,7 @@ public:
     void jumpTo(const RealTime &rt);
  
     /// Return the Sound system status (audio/MIDI)
-    unsigned int getSoundDriverStatus(const QString &guiVersion);
+    unsigned getSoundDriverStatus();
 
     /// Add an audio file to the sequencer
     /**
@@ -134,21 +133,11 @@ public:
     MappedDevice getMappedDevice(unsigned int id);
 #endif
 
-    /// Query whether the driver implements device reconnection.
-    /**
-     * Returns a non-zero value if the addDevice, removeDevice,
-     * getConnections, getConnection and setConnection methods
-     * may be used with devices of the given type.
-     */
-    int canReconnect(Device::DeviceType deviceType);
-
     /**
      * Create a device of the given type and direction (corresponding
      * to MidiDevice::DeviceDirection enum) and return its id.
      * The device will have no connection by default.  Direction is
      * currently ignored for non-MIDI devices.
-     *
-     * Do not use this unless canReconnect(type) returned true.
      */
     bool addDevice(Device::DeviceType type,
                    DeviceId id,
@@ -158,8 +147,6 @@ public:
     /// Remove the device of the given id.
     /**
      * Ignored if driver does not permit changing the number of devices
-     * (i.e. if canReconnect(type) would return false when given the
-     * type of the supplied device).
      */
     void removeDevice(unsigned int id);
     /// Remove all of the devices (of types that can be added or removed).
@@ -177,7 +164,6 @@ public:
      * the given type and direction (corresponding to MidiDevice::
      * DeviceDirection enum).  Direction is ignored for non-MIDI devices.
      * Returns zero if devices of this type are non-reconnectable
-     * (i.e. if canReconnect(type) would return false).
      */
     unsigned int getConnections(Device::DeviceType type,
                                 MidiDevice::DeviceDirection direction);
@@ -346,9 +332,26 @@ public:
      */
     void setQuarterNoteLength(RealTime rt);
 
-    /// Return a (potentially lengthy) human-readable status log
-    QString getStatusLog();
+    enum TransportRequest {
+        TransportNoChange,
+        TransportStop,
+        TransportStart,
+        TransportPlay,
+        TransportRecord,
+        TransportJumpToTime, // time arg required
+        TransportStartAtTime, // time arg required
+        TransportStopAtTime // time arg required
+    };
 
+    /// Called by RosegardenMainWindow::slotHandleInputs().
+    /**
+     * Get the next transport request from the thread-safe request queue
+     * (m_transportRequests).
+     *
+     * ??? Instead of this, we should send QEvents over to
+     *     RosegardenMainWindow.  See RosegardenMainWindow::customEvent()
+     *     which is already used for this.
+     */
     bool getNextTransportRequest(TransportRequest &request, RealTime &time);
 
     MappedEventList pullAsynchronousMidiQueue();
@@ -427,19 +430,24 @@ public:
     void initialiseStudio();
 
 
-    // --------- ExternalTransport Interface --------
+    // --------- Transport Interface --------
     //
     // Whereas the interface (above) is for the GUI to call to
     // make the sequencer follow its wishes, this interface is for
     // external clients to call (via some low-level audio callback)
-    // and requires sychronising with the GUI.
-    
-    TransportToken transportChange(TransportRequest) override;
-    TransportToken transportJump(TransportRequest, RealTime) override;
-    bool isTransportSyncComplete(TransportToken token) override;
-    TransportToken getInvalidTransportToken() const override { return 0; }
+    // and requires synchronising with the GUI.
 
-    // ---------- End of ExternalTransport Interface -----------
+    typedef unsigned long TransportToken;
+
+    TransportToken transportChange(TransportRequest);
+    TransportToken transportJump(TransportRequest, RealTime);
+    bool isTransportSyncComplete(TransportToken token);
+
+    // The value returned here is a constant that is guaranteed never
+    // to be returned by any of the transport request methods.
+    TransportToken getInvalidTransportToken() const  { return 0; }
+
+    // ---------- End of Transport Interface -----------
 
 private slots:
     /// Connected to InstrumentStaticSignals::controlChange().
