@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -34,7 +34,7 @@ class SequencerThread : public QThread
 {
 protected:
     /// The sequencer thread's processing loop.
-    virtual void run();
+    void run() override;
 };
 
 }
