@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2018 the Rosegarden development team.
+    Copyright 2000-2020 the Rosegarden development team.
  
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
@@ -18,9 +18,11 @@
 #ifdef HAVE_ALSA
 
 #include "SoundDriver.h"
+#include "NoteOffEvent.h"
 #include "base/Instrument.h"
 #include "base/Device.h"
 #include "AlsaPort.h"
+#include "MappedEventList.h"
 #include "Scavenger.h"
 #include "RunnablePluginInstance.h"
 
@@ -53,15 +55,16 @@ public:
     void shutdown() override;
 
     bool initialise() override;
+
     void initialisePlayback(const RealTime &position) override;
     void stopPlayback() override;
     void punchOut() override;
     void resetPlayback(const RealTime &oldPosition, const RealTime &position) override;
-    void allNotesOff() override;
+    void allNotesOff();
 
     RealTime getSequencerTime() override;
 
-    /// Get MIDI data from ALSA
+    /// Get all pending input events from ALSA as a MappedEventList.
     /**
      * Called by RosegardenSequencer::processRecordedMidi() when recording and
      * RosegardenSequencer::processAsynchronousEvents() when playing or
@@ -73,28 +76,38 @@ public:
     bool getMappedEventList(MappedEventList &mappedEventList) override;
     
     bool record(RecordStatus recordStatus,
-                        const std::vector<InstrumentId> *armedInstruments = nullptr,
-                        const std::vector<QString> *audioFileNames = nullptr) override;
+                const std::vector<InstrumentId> &armedInstruments,
+                const std::vector<QString> &audioFileNames) override;
 
     void startClocks() override;
     virtual void startClocksApproved(); // called by JACK driver in sync mode
     void stopClocks() override;
     bool areClocksRunning() const override { return m_queueRunning; }
 
-    /// Send both MIDI and audio events out, unqueued
+    /// Send both MIDI and audio events out immediately (unqueued).
     /**
      * This version sends MIDI data to ALSA for transmission via MIDI
      * immediately.  (I assume audio events are also sent immediately.)
+     *
+     * RosegardenSequencer::processAsynchronousEvents() uses this to send
+     * out its m_asyncOutQueue.
+     *
+     * RosegardenSequencer::routeEvents() also uses this for async events
+     * and recorded MIDI thru.
      */
     void processEventsOut(const MappedEventList &mC) override;
+
     /// Send both MIDI and audio events out, queued
     /**
      * Used by RosegardenSequencer::keepPlaying() to send events out
      * during playback.
+     *
+     * The slice range is used for generating MIDI Time Code and
+     * processing pending note off events.
      */
-    void processEventsOut(const MappedEventList &mC,
-                                  const RealTime &sliceStart,
-                                  const RealTime &sliceEnd) override;
+    void processEventsOut(const MappedEventList &rgEventList,
+                          const RealTime &sliceStart,
+                          const RealTime &sliceEnd) override;
 
     // Return the sample rate
     //
@@ -112,7 +125,8 @@ public:
     void setMIDIClockInterval(RealTime interval) override;
 
     // initialise subsystems
-    //
+
+    // Set up queue, client and port
     bool initialiseMidi();
     void initialiseAudio();
 
@@ -179,14 +193,6 @@ public:
 #endif
     }
 
-    // Remove all plugin instances
-    //
-    void removePluginInstances() override {
-#ifdef HAVE_LIBJACK
-        if (m_jackDriver) m_jackDriver->removePluginInstances();
-#endif
-    }
-
     void setPluginInstancePortValue(InstrumentId id,
                                             int position,
                                             unsigned long portNumber,
@@ -330,7 +336,14 @@ public:
     void claimUnwantedPlugin(void *plugin) override;
     void scavengePlugins() override;
 
-    bool checkForNewClients() override;
+    /// Update Ports and Connections
+    /**
+     * Updates m_alsaPorts and m_devicePortMap to match the ports and
+     * connections that are out there.
+     *
+     * ??? rename: updatePortsAndConnections() or just update()?
+     */
+    void checkForNewClients() override;
 
     void setLoop(const RealTime &loopStart, const RealTime &loopEnd) override;
 
@@ -390,8 +403,6 @@ public:
     void setRecordDevice(DeviceId id, bool connectAction);
     void unsetRecordDevices();
 
-    bool canReconnect(Device::DeviceType type) override;
-
     bool addDevice(Device::DeviceType type,
                            DeviceId id,
                            InstrumentId baseInstrumentId,
@@ -410,8 +421,8 @@ public:
     QString getConnection(DeviceId id) override;
     void setConnection(DeviceId deviceId, QString connection) override;
     void setPlausibleConnection(DeviceId deviceId,
-                                        QString connection,
-                                        bool recordDevice = false) override;
+                                QString idealConnection,
+                                bool recordDevice = false) override;
     void connectSomething() override;
 
     unsigned int getTimers() override;
@@ -470,12 +481,15 @@ protected:
 
     typedef std::vector<QSharedPointer<AlsaPortDescription> > AlsaPortVector;
 
+    /// Bring m_alsaPorts up-to-date.
     /**
-     * Bring m_alsaPorts up-to-date; if newPorts is non-null, also
-     * return the new ports (not previously in m_alsaPorts) through it
+     * Polls ALSA ports and should be called when a client or port event
+     * arrives from ALSA.
+     *
+     * Called from initialiseMidi() and checkForNewClients().
      */
-    virtual void generatePortList(AlsaPortVector *newPorts = nullptr);
-    void generateFixedInstruments() override;
+    virtual void generatePortList();
+    void generateFixedInstruments();
 
     virtual void generateTimerList();
     virtual std::string getAutoTimer(bool &wantTimerChecks);
@@ -493,8 +507,8 @@ protected:
      * Used by processEventsOut() to send MIDI out via ALSA.
      */
     void processMidiOut(const MappedEventList &mC,
-                                const RealTime &sliceStart,
-                                const RealTime &sliceEnd) override;
+                        const RealTime &sliceStart,
+                        const RealTime &sliceEnd);
 
     virtual void processSoftSynthEventOut(InstrumentId id,
                                           const snd_seq_event_t *event,
@@ -504,10 +518,6 @@ protected:
 
     virtual void processAudioQueue(bool /* now */) { }
 
-    virtual void setConnectionToDevice(MappedDevice &device, QString connection);
-    virtual void setConnectionToDevice(MappedDevice &device, QString connection,
-                                       const ClientPortPair &pair);
-
 private:
     RealTime getAlsaTime();
 
@@ -519,7 +529,11 @@ private:
                               
     int checkAlsaError(int rc, const char *message);
 
+    /// The ALSA ports.
     AlsaPortVector m_alsaPorts;
+    void setFirstConnection(DeviceId deviceId, bool recordDevice);
+
+    bool m_startPlayback;
 
     // ALSA MIDI/Sequencer stuff
     //
@@ -528,11 +542,15 @@ private:
 
     int                          m_inputPort;
     
-    typedef std::map<DeviceId, int> DeviceIntMap;
-    DeviceIntMap                 m_outputPorts;
+    typedef std::map<DeviceId, int /* portNumber */> DeviceIntMap;
+    // ??? The ports that are created for each output device in the
+    //     Composition/Studio?
+    DeviceIntMap m_outputPorts;
 
     int                          m_syncOutputPort;
-    int                          m_controllerPort;
+
+    int m_externalControllerPort;
+    void configureExternalControllerPort();
 
     int                          m_queue;
     int                          m_maxClients;
@@ -597,8 +615,25 @@ private:
     typedef std::set<InstrumentId> InstrumentSet;
     InstrumentSet m_recordingInstruments;
 
+    typedef std::vector<MappedDevice *> MappedDeviceList;
+    /// The devices in the Composition.
+    MappedDeviceList m_devices;
+    MappedDevice *findDevice(DeviceId deviceId);
+
+    // ??? rename: ConnectionMap
     typedef std::map<DeviceId, ClientPortPair> DevicePortMap;
+    /// Composition/Studio MappedDevice -> ALSA ClientPortPair connections.
+    /**
+     * ??? rename: m_connectionMap
+     */
     DevicePortMap m_devicePortMap;
+    void setConnectionToDevice(MappedDevice &device, QString connection);
+    void setConnectionToDevice(MappedDevice &device, QString connection,
+                               const ClientPortPair &pair);
+    /// Return whether the client/port is in m_devicePortMap.
+    bool portInUse(int client, int port) const;
+    /// Is the given deviceId within m_devicePortMap connected?
+    bool isConnected(DeviceId deviceId) const;
 
     std::string getPortName(ClientPortPair port);
     ClientPortPair getPortByName(std::string name);
@@ -613,7 +648,15 @@ private:
         long resolution;
     };
     std::vector<AlsaTimerInfo> m_timers;
-    std::string m_currentTimer;
+    QString m_currentTimer;
+
+    /// A time ordered set of pending MIDI NoteOffEvent objects.
+    /**
+     * This is used to turn off all notes when Stop is pressed.
+     *
+     * See processNotesOff().
+     */
+    NoteOffQueue m_noteOffQueue;
 
     /// Send out the note-off events in m_noteOffQueue
     /**
@@ -643,6 +686,10 @@ private:
 
     bool m_queueRunning;
     
+    /// An ALSA client or port event was received.
+    /**
+     * checkForNewClients() will handle.
+     */
     bool m_portCheckNeeded;
 
     enum { NeedNoJackStart, NeedJackReposition, NeedJackStart } m_needJackStart;
@@ -652,7 +699,7 @@ private:
     double m_timerRatio;
     bool m_timerRatioCalculated;
 
-    std::string getAlsaModuleVersionString();
+    std::string getAlsaVersion();
     std::string getKernelVersionString();
     void extractVersion(std::string vstr, int &major, int &minor, int &subminor, std::string &suffix);
     bool versionIsAtLeast(std::string vstr, int major, int minor, int subminor);
@@ -712,8 +759,39 @@ private:
 
     /// Compute SPP at or prior to time.
     int songPositionPointer(const RealTime &time);
+
+    /// See handleTransportCCs().
+    bool m_acceptTransportCCs;
+    /// Handle CCs like 117 for play, 116 for stop, etc...
+    /**
+     * Returns true if handled and the CC can be discarded.
+     */
+    bool handleTransportCCs(unsigned controlNumber, int value);
+
+    /// Whether we are sending MIDI Clocks (transport master).
+    /**
+     * ??? This is basically (m_midiSyncStatus == TRANSPORT_MASTER).  It is
+     *     likely redundant and m_midiSyncStatus can be used instead.
+     */
+    bool                         m_midiClockEnabled;
+
+    MappedInstrument *getMappedInstrument(InstrumentId id);
+
+    /// Cancel the playback of an audio file.
+    /**
+     * Either by instrument and audio file id or by audio segment id.
+     */
+    void cancelAudioFile(const MappedEvent *mE);
+
+    void clearAudioQueue();
+
+    TransportSyncStatus m_midiSyncStatus;
+    TransportSyncStatus m_mmcStatus;
+    TransportSyncStatus m_mtcStatus;
+
 };
 
+
 }
 
 #endif // HAVE_ALSA
