@@ -28,14 +28,40 @@
 namespace Rosegarden
 {
 
-typedef std::pair<int, int> ClientPortPair;
 
-// Use this to hold all client information so that we can sort it
-// before generating devices - we want to put non-duplex devices
-// at the front of any device list (makes thing much easier at the
-// GUI and we already have some backwards compatability issues with
-// this).
-//
+struct ClientPortPair
+{
+    ClientPortPair() :
+        client(0),
+        port(0)
+    { }
+
+    ClientPortPair(int i_client, int i_port) :
+        client(i_client),
+        port(i_port)
+    { }
+
+    int client;
+    int port;
+
+    bool operator==(const ClientPortPair &rhs) const
+    {
+        return (client == rhs.client  &&  port == rhs.port);
+    }
+
+    bool operator!=(const ClientPortPair &rhs) const
+    {
+        return (client != rhs.client  ||  port != rhs.port);
+    }
+};
+
+/**
+ * Use this to hold all client information so that we can sort it
+ * before generating devices - we want to put non-duplex devices
+ * at the front of any device list (makes thing much easier at the
+ * GUI and we already have some backwards compatibility issues with
+ * this).
+ */
 class AlsaPortDescription
 {
 public:
@@ -65,8 +91,7 @@ public:
 
 };
 
-// Sort by checking direction
-//
+/// Sort by checking direction
 struct AlsaPortCmp
 {
     bool operator()(QSharedPointer<AlsaPortDescription> a1,
