@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     Other copyrights also apply to some parts of this work.  Please
     see the AUTHORS file and individual file headers for details.
@@ -123,7 +123,7 @@ AudioFileManager::addFile(const QString &filePath)
     }
 
     // prepare for audio file
-    AudioFile *aF = 0;
+    AudioFile *aF = nullptr;
     AudioFileId id = getUniqueAudioFileID();
 
     if (ext == "wav") {
@@ -137,14 +137,14 @@ AudioFileManager::addFile(const QString &filePath)
 
             try {
                 aF = new BWFAudioFile(id, qstrtostr(getShortFilename(filePath)), filePath);
-            } catch (SoundFile::BadSoundFileException e) {
+            } catch (const SoundFile::BadSoundFileException &e) {
                 delete aF;
                 throw BadAudioPathException(e);
             }
         } else if (subType == WAV) {
             try {
                 aF = new WAVAudioFile(id, qstrtostr(getShortFilename(filePath)), filePath);
-            } catch (SoundFile::BadSoundFileException e) {
+            } catch (const SoundFile::BadSoundFileException &e) {
                 delete aF;
                 throw BadAudioPathException(e);
             }
@@ -152,7 +152,7 @@ AudioFileManager::addFile(const QString &filePath)
 
         // Ensure we have a valid file handle
         //
-        if (aF == 0) {
+        if (aF == nullptr) {
             RG_WARNING << "addFile(): Unknown WAV audio file subtype in " << filePath;
             throw BadAudioPathException(filePath, __FILE__, __LINE__);
         }
@@ -164,7 +164,7 @@ AudioFileManager::addFile(const QString &filePath)
                 RG_WARNING << "addFile(): Malformed audio file in " << filePath;
                 throw BadAudioPathException(filePath, __FILE__, __LINE__);
             }
-        } catch (SoundFile::BadSoundFileException e) {
+        } catch (const SoundFile::BadSoundFileException &e) {
             delete aF;
             throw BadAudioPathException(e);
         }
@@ -257,7 +257,7 @@ AudioFileManager::insertFile(const std::string &name,
         }
         m_audioFiles.push_back(aF);
 
-    } catch (SoundFile::BadSoundFileException e) {
+    } catch (const SoundFile::BadSoundFileException &e) {
         delete aF;
         throw BadAudioPathException(e);
     }
@@ -333,7 +333,7 @@ AudioFileManager::insertFile(const std::string &name,
     removeFile(id);
 
     // and insert
-    WAVAudioFile *aF = 0;
+    WAVAudioFile *aF = nullptr;
 
     try {
 
@@ -348,7 +348,7 @@ AudioFileManager::insertFile(const std::string &name,
         m_audioFiles.push_back(aF);
         updateAudioFileID(id);
 
-    } catch (SoundFile::BadSoundFileException e) {
+    } catch (const SoundFile::BadSoundFileException &e) {
         delete aF;
         throw BadAudioPathException(e);
     }
@@ -507,17 +507,17 @@ AudioFileManager::createRecordingAudioFile(QString projectName, QString instrume
     }
 
     // insert file into vector
-    WAVAudioFile *aF = 0;
+    WAVAudioFile *aF = nullptr;
 
     QString aup( m_audioPath );
     QString fnm(fileName);
     const QString fpath = m_audioPath + fileName;
     try {
-        aF = new WAVAudioFile( static_cast<const unsigned int>(newId), qstrtostr(fileName), fpath );
+        aF = new WAVAudioFile(newId, qstrtostr(fileName), fpath);
         //aF = new WAVAudioFile(newId, fileName.data(), m_audioPath + qstrtostr(fileName) );
         m_audioFiles.push_back(aF);
         m_recordedAudioFiles.insert(aF);
-    } catch (SoundFile::BadSoundFileException e) {
+    } catch (const SoundFile::BadSoundFileException &e) {
         delete aF;
         throw BadAudioPathException(e);
     }
@@ -560,7 +560,7 @@ AudioFileManager::createDerivedAudioFile(AudioFileId source,
         ;
 
     AudioFile *sourceFile = getAudioFile(source);
-    if (!sourceFile) return 0;
+    if (!sourceFile) return nullptr;
 
     AudioFileId newId = getUniqueAudioFileID();
     QString fileName = "";
@@ -586,7 +586,7 @@ AudioFileManager::createDerivedAudioFile(AudioFileId source,
     }
 
     // insert file into vector
-    WAVAudioFile *aF = 0;
+    WAVAudioFile *aF = nullptr;
 
     try {
         aF = new WAVAudioFile(newId,
@@ -594,7 +594,7 @@ AudioFileManager::createDerivedAudioFile(AudioFileId source,
                               m_audioPath + fileName );
         m_audioFiles.push_back(aF);
         m_derivedAudioFiles.insert(aF);
-    } catch (SoundFile::BadSoundFileException e) {
+    } catch (const SoundFile::BadSoundFileException &e) {
         delete aF;
         throw BadAudioPathException(e);
     }
@@ -614,7 +614,7 @@ AudioFileManager::importURL(const QUrl &url, int sampleRate)
 
     FileSource source(url);
     if (!source.isAvailable()) {
-        QMessageBox::critical(0, tr("Rosegarden"),
+        QMessageBox::critical(nullptr, tr("Rosegarden"),
                 tr("Cannot download file %1").arg(url.toString()));
         throw SoundFile::BadSoundFileException(url.toString());
     }
@@ -680,7 +680,7 @@ AudioFileManager::importFile(const QString &fileName, int sampleRate)
             ;
 
         // insert file into vector
-        WAVAudioFile *aF = 0;
+        WAVAudioFile *aF = nullptr;
 
         aF = new WAVAudioFile(newId,
                               qstrtostr(targetName),
@@ -931,7 +931,7 @@ AudioFileManager::generatePreview(AudioFileId id)
 
     AudioFile *audioFile = getAudioFile(id);
 
-    if (audioFile == 0)
+    if (audioFile == nullptr)
         return false;
 
     if (!m_peakManager.hasValidPeaks(audioFile))
@@ -953,7 +953,7 @@ AudioFileManager::getAudioFile(AudioFileId id)
         if ((*it)->getId() == id)
             return (*it);
     }
-    return 0;
+    return nullptr;
 }
 
 std::vector<float>
@@ -968,12 +968,16 @@ AudioFileManager::getPreview(AudioFileId id,
 
     AudioFile *audioFile = getAudioFile(id);
 
-    if (audioFile == 0) {
+    if (audioFile == nullptr) {
         return std::vector<float>();
     }
 
     if (!m_peakManager.hasValidPeaks(audioFile)) {
-        RG_WARNING << "getPreview(): No peaks for audio file " << audioFile->getFilename();
+        // ??? This happens a lot when recording audio.  Need to detect
+        //     that we are recording and suppress this.  Or just don't
+        //     call this when recording.  The caller has comments in
+        //     its catch() to this effect.
+        RG_WARNING << "getPreview(): No peaks for audio file" << audioFile->getFilename() << "(this is probably OK when recording)";
         throw PeakFileManager::BadPeakFileException(
                 audioFile->getFilename(), __FILE__, __LINE__);
     }
@@ -1073,7 +1077,7 @@ AudioFileManager::drawHighlightedPreview(AudioFileId id,
         return;
 
     if (!m_peakManager.hasValidPeaks(audioFile)) {
-        RG_WARNING << "getPreview(): No peaks for audio file " << audioFile->getFilename();
+        RG_WARNING << "drawHighlightedPreview(): No peaks for audio file " << audioFile->getFilename();
         throw PeakFileManager::BadPeakFileException
         (audioFile->getFilename(), __FILE__, __LINE__);
     }
@@ -1160,7 +1164,7 @@ AudioFileManager::getSplitPoints(AudioFileId id,
 
     AudioFile *audioFile = getAudioFile(id);
 
-    if (audioFile == 0)
+    if (audioFile == nullptr)
         return std::vector<SplitPointPair>();
 
     return m_peakManager.getSplitPoints(audioFile,
