@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -42,13 +42,13 @@ public:
                   unsigned int bytesPerFrame,
                   unsigned int bitsPerSample);
 
-    ~BWFAudioFile();
+    ~BWFAudioFile() override;
 
     // Override these methods for the WAV
     //
-    virtual bool open();
-    virtual bool write();
-    virtual void close();
+    bool open() override;
+    bool write() override;
+    void close() override;
 
     // Get all header information
     //
@@ -60,23 +60,23 @@ public:
 
     // Offset to start of sample data
     //
-    virtual std::streampos getDataOffset();
+    std::streampos getDataOffset() override;
 
     // Peak file name
     //
-    virtual QString getPeakFilename()
+    QString getPeakFilename() override
         { return (m_fileName + ".pk"); }
 
 
     //!!! NOT IMPLEMENTED YET
     // 
-    virtual bool decode(const unsigned char */* sourceData */,
+    bool decode(const unsigned char */* sourceData */,
                         size_t /* sourceBytes */,
                         size_t /* targetSampleRate */,
                         size_t /* targetChannels */,
                         size_t /* targetFrames */,
                         std::vector<float *> &/* targetData */,
-                        bool /* addToResultBuffers = false */) { return false; }
+                        bool /* addToResultBuffers = false */) override { return false; }
 
 protected:
 
