@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -225,7 +225,7 @@ private:
     // Singleton.  Use getInstance().
     ControlBlock();
 
-    void clearTracks(void);
+    void clearTracks();
 
     RosegardenDocument *m_doc;
 
