@@ -233,8 +233,10 @@ DSSIPluginFactory::getPluginPath()
         path = cpath;
 
     if (path == "") {
-//      path = "/usr/local/lib/dssi:/usr/lib/dssi";
-        path = "/usr/local/lib/dssi:/usr/lib/dssi:/usr/local/lib64/dssi:/usr/lib64/dssi";
+        // ??? Probably should offer "Additional DSSI search paths" in the
+        //     preferences.
+        path = "/usr/local/lib/dssi:/usr/lib/dssi:/usr/local/lib64/dssi:"
+               "/usr/lib64/dssi:/usr/lib/x86_64-linux-gnu/dssi";
         char *home = getenv("HOME");
         if (home)
             path = std::string(home) + "/.dssi:" + path;
