@@ -23,6 +23,7 @@
 #include "base/AudioLevel.h"
 #include "Audit.h"
 #include "PluginFactory.h"
+#include "SequencerDataBlock.h"
 
 #include "misc/ConfigGroups.h"
 #include "misc/Debug.h"
@@ -52,7 +53,7 @@ JackDriver::JackDriver(AlsaDriver *alsaDriver) :
         m_sampleRate(0),
         m_tempOutBuffer(nullptr),
         m_jackTransportEnabled(false),
-        m_jackTransportMaster(false),
+        m_jackTransportSource(false),
         m_waiting(false),
         m_waitingState(JackTransportStopped),
         m_waitingToken(0),
@@ -206,10 +207,9 @@ JackDriver::initialise(bool reinitialise)
 
     // Create a log that the user can easily see through the preferences
     // even in a release build.
-    Audit audit;
-    audit << '\n';
-    audit << "===============================================================\n";
-    audit << "JackDriver::initialise() begin...\n";
+    AUDIT << '\n';
+    AUDIT << "===============================================================\n";
+    AUDIT << "JackDriver::initialise() begin...\n";
     RG_DEBUG << "initialise() begin...";
 
     std::string jackClientName = "rosegarden";
@@ -229,8 +229,8 @@ JackDriver::initialise(bool reinitialise)
         RG_WARNING << "initialise() - JACK server not running";
         RG_WARNING << "  Attempt to start JACK server was " << (jackOptions & JackNoStartServer ? "NOT " : "") << "made per user config";
         // Also send to user log.
-        audit << "JACK server not running\n";
-        audit << "  Attempt to start JACK server was " << (jackOptions & JackNoStartServer ? "NOT " : "") << "made per user config\n";
+        AUDIT << "JACK server not running\n";
+        AUDIT << "  Attempt to start JACK server was " << (jackOptions & JackNoStartServer ? "NOT " : "") << "made per user config\n";
         return ;
     }
 
@@ -259,7 +259,7 @@ JackDriver::initialise(bool reinitialise)
     m_bufferSize = jack_get_buffer_size(m_client);
 
     RG_DEBUG << "initialise() - JACK sample rate = " << m_sampleRate << "Hz, buffer size = " << m_bufferSize;
-    audit << "JACK sample rate = " << m_sampleRate << "Hz, buffer size = " << m_bufferSize << '\n';
+    AUDIT << "JACK sample rate = " << m_sampleRate << "Hz, buffer size = " << m_bufferSize << '\n';
 
     PluginFactory::setSampleRate(m_sampleRate);
 
@@ -273,7 +273,7 @@ JackDriver::initialise(bool reinitialise)
         m_tempOutBuffer = new sample_t[m_bufferSize];
 
         RG_DEBUG << "initialise() - creating disk thread...";
-        audit << "Creating audio file thread...\n";
+        AUDIT << "Creating audio file thread...\n";
 
         m_fileReader = new AudioFileReader(m_alsaDriver, m_sampleRate);
         m_fileWriter = new AudioFileWriter(m_alsaDriver, m_sampleRate);
@@ -304,19 +304,19 @@ JackDriver::initialise(bool reinitialise)
 
     if (!createMainOutputs()) { // one stereo pair master, one pair monitor
         RG_WARNING << "initialise() - failed to create main outputs!";
-        audit << "WARNING: failed to create main outputs!\n";
+        AUDIT << "WARNING: failed to create main outputs!\n";
         return ;
     }
 
     if (!createRecordInputs(1)) {
         RG_WARNING << "initialise() - failed to create record inputs!";
-        audit << "WARNING: failed to create record inputs!\n";
+        AUDIT << "WARNING: failed to create record inputs!\n";
         return ;
     }
 
     if (jack_activate(m_client)) {
         RG_WARNING << "initialise() - client activation failed";
-        audit << "WARNING: client activation failed\n";
+        AUDIT << "WARNING: client activation failed\n";
         return ;
     }
 
@@ -344,25 +344,25 @@ JackDriver::initialise(bool reinitialise)
             for (i = 0; ports[i]; i++)
                 ;
             RG_DEBUG << "initialise() - found " << i << " JACK physical outputs";
-            audit << "Found " << i << " JACK physical outputs\n";
+            AUDIT << "Found " << i << " JACK physical outputs\n";
 
             jack_free(ports);
 
         } else {
             RG_WARNING << "initialise() - no JACK physical outputs found";
-            audit << "WARNING: no JACK physical outputs found\n";
+            AUDIT << "WARNING: no JACK physical outputs found\n";
         }
 
         if (playback_1 != "") {
             RG_DEBUG << "initialise() - connecting from " << "\"" << jack_port_name(m_outputMasters[0]) << "\" to \"" << playback_1.c_str() << "\"";
-            audit << "connecting from " << "\"" << jack_port_name(m_outputMasters[0]) << "\" to \"" << playback_1.c_str() << "\"\n";
+            AUDIT << "connecting from " << "\"" << jack_port_name(m_outputMasters[0]) << "\" to \"" << playback_1.c_str() << "\"\n";
 
             // connect our client up to the ALSA ports - first left output
             //
             if (jack_connect(m_client, jack_port_name(m_outputMasters[0]),
                              playback_1.c_str())) {
                 RG_WARNING << "initialise() - cannot connect to JACK output port";
-                audit << "WARNING: cannot connect to JACK output port\n";
+                AUDIT << "WARNING: cannot connect to JACK output port\n";
                 return ;
             }
 
@@ -380,12 +380,12 @@ JackDriver::initialise(bool reinitialise)
 
         if (playback_2 != "") {
             RG_DEBUG << "initialise() - connecting from " << "\"" << jack_port_name(m_outputMasters[1]) << "\" to \"" << playback_2.c_str() << "\"";
-            audit << "WARNING: connecting from " << "\"" << jack_port_name(m_outputMasters[1]) << "\" to \"" << playback_2.c_str() << "\"\n";
+            AUDIT << "WARNING: connecting from " << "\"" << jack_port_name(m_outputMasters[1]) << "\" to \"" << playback_2.c_str() << "\"\n";
 
             if (jack_connect(m_client, jack_port_name(m_outputMasters[1]),
                              playback_2.c_str())) {
                 RG_WARNING << "initialise() - cannot connect to JACK output port";
-                audit << "WARNING: cannot connect to JACK output port\n";
+                AUDIT << "WARNING: cannot connect to JACK output port\n";
             }
 
             /*
@@ -420,42 +420,42 @@ JackDriver::initialise(bool reinitialise)
             for (i = 0; ports[i]; i++)
                 ;
             RG_DEBUG << "initialise() - found " << i << " JACK physical inputs";
-            audit << "found " << i << " JACK physical inputs\n";
+            AUDIT << "found " << i << " JACK physical inputs\n";
 
             jack_free(ports);
 
         } else {
             RG_WARNING << "initialise() - no JACK physical inputs found";
-            audit << "WARNING: no JACK physical inputs found\n";
+            AUDIT << "WARNING: no JACK physical inputs found\n";
         }
 
         if (capture_1 != "") {
 
             RG_DEBUG << "initialise() - connecting from " << "\"" << capture_1.c_str() << "\" to \"" << jack_port_name(m_inputPorts[0]) << "\"";
-            audit << "connecting from " << "\"" << capture_1.c_str() << "\" to \"" << jack_port_name(m_inputPorts[0]) << "\"\n";
+            AUDIT << "connecting from " << "\"" << capture_1.c_str() << "\" to \"" << jack_port_name(m_inputPorts[0]) << "\"\n";
 
             if (jack_connect(m_client, capture_1.c_str(),
                              jack_port_name(m_inputPorts[0]))) {
                 RG_WARNING << "initialise() - cannot connect to JACK input port";
-                audit << "WARNING: cannot connect to JACK input port\n";
+                AUDIT << "WARNING: cannot connect to JACK input port\n";
             }
         }
 
         if (capture_2 != "") {
 
             RG_DEBUG << "initialise() - connecting from " << "\"" << capture_2.c_str() << "\" to \"" << jack_port_name(m_inputPorts[1]) << "\"";
-            audit << "connecting from " << "\"" << capture_2.c_str() << "\" to \"" << jack_port_name(m_inputPorts[1]) << "\"\n";
+            AUDIT << "connecting from " << "\"" << capture_2.c_str() << "\" to \"" << jack_port_name(m_inputPorts[1]) << "\"\n";
 
             if (jack_connect(m_client, capture_2.c_str(),
                              jack_port_name(m_inputPorts[1]))) {
                 RG_WARNING << "initialise() - cannot connect to JACK input port";
-                audit << "WARNING: cannot connect to JACK input port\n";
+                AUDIT << "WARNING: cannot connect to JACK input port\n";
             }
         }
     }
 
     RG_DEBUG << "initialise() - initialised JACK audio subsystem";
-    audit << "initialised JACK audio subsystem\n";
+    AUDIT << "initialised JACK audio subsystem\n";
 
     m_ok = true;
 }
@@ -656,10 +656,9 @@ JackDriver::setAudioPorts(bool faderOuts, bool submasterOuts)
 
     // Create a log that the user can easily see through the preferences
     // even in a release build.
-    Audit audit;
-    audit << '\n';
-    audit << "===============================================================\n";
-    audit << "JackDriver::setAudioPorts() begin...\n";
+    AUDIT << '\n';
+    AUDIT << "===============================================================\n";
+    AUDIT << "JackDriver::setAudioPorts() begin...\n";
 
 #ifdef DEBUG_JACK_DRIVER
     RG_DEBUG << "setAudioPorts(" << faderOuts << "," << submasterOuts << ")";
@@ -667,7 +666,7 @@ JackDriver::setAudioPorts(bool faderOuts, bool submasterOuts)
 
     if (!m_client) {
         RG_WARNING << "setAudioPorts(" << faderOuts << "," << submasterOuts << "): no client yet";
-        audit << "WARNING: setAudioPorts(" << faderOuts << "," << submasterOuts << "): no client yet\n";
+        AUDIT << "WARNING: setAudioPorts(" << faderOuts << "," << submasterOuts << "): no client yet\n";
         return ;
     }
 
@@ -680,7 +679,7 @@ JackDriver::setAudioPorts(bool faderOuts, bool submasterOuts)
         if (!createFaderOutputs(audioInstruments, synthInstruments)) {
             m_ok = false;
             RG_WARNING << "setAudioPorts(): Failed to create fader outs!";
-            audit << "WARNING: Failed to create fader outs!\n";
+            AUDIT << "WARNING: Failed to create fader outs!\n";
             return ;
         }
     } else {
@@ -694,14 +693,14 @@ JackDriver::setAudioPorts(bool faderOuts, bool submasterOuts)
                 MappedObject::AudioBuss);
         if (count == 0) {
             RG_WARNING << "setAudioPorts(): Mapped studio contains no master buss!  Probably a symptom of a serious error";
-            audit << "WARNING: Mapped studio contains no master buss!  Probably a symptom of a serious error\n";
+            AUDIT << "WARNING: Mapped studio contains no master buss!  Probably a symptom of a serious error\n";
         } else {
             count = count - 1;
         }
         if (!createSubmasterOutputs(count)) {
             m_ok = false;
             RG_WARNING << "setAudioPorts(): Failed to create submaster outs!";
-            audit << "WARNING(): Failed to create submaster outs!\n";
+            AUDIT << "WARNING(): Failed to create submaster outs!\n";
             return ;
         }
 
@@ -886,15 +885,15 @@ JackDriver::jackProcess(jack_nframes_t nframes)
 
         if (state == JackTransportStopped) {
             if (playing && clocksRunning && !m_waiting) {
-                ExternalTransport *transport =
-                    m_alsaDriver->getExternalTransportControl();
-                if (transport) {
+                RosegardenSequencer *sequencer =
+                    m_alsaDriver->getSequencer();
+                if (sequencer) {
 #ifdef DEBUG_JACK_TRANSPORT
                     RG_DEBUG << "jackProcess(): JACK transport stopped externally at " << position.frame;
 #endif
 
-                    m_waitingToken = transport->transportJump(
-                            ExternalTransport::TransportStopAtTime,
+                    m_waitingToken = sequencer->transportJump(
+                            RosegardenSequencer::TransportStopAtTime,
                             RealTime::frame2RealTime(position.frame,
                                                      position.frame_rate));
                 }
@@ -1542,9 +1541,9 @@ JackDriver::jackSyncCallback(jack_transport_state_t state,
     if (!inst->m_jackTransportEnabled)
         return true; // ignore
 
-    ExternalTransport *transport =
-        inst->m_alsaDriver->getExternalTransportControl();
-    if (!transport)
+    RosegardenSequencer *sequencer =
+        inst->m_alsaDriver->getSequencer();
+    if (!sequencer)
         return true;
 
 #ifdef DEBUG_JACK_TRANSPORT
@@ -1555,30 +1554,30 @@ JackDriver::jackSyncCallback(jack_transport_state_t state,
 
 #endif
 
-    ExternalTransport::TransportRequest request =
-        ExternalTransport::TransportNoChange;
+    RosegardenSequencer::TransportRequest request =
+            RosegardenSequencer::TransportNoChange;
 
     if (inst->m_alsaDriver->isPlaying()) {
 
         if (state == JackTransportStarting) {
-            request = ExternalTransport::TransportJumpToTime;
+            request = RosegardenSequencer::TransportJumpToTime;
         } else if (state == JackTransportStopped) {
-            request = ExternalTransport::TransportStop;
+            request = RosegardenSequencer::TransportStop;
         }
 
     } else {
 
         if (state == JackTransportStarting) {
-            request = ExternalTransport::TransportStartAtTime;
+            request = RosegardenSequencer::TransportStartAtTime;
         } else if (state == JackTransportStopped) {
-            request = ExternalTransport::TransportNoChange;
+            request = RosegardenSequencer::TransportNoChange;
         }
     }
 
     if (!inst->m_waiting || inst->m_waitingState != state) {
 
-        if (request == ExternalTransport::TransportJumpToTime ||
-                request == ExternalTransport::TransportStartAtTime) {
+        if (request == RosegardenSequencer::TransportJumpToTime ||
+                request == RosegardenSequencer::TransportStartAtTime) {
 
             RealTime rt = RealTime::frame2RealTime(position->frame,
                                                    position->frame_rate);
@@ -1587,31 +1586,31 @@ JackDriver::jackSyncCallback(jack_transport_state_t state,
             RG_DEBUG << "jackSyncCallback(): Requesting jump to " << rt;
 #endif
 
-            inst->m_waitingToken = transport->transportJump(request, rt);
+            inst->m_waitingToken = sequencer->transportJump(request, rt);
 
 #ifdef DEBUG_JACK_TRANSPORT
             RG_DEBUG << "jackSyncCallback(): My token is " << inst->m_waitingToken;
 #endif
 
-        } else if (request == ExternalTransport::TransportStop) {
+        } else if (request == RosegardenSequencer::TransportStop) {
 
 #ifdef DEBUG_JACK_TRANSPORT
             RG_DEBUG << "jackSyncCallback(): Requesting state change to " << request;
 #endif
 
-            inst->m_waitingToken = transport->transportChange(request);
+            inst->m_waitingToken = sequencer->transportChange(request);
 
 #ifdef DEBUG_JACK_TRANSPORT
             RG_DEBUG << "jackSyncCallback(): My token is " << inst->m_waitingToken;
 #endif
 
-        } else if (request == ExternalTransport::TransportNoChange) {
+        } else if (request == RosegardenSequencer::TransportNoChange) {
 
 #ifdef DEBUG_JACK_TRANSPORT
             RG_DEBUG << "jackSyncCallback(): Requesting no state change!";
 #endif
 
-            inst->m_waitingToken = transport->transportChange(request);
+            inst->m_waitingToken = sequencer->transportChange(request);
 
 #ifdef DEBUG_JACK_TRANSPORT
             RG_DEBUG << "jackSyncCallback(): My token is " << inst->m_waitingToken;
@@ -1630,7 +1629,7 @@ JackDriver::jackSyncCallback(jack_transport_state_t state,
 
     } else {
 
-        if (transport->isTransportSyncComplete(inst->m_waitingToken)) {
+        if (sequencer->isTransportSyncComplete(inst->m_waitingToken)) {
 #ifdef DEBUG_JACK_TRANSPORT
             RG_DEBUG << "jackSyncCallback(): Sync complete";
 #endif
@@ -1679,11 +1678,11 @@ JackDriver::relocateTransportInternal(bool alsoStart)
         // Where did this request come from?  Are we just responding
         // to an external sync?
 
-        ExternalTransport *transport =
-            m_alsaDriver->getExternalTransportControl();
+        RosegardenSequencer *sequencer =
+            m_alsaDriver->getSequencer();
 
-        if (transport) {
-            if (transport->isTransportSyncComplete(m_waitingToken)) {
+        if (sequencer) {
+            if (sequencer->isTransportSyncComplete(m_waitingToken)) {
 
                 // Nope, this came from Rosegarden
 
@@ -1774,11 +1773,11 @@ JackDriver::stopTransport()
         // Where did this request come from?  Is this a result of our
         // sync to a transport that has in fact already stopped?
 
-        ExternalTransport *transport =
-            m_alsaDriver->getExternalTransportControl();
+        RosegardenSequencer *sequencer =
+            m_alsaDriver->getSequencer();
 
-        if (transport) {
-            if (transport->isTransportSyncComplete(m_waitingToken)) {
+        if (sequencer) {
+            if (sequencer->isTransportSyncComplete(m_waitingToken)) {
 
                 // No, we have no outstanding external requests; this
                 // must have genuinely been requested from within
@@ -2339,13 +2338,6 @@ JackDriver::removePluginInstance(InstrumentId id, int position)
         m_instrumentMixer->removePlugin(id, position);
 }
 
-void
-JackDriver::removePluginInstances()
-{
-    if (m_instrumentMixer)
-        m_instrumentMixer->removeAllPlugins();
-}
-
 void
 JackDriver::setPluginInstancePortValue(InstrumentId id, int position,
                                        unsigned long portNumber,
