@@ -24,7 +24,8 @@
 #include "SoundDriver.h"
 #include "base/Instrument.h"
 #include "base/RealTime.h"
-#include "ExternalTransport.h"
+#include "sequencer/RosegardenSequencer.h"
+
 #include <QStringList>
 
 namespace Rosegarden
@@ -48,10 +49,10 @@ public:
     bool isOK() const { return m_ok; }
 
     bool isTransportEnabled() { return m_jackTransportEnabled; }
-    bool isTransportMaster () { return m_jackTransportMaster; }
+    bool isTransportSource () { return m_jackTransportSource; }
 
     void setTransportEnabled(bool e) { m_jackTransportEnabled = e; }
-    void setTransportMaster (bool m) { m_jackTransportMaster  = m; }
+    void setTransportSource (bool m) { m_jackTransportSource  = m; }
 
     // These methods call back on the sound driver if necessary to
     // establish the current transport location to start at or
@@ -76,10 +77,6 @@ public:
 
     virtual void removePluginInstance(InstrumentId id, int position);
 
-    // Remove all plugin instances
-    //
-    virtual void removePluginInstances();
-
     virtual void setPluginInstancePortValue(InstrumentId id,
                                             int position,
                                             unsigned long portNumber,
@@ -248,11 +245,11 @@ protected:
     sample_t                    *m_tempOutBuffer;
 
     bool                         m_jackTransportEnabled;
-    bool                         m_jackTransportMaster;
+    bool                         m_jackTransportSource;
 
     bool                         m_waiting;
     jack_transport_state_t       m_waitingState;
-    ExternalTransport::TransportToken m_waitingToken;
+    RosegardenSequencer::TransportToken m_waitingToken;
     int                          m_ignoreProcessTransportCount;
 
     AudioBussMixer              *m_bussMixer;
