@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -32,22 +32,22 @@ class LADSPAPluginInstance;
 class LADSPAPluginFactory : public PluginFactory
 {
 public:
-    virtual ~LADSPAPluginFactory();
+    ~LADSPAPluginFactory() override;
 
-    virtual void discoverPlugins();
+    void discoverPlugins() override;
 
-    virtual const std::vector<QString> &getPluginIdentifiers() const;
+    const std::vector<QString> &getPluginIdentifiers() const override;
 
-    virtual void enumeratePlugins(MappedObjectPropertyList &list);
+    void enumeratePlugins(MappedObjectPropertyList &list) override;
 
-    virtual void populatePluginSlot(QString identifier, MappedPluginSlot &slot);
+    void populatePluginSlot(QString identifier, MappedPluginSlot &slot) override;
 
-    virtual RunnablePluginInstance *instantiatePlugin(QString identifier,
+    RunnablePluginInstance *instantiatePlugin(QString identifier,
                                                       int instrumentId,
                                                       int position,
                                                       unsigned int sampleRate,
                                                       unsigned int blockSize,
-                                                      unsigned int channels);
+                                                      unsigned int channels) override;
 
     MappedObjectValue getPortMinimum(const LADSPA_Descriptor *, int port);
     MappedObjectValue getPortMaximum(const LADSPA_Descriptor *, int port);
@@ -66,7 +66,7 @@ protected:
     virtual void generateTaxonomy(QString uri, QString base);
     virtual void generateFallbackCategories();
 
-    virtual void releasePlugin(RunnablePluginInstance *, QString);
+    void releasePlugin(RunnablePluginInstance *, QString) override;
 
     virtual const LADSPA_Descriptor *getLADSPADescriptor(QString identifier);
 
