@@ -22,10 +22,11 @@
 #include "base/Profiler.h"
 #include "misc/Debug.h"
 #include "sound/MappedInserterBase.h"
+#include "gui/seqmanager/MEBIterator.h"
 #include "sound/ControlBlock.h"
 
-#include <queue>
-#include <functional>
+#include <queue>  // std::priority_queue
+#include <functional>  // std::greater
 
 //#define DEBUG_META_ITERATOR 1
 //#define DEBUG_PLAYING_AUDIO_FILES 1
@@ -34,13 +35,9 @@ namespace Rosegarden
 {
 
 
-MappedBufMetaIterator::~MappedBufMetaIterator()
-{
-    clear();
-}
-
 void
-MappedBufMetaIterator::addSegment(QSharedPointer<MappedEventBuffer> mappedEventBuffer)
+MappedBufMetaIterator::addBuffer(
+        QSharedPointer<MappedEventBuffer> mappedEventBuffer)
 {
     // BUG #1349 (was #3546135)
     // If we already have this segment, bail, or else we'll have two
@@ -48,47 +45,40 @@ MappedBufMetaIterator::addSegment(QSharedPointer<MappedEventBuffer> mappedEventB
     // cause an access to freed memory and a subsequent crash.
     // This seems to happen when recording and we pass the end of the
     // composition.
-    if (m_segments.find(mappedEventBuffer) != m_segments.end())
+    if (m_buffers.find(mappedEventBuffer) != m_buffers.end())
         return;
 
-    m_segments.insert(mappedEventBuffer);
+    m_buffers.insert(mappedEventBuffer);
 
-    MappedEventBuffer::iterator *iter =
-            new MappedEventBuffer::iterator(mappedEventBuffer);
-    moveIteratorToTime(*iter, m_currentTime);
+    QSharedPointer<MEBIterator> iter(new MEBIterator(mappedEventBuffer));
+    iter->moveTo(m_currentTime);
     m_iterators.push_back(iter);
 }
 
 void
-MappedBufMetaIterator::removeSegment(QSharedPointer<MappedEventBuffer> mappedEventBuffer)
+MappedBufMetaIterator::removeBuffer(
+        QSharedPointer<MappedEventBuffer> mappedEventBuffer)
 {
     // Remove from m_iterators
-    for (SegmentIterators::iterator i = m_iterators.begin();
-         i != m_iterators.end(); ++i) {
-        if ((*i)->getSegment() == mappedEventBuffer) {
-            delete (*i);
-            // Now mappedEventBuffer may not be a valid address since the
-            // iterator we just deleted may have been the last "owner" of
-            // the MappedEventBuffer.  See MappedEventBuffer::iterator's
-            // dtor and MappedEventBuffer::removeOwner().
+    for (IteratorVector::iterator i = m_iterators.begin();
+         i != m_iterators.end();
+         ++i) {
+        // Found it?  Delete it.
+        if ((*i)->getMappedEventBuffer() == mappedEventBuffer) {
             m_iterators.erase(i);
             break;
         }
     }
 
     // Remove from m_segments
-    m_segments.erase(mappedEventBuffer);
+    m_buffers.erase(mappedEventBuffer);
 }
 
 void
 MappedBufMetaIterator::clear()
 {
-    for (size_t i = 0; i < m_iterators.size(); ++i) {
-        delete m_iterators[i];
-    }
     m_iterators.clear();
-
-    m_segments.clear();
+    m_buffers.clear();
 }
 
 void
@@ -97,8 +87,9 @@ MappedBufMetaIterator::reset()
     m_currentTime = RealTime::zeroTime;
 
     // Reset each iterator.
-    for (SegmentIterators::iterator i = m_iterators.begin();
-         i != m_iterators.end(); ++i) {
+    for (IteratorVector::iterator i = m_iterators.begin();
+         i != m_iterators.end();
+         ++i) {
         (*i)->reset();
     }
 }
@@ -112,53 +103,13 @@ MappedBufMetaIterator::jumpToTime(const RealTime &time)
 
     m_currentTime = time;
 
-    for (SegmentIterators::iterator i = m_iterators.begin();
-         i != m_iterators.end(); ++i) {
-        moveIteratorToTime(**i, time);
+    for (IteratorVector::iterator i = m_iterators.begin();
+         i != m_iterators.end();
+         ++i) {
+        (*i)->moveTo(time);
     }
 }
 
-void
-MappedBufMetaIterator::moveIteratorToTime(MappedEventBuffer::iterator &iter,
-                                          const RealTime &time)
-{
-    // ??? Move this routine to MappedEventBuffer::iterator::moveTo(time).
-
-    // Rather than briefly unlock and immediately relock each
-    // iteration, we leave the lock on until we're done.
-    QReadLocker locker(iter.getLock());
-
-    // For each event from the current iterator position
-    while (1) {
-        if (iter.atEnd())
-            break;
-
-        // We use peek because it's safe even if we have not fully
-        // filled the buffer yet.  That means we can get nullptr.
-        const MappedEvent *event = iter.peek();
-
-        // We know nothing about the event yet.  Stop here.
-        if (!event)
-            break;
-
-#if 1
-        // If the event sounds past time, stop here.
-        // This will cause re-firing of events in progress.
-        if (event->getEventTime() + event->getDuration() >= time)
-            break;
-#else
-        // If the event starts on or after time, stop here.
-        // This will cause events in progress to be skipped.
-        if (event->getEventTime() >= time)
-            break;
-#endif
-
-        ++iter;
-    }
-
-    iter.setReady(false);
-}
-
 void
 MappedBufMetaIterator::fetchFixedChannelSetup(MappedInserterBase &inserter)
 {
@@ -166,8 +117,8 @@ MappedBufMetaIterator::fetchFixedChannelSetup(MappedInserterBase &inserter)
     std::set<TrackId> tracks;
 
     // for each MappedEventBuffer/segment in m_segments
-    for (MappedSegments::iterator i = m_segments.begin();
-         i != m_segments.end(); ++i) {
+    for (BufferSet::iterator i = m_buffers.begin();
+         i != m_buffers.end(); ++i) {
         QSharedPointer<MappedEventBuffer> mappedEventBuffer = *i;
 
         TrackId trackID = mappedEventBuffer->getTrackID();
@@ -194,60 +145,70 @@ MappedBufMetaIterator::fetchEvents(MappedInserterBase &inserter,
     RG_DEBUG << "fetchEvents() " << startTime << " -> " << endTime;
 #endif
 
-    // To keep mappers on the same channel from interfering, for
+    // To keep buffers on the same channel from interfering, for
     // instance sending their initializations while another is playing
     // on the channel, we divide the timeslice into sub-slices during which
-    // no new mappers start and pass each sub-slice to
-    // fetchEventsNoncompeting.  We could re-slice it smarter but this
+    // no buffers start and pass each sub-slice to
+    // fetchEventsNoncompeting().  We could re-slice it smarter but this
     // suffices.
 
-    // Make a queue of all segment starts that occur during the slice.
-    // ??? Why not use std::set instead?  All this is doing is sorting
-    //     the start times.  std::vector and std::sort() should be another
-    //     option.  Using std::priority_queue implies there will be a
-    //     Compare predicate that is more interesting than std::greater.
-    std::priority_queue<RealTime,
-                        std::vector<RealTime>,
-                        std::greater<RealTime> >
-        segStarts;
+    // Test Case?  I suspect that two Segment's that butt up against
+    // each other and that trigger resending of channel setup would
+    // be the test case here.  Thing is that I don't think we do that
+    // anymore.  All this sub-slicing might be pointless now.
 
-    for (SegmentIterators::iterator i = m_iterators.begin();
-         i != m_iterators.end();
+    // Note that the slices are about 160msecs.  It's very unlikely that
+    // there will be anything interesting ever going on in this routine.
+
+    // Make a set of all buffer starts that occur during the slice sorted
+    // from earliest to latest.
+    typedef std::set<RealTime> TimeSet;
+    TimeSet bufferStarts;
+
+    // For each buffer.
+    for (BufferSet::iterator i = m_buffers.begin();
+         i != m_buffers.end();
          ++i) {
         RealTime start;
         RealTime end;
-        (*i)->getSegment()->getStartEnd(start, end);
+        (*i)->getStartEnd(start, end);
         // If this segment's start is within the timeslice, add it
-        // to segStarts.
-        if (start >= startTime  &&  start < endTime)
-            segStarts.push(start);
+        // to bufferStarts.
+        if (start >= startTime  &&  start < endTime) {
+            bufferStarts.insert(start);
+            //RG_DEBUG << "sub-slice: " << start;
+        }
     }
 
+    //if (!bufferStarts.empty()) {
+    //    RG_DEBUG << "  fetchEvents()" << startTime << "-" << endTime;
+    //    RG_DEBUG << "  bufferStarts.size(): " << bufferStarts.size();
+    //}
+
     // The progressive starting time, updated each iteration.
     RealTime innerStart = startTime;
 
-    // For each distinct gap, do a slice.
-    while (!segStarts.empty()) {
-        // We're at innerStart.  Get a mapper that didn't start yet.
-        RealTime innerEnd = segStarts.top();
-        // Remove it from the queue.
-        segStarts.pop();
-        // If it starts exactly at innerStart, it doesn't need its own
-        // slice.
-        if (innerEnd == innerStart)
-            continue;
-        // Get a slice from the previous end-time (or startTime) to
-        // this new start-time.
+    // For each sub-slice
+    for (TimeSet::const_iterator i = bufferStarts.begin();
+         i != bufferStarts.end();
+         ++i) {
+        // Get the end of the current sub-slice.
+        RealTime innerEnd = *i;
+
+        //RG_DEBUG << "  fetchEventsNoncompeting(): " << innerStart << "-" << innerEnd;
+
+        // Get the sub-slice
         fetchEventsNoncompeting(inserter, innerStart, innerEnd);
+
+        // Move to the next sub-slice
         innerStart = innerEnd;
     }
 
     // Do one more slice to take us to the end time.  This is always
-    // correct to do, since segStarts can't contain a start equal to
+    // correct to do, since bufferStarts can't contain a start equal to
     // endTime.
     fetchEventsNoncompeting(inserter, innerStart, endTime);
 
-    return;
 }
 
 void
@@ -265,12 +226,12 @@ fetchEventsNoncompeting(MappedInserterBase &inserter,
     m_currentTime = endTime;
     
     // For each segment, activate segments that have anything playing.
-    for (SegmentIterators::iterator i = m_iterators.begin();
+    for (IteratorVector::iterator i = m_iterators.begin();
          i != m_iterators.end();
          ++i) { 
         RealTime start;
         RealTime end;
-        (*i)->getSegment()->getStartEnd(start, end);
+        (*i)->getMappedEventBuffer()->getStartEnd(start, end);
 
         // Activate segments that have anything playing during this
         // slice.  We include segments that end exactly when we start, but
@@ -300,8 +261,10 @@ fetchEventsNoncompeting(MappedInserterBase &inserter,
         segmentsHaveMore = false;
 
         // For each segment, process only the first event.
-        for (size_t i = 0; i < m_iterators.size(); ++i) {
-            MappedEventBuffer::iterator *iter = m_iterators[i];
+        for (IteratorVector::iterator i = m_iterators.begin();
+             i != m_iterators.end();
+             ++i) {
+            QSharedPointer<MEBIterator> iter = (*i);
 
 #ifdef DEBUG_META_ITERATOR
             RG_DEBUG << "fetchEventsNoncompeting() : checking segment #" << i;
@@ -402,17 +365,18 @@ fetchEventsNoncompeting(MappedInserterBase &inserter,
 }
 
 void
-MappedBufMetaIterator::
-resetIteratorForSegment(QSharedPointer<MappedEventBuffer> mappedEventBuffer, bool immediate)
+MappedBufMetaIterator::resetIteratorForBuffer(
+        QSharedPointer<MappedEventBuffer> mappedEventBuffer, bool immediate)
 {
     // For each segment
-    for (SegmentIterators::iterator i = m_iterators.begin();
-         i != m_iterators.end(); ++i) {
+    for (IteratorVector::iterator i = m_iterators.begin();
+         i != m_iterators.end();
+         ++i) {
 
-        MappedEventBuffer::iterator *iter = *i;
+        QSharedPointer<MEBIterator> iter = *i;
 
         // If we found it
-        if (iter->getSegment() == mappedEventBuffer) {
+        if (iter->getMappedEventBuffer() == mappedEventBuffer) {
 
 #ifdef DEBUG_META_ITERATOR
             RG_DEBUG << "resetIteratorForSegment(" << mappedEventBuffer << ") : found iterator";
@@ -420,7 +384,7 @@ resetIteratorForSegment(QSharedPointer<MappedEventBuffer> mappedEventBuffer, boo
 
             if (immediate) {
                 iter->reset();
-                moveIteratorToTime(*iter, m_currentTime);
+                iter->moveTo(m_currentTime);
             } else {
                 iter->setReady(false);
             }
@@ -438,10 +402,15 @@ MappedBufMetaIterator::getAudioEvents(std::vector<MappedEvent> &audioEvents)
     audioEvents.clear();
 
     // For each segment
-    for (MappedSegments::iterator i = m_segments.begin();
-         i != m_segments.end(); ++i) {
+    for (BufferSet::iterator i = m_buffers.begin();
+         i != m_buffers.end(); ++i) {
 
-        MappedEventBuffer::iterator iter(*i);
+        // ??? The various features of MEBIterator are not needed here.
+        //     Instead, we should probably lock the buffer for read
+        //     (MappedEventBuffer::m_lock which should probably be
+        //     public) and get at it directly via
+        //     MappedEventBuffer::getBuffer() (or just make m_buffer public).
+        MEBIterator iter(*i);
 
         // For each event
         while (!iter.atEnd()) {
@@ -475,82 +444,12 @@ MappedBufMetaIterator::getAudioEvents(std::vector<MappedEvent> &audioEvents)
             }
 
             // ??? Why does this need to contain copies?  Can we simplify
-            //     to pointers to the originals?
+            //     to pointers to the originals?  Maybe switch to
+            //     QSharedPointer?
             audioEvents.push_back(event);
         }
     }
 }
 
-#if 0
-std::vector<MappedEvent> &
-MappedBufMetaIterator::getPlayingAudioFiles(const RealTime &songPosition)
-{
-    // Clear playing audio segments
-    //
-    m_playingAudioSegments.clear();
-
-#ifdef DEBUG_PLAYING_AUDIO_FILES
-    RG_DEBUG << "getPlayingAudioFiles()...";
-#endif
-
-    for (MappedSegments::iterator i = m_segments.begin();
-         i != m_segments.end(); ++i) {
-
-        MappedEventBuffer::iterator iter(*i);
-
-        while (!iter.atEnd()) {
-            if ((*iter).getType() != MappedEvent::Audio) {
-                ++iter;
-                continue;
-            }
-
-            MappedEvent evt(*iter);
-
-            // Check for this track being muted or soloed
-            //
-            if (ControlBlock::getInstance()->isTrackMuted(evt.getTrackId()) == true) {
-#ifdef DEBUG_PLAYING_AUDIO_FILES
-                RG_DEBUG << "  track " << evt.getTrackId() << " is muted";
-#endif
-
-                ++iter;
-                continue;
-            }
-
-            if (ControlBlock::getInstance()->isSolo() == true &&
-                evt.getTrackId() != ControlBlock::getInstance()->getSelectedTrack()) {
-#ifdef DEBUG_PLAYING_AUDIO_FILES
-                RG_DEBUG << "  track " << evt.getTrackId() << " is not solo track";
-#endif
-
-                ++iter;
-                continue;
-            }
-
-            // If there's an audio event and it should be playing at this time
-            // then flag as such.
-            //
-            if (songPosition > evt.getEventTime() - RealTime(1, 0) &&
-                songPosition < evt.getEventTime() + evt.getDuration()) {
-
-#ifdef DEBUG_PLAYING_AUDIO_FILES
-                RG_DEBUG << "  instrument id = " << evt.getInstrument();
-                RG_DEBUG << "  id " << evt.getRuntimeSegmentId() << ", audio event time     = " << evt.getEventTime();
-                RG_DEBUG << "  audio event duration = " << evt.getDuration();
-#endif // DEBUG_PLAYING_AUDIO_FILES
-
-                m_playingAudioSegments.push_back(evt);
-            }
-
-            ++iter;
-        }
-
-        //RG_DEBUG << "END OF ITERATOR\n";
-    }
-
-    return m_playingAudioSegments;
-}
-#endif
-
 
 }
