@@ -51,9 +51,6 @@ protected:
 
     std::string getDataBlock(blockid);
 
-    void addDataByteForEvent(MidiByte byte, MappedEvent*);
-
-
     blockid registerDataBlock(const std::string&);
     void unregisterDataBlock(blockid);
 
@@ -128,9 +125,9 @@ public:
 
         // Update Instruments - new ALSA client detected
         SystemUpdateInstruments  = 1 << 13,
-        // Set RG as JACK master/slave
+        // Set RG as JACK source/follower
         SystemJackTransport      = 1 << 14,
-        // Set RG as MMC master/slave
+        // Set RG as MMC source/follower
         SystemMMCTransport       = 1 << 15,
         // Set System Messages and MIDI Clock
         SystemMIDIClock          = 1 << 16,
@@ -152,7 +149,7 @@ public:
         // Panic function
         Panic                    = 1 << 24,
 
-        // Set RG as MTC master/slave
+        // Set RG as MTC source/follower
         SystemMTCTransport       = 1 << 25,
         // Auto-connect sync outputs
         SystemMIDISyncAuto       = 1 << 26,
@@ -206,7 +203,7 @@ public:
         WarningImpreciseTimerTryRTC = 11
     } FailureCode;
 
-    MappedEvent(): m_trackId((int)NO_TRACK),
+    MappedEvent(): m_trackId((int)NoTrack),
                    m_instrument(0),
                    m_type(InvalidMappedEvent),
                    m_data1(0),
@@ -241,7 +238,7 @@ public:
                 const RealTime &absTime,
                 const RealTime &duration,
                 const RealTime &audioStartMarker):
-        m_trackId((int)NO_TRACK),
+        m_trackId((int)NoTrack),
         m_instrument(id),
         m_type(type),
         m_data1(pitch),
@@ -264,7 +261,7 @@ public:
                 const RealTime &eventTime,
                 const RealTime &duration,
                 const RealTime &audioStartMarker):
-         m_trackId((int)NO_TRACK),
+         m_trackId((int)NoTrack),
          m_instrument(id),
          m_type(Audio),
          m_data1(audioID % 256),
@@ -287,7 +284,7 @@ public:
                 MappedEventType type,
                 MidiByte data1,
                 MidiByte data2):
-         m_trackId((int)NO_TRACK),
+         m_trackId((int)NoTrack),
          m_instrument(id),
          m_type(type),
          m_data1(data1),
@@ -303,10 +300,18 @@ public:
          m_recordedChannel(0),
          m_recordedDevice(0) {}
 
+    /**
+     * For SysEx...
+     *   - Set instrumentId to NoInstrument.
+     *   - Set type to MidiSystemMessage.
+     *   - Set data1 to MIDI_SYSTEM_EXCLUSIVE.
+     *   - Set recorded device with the destination device.
+     *   - Call addDataString() to add the SysEx data.
+     */
     MappedEvent(InstrumentId id,
                 MappedEventType type,
                 MidiByte data1):
-        m_trackId((int)NO_TRACK),
+        m_trackId((int)NoTrack),
         m_instrument(id),
         m_type(type),
         m_data1(data1),
@@ -322,13 +327,10 @@ public:
         m_recordedChannel(0),
         m_recordedDevice(0) {}
 
-
-    // Construct SysExs say
-    //
-    MappedEvent(InstrumentId id,
+    MappedEvent(InstrumentId instrumentId,
                 MappedEventType type):
-        m_trackId((int)NO_TRACK),
-        m_instrument(id),
+        m_trackId((int)NoTrack),
+        m_instrument(instrumentId),
         m_type(type),
         m_data1(0),
         m_data2(0),
@@ -474,10 +476,17 @@ public:
 
     MappedEvent& operator=(const MappedEvent &mE);
 
-    /// Add a single byte to the event's datablock (for SysExs)
-    void addDataByte(MidiByte byte);
-    /// Add several bytes to the event's datablock
-    void addDataString(const std::string& data);
+    /// Add several raw bytes to the event's SysEx datablock.
+    /*
+     * If the block doesn't exist, it is created.
+     *
+     * To set up a SysEx message, see the comments on the ctor that
+     * takes three parameters.
+     *
+     * DO NOT include the F0/F7 SOX/EOX in the block.  Those will be
+     * added by AlsaDriver::processMidiOut().
+     */
+    void addDataString(const std::string &rawData);
 
     /// Size of a MappedEvent in a stream
     static const size_t streamedSize;
