@@ -3,7 +3,7 @@
 /*
   Rosegarden
   A sequencer and musical notation editor.
-  Copyright 2000-2017 the Rosegarden development team.
+  Copyright 2000-2018 the Rosegarden development team.
  
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -103,7 +103,7 @@ PeakFile::open()
 
     try {
         parseHeader();
-    } catch (BadSoundFileException s) {
+    } catch (const BadSoundFileException &s) {
 
 #ifdef DEBUG_PEAKFILE
         RG_WARNING << "open() - EXCEPTION \"" << s.getMessage() << "\"";
@@ -208,7 +208,7 @@ PeakFile::write()
     try {
         if (!m_audioFile->open())
             return false;
-    } catch (BadSoundFileException e) {
+    } catch (const BadSoundFileException &e) {
 #ifdef DEBUG_PEAKFILE
         RG_WARNING << "write() - \"" << e.getMessage() << "\"";
 #endif
@@ -239,10 +239,10 @@ PeakFile::close()
     if (m_inFile && m_inFile->is_open()) {
         m_inFile->close();
         delete m_inFile;
-        m_inFile = 0;
+        m_inFile = nullptr;
     }
 
-    if (m_outFile == 0)
+    if (m_outFile == nullptr)
         return ;
 
     // Seek to start of chunk
@@ -300,7 +300,7 @@ PeakFile::close()
     //
     m_outFile->close();
     delete m_outFile;
-    m_outFile = 0;
+    m_outFile = nullptr;
 }
 
 bool
@@ -515,7 +515,7 @@ PeakFile::writePeaks(std::ofstream *file)
             // Read a block
             samples = m_audioFile->
                       getBytes(m_blockSize * channels * bytes);
-        } catch (BadSoundFileException e) {
+        } catch (const BadSoundFileException &e) {
             RG_WARNING << "writePeaks():" << e.getMessage();
             break;
         }
@@ -674,7 +674,7 @@ PeakFile::getPreview(const RealTime &startTime,
             try
             {
                 m_peakCache = getBytes(m_inFile, getSize() - 128);
-            } catch (BadSoundFileException e)
+            } catch (const BadSoundFileException &e)
             {
                 RG_WARNING << "PeakFile::getPreview: " << e.getMessage();
             }
@@ -789,7 +789,7 @@ PeakFile::getPreview(const RealTime &startTime,
 
                     try {
                         peakData = getBytes(m_inFile, m_format * m_pointsPerValue);
-                    } catch (BadSoundFileException e) {
+                    } catch (const BadSoundFileException &e) {
                         // Problem with the get - probably an EOF
                         // return the results so far.
                         //
@@ -968,7 +968,7 @@ PeakFile::getSplitPoints(const RealTime &startTime,
         for (int ch = 0; ch < m_channels; ch++) {
             try {
                 peakData = getBytes(m_inFile, m_format * m_pointsPerValue);
-            } catch (BadSoundFileException e) {
+            } catch (const BadSoundFileException &e) {
                 RG_WARNING << "getSplitPoints(): " << e.getMessage();
                 break;
             }
