@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
     See the AUTHORS file for more details.
 
     This program is free software; you can redistribute it and/or
@@ -44,7 +44,7 @@ class PeakFileManager : public QObject
     Q_OBJECT
 public:
     PeakFileManager();
-    virtual ~PeakFileManager();
+    ~PeakFileManager() override;
     
     class BadPeakFileException : public Exception
     {
@@ -56,7 +56,7 @@ public:
         BadPeakFileException(const SoundFile::BadSoundFileException &e) :
             Exception(QObject::tr("Bad peak file (malformed audio?) ") + e.getPath()), m_path(e.getPath()) { }
 
-        ~BadPeakFileException() throw() { }
+        ~BadPeakFileException() throw() override { }
 
         QString getPath() const { return m_path; }
 
