@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2018 the Rosegarden development team.
+    Copyright 2000-2020 the Rosegarden development team.
     See the AUTHORS file for more details.
  
     This program is free software; you can redistribute it and/or
@@ -22,8 +22,9 @@
 #include "WAVAudioFile.h"
 #include "MappedStudio.h"
 #include "AudioPlayQueue.h"
+#include "PlayableAudioFile.h"
 
-#include <unistd.h>
+#include <unistd.h>  // for usleep()
 #include <sys/time.h>
 #include <pthread.h> // for mutex
 
@@ -32,55 +33,29 @@
 namespace Rosegarden
 {
 
-// ---------- SoundDriver -----------
-//
 
-
-SoundDriver::SoundDriver(MappedStudio *studio, const std::string &name):
+SoundDriver::SoundDriver(MappedStudio *studio, const QString &name) :
         m_name(name),
         m_driverStatus(NO_DRIVER),
+        m_sequencer(nullptr),
         m_playStartPosition(0, 0),
-        m_startPlayback(false),
         m_playing(false),
-        m_midiRecordDevice(0),
         m_recordStatus(RECORD_OFF),
-        m_midiRunningId(MidiInstrumentBase),
-        m_audioRunningId(AudioInstrumentBase),
-        //    m_audioQueueScavenger(4, 50),
+        m_midiClockInterval(0, 0),
         m_audioQueue(nullptr),
-        m_lowLatencyMode(true),
+        m_smallFileSize(0),
         m_audioRecFileFormat(RIFFAudioFile::FLOAT),
-        m_studio(studio),
-        m_externalTransport(nullptr),
-        m_mmcStatus(TRANSPORT_OFF),
-        m_mtcStatus(TRANSPORT_OFF),
-        m_mmcId(0),            // default MMC id of 0
-        m_midiClockEnabled(false),
-        m_midiClockInterval(0, 0)
+        m_studio(studio)
 {
     m_audioQueue = new AudioPlayQueue();
 }
 
-
 SoundDriver::~SoundDriver()
 {
     RG_DEBUG << "SoundDriver::~SoundDriver (exiting)";
     delete m_audioQueue;
 }
 
-MappedInstrument*
-SoundDriver::getMappedInstrument(InstrumentId id)
-{
-    std::vector<MappedInstrument*>::const_iterator it;
-
-    for (it = m_instruments.begin(); it != m_instruments.end(); ++it) {
-        if ((*it)->getId() == id)
-            return (*it);
-    }
-
-    return nullptr;
-}
-
 void
 SoundDriver::initialiseAudioQueue(const std::vector<MappedEvent> &events)
 {
@@ -100,7 +75,7 @@ SoundDriver::initialiseAudioQueue(const std::vector<MappedEvent> &events)
         if (audioFile) {
             MappedAudioFader *fader =
                 dynamic_cast<MappedAudioFader*>
-                (getMappedStudio()->getAudioFader(i->getInstrument()));
+                (m_studio->getAudioFader(i->getInstrument()));
 
             if (!fader) {
                 RG_DEBUG << "WARNING: SoundDriver::initialiseAudioQueue: no fader for audio instrument " << i->getInstrument();
@@ -129,7 +104,7 @@ SoundDriver::initialiseAudioQueue(const std::vector<MappedEvent> &events)
                                             i->getAudioStartMarker(),
                                             i->getDuration(),
                                             bufferFrames,
-                                            size_t(getSmallFileSize()) * 1024,
+                                            size_t(m_smallFileSize) * 1024,
                                             channels,
                                             int(getSampleRate()));
             } catch (...) {
@@ -185,51 +160,6 @@ SoundDriver::initialiseAudioQueue(const std::vector<MappedEvent> &events)
         m_audioQueueScavenger.claim(oldQueue);
 }
 
-void
-SoundDriver::clearAudioQueue()
-{
-    RG_DEBUG << "SoundDriver::clearAudioQueue";
-
-    if (m_audioQueue->empty())
-        return ;
-
-    AudioPlayQueue *newQueue = new AudioPlayQueue();
-    AudioPlayQueue *oldQueue = m_audioQueue;
-    m_audioQueue = newQueue;
-    if (oldQueue)
-        m_audioQueueScavenger.claim(oldQueue);
-}
-void
-SoundDriver::cancelAudioFile(MappedEvent *mE)
-{
-    RG_DEBUG << "SoundDriver::cancelAudioFile";
-
-    if (!m_audioQueue)
-        return ;
-
-    // For now we only permit cancelling unscheduled files.
-
-    const AudioPlayQueue::FileList &files = m_audioQueue->getAllUnscheduledFiles();
-    for (AudioPlayQueue::FileList::const_iterator fi = files.begin();
-            fi != files.end(); ++fi) {
-        PlayableAudioFile *file = *fi;
-        if (mE->getRuntimeSegmentId() == -1) {
-
-            // ERROR? The comparison between file->getAudioFile()->getId() of type unsigned int
-            //        and mE->getAudioID() of type int.
-            if (file->getInstrument() == mE->getInstrument() &&
-                    int(file->getAudioFile()->getId()) == mE->getAudioID()) {
-                file->cancel();
-            }
-        } else {
-            if (file->getRuntimeSegmentId() == mE->getRuntimeSegmentId() &&
-                    file->getStartTime() == mE->getEventTime()) {
-                file->cancel();
-            }
-        }
-    }
-}
-
 const AudioPlayQueue *
 SoundDriver::getAudioQueue() const
 {
@@ -259,6 +189,7 @@ SoundDriver::setMappedInstrument(MappedInstrument *mI)
     << "id = " << mI->getId();
 
 }
+
 /*!DEVPUSH
 unsigned int
 SoundDriver::getDevices()
@@ -298,7 +229,6 @@ SoundDriver::getMappedDevice(DeviceId id)
 */
 
 
-
 bool
 SoundDriver::addAudioFile(const QString &fileName, unsigned int id)
 {
