@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
     See the AUTHORS file for more details.
  
     This program is free software; you can redistribute it and/or
@@ -24,14 +24,20 @@
 namespace Rosegarden
 {
 
+static bool s_soundEnabled = true;
+
 SoundDriver *
 SoundDriverFactory::createDriver(MappedStudio *studio)
 {
-    SoundDriver *driver = 0;
+    SoundDriver *driver = nullptr;
     bool initialised = false;
 
 #ifdef HAVE_ALSA
-    driver = new AlsaDriver(studio);
+    if (s_soundEnabled) {
+        driver = new AlsaDriver(studio);
+    } else {
+        driver = new DummyDriver(studio);
+    }
 #else
     driver = new DummyDriver(studio);
 #endif
@@ -55,6 +61,10 @@ SoundDriverFactory::createDriver(MappedStudio *studio)
     return driver;
 }
 
+void SoundDriverFactory::setSoundEnabled(bool b)
+{
+    s_soundEnabled = b;
+}
 
 }
 
