@@ -3,7 +3,7 @@
 /*
     Rosegarden
     A MIDI and audio sequencer and musical notation editor.
-    Copyright 2000-2017 the Rosegarden development team.
+    Copyright 2000-2018 the Rosegarden development team.
  
     This file is Copyright 2005-2011 Chris Cannam.
 
@@ -33,13 +33,13 @@ class ROSEGARDENPRIVATE_EXPORT WavFileWriteStream : public AudioWriteStream
 {
 public:
     WavFileWriteStream(Target target);
-    virtual ~WavFileWriteStream();
+    ~WavFileWriteStream() override;
 
     static void initStaticObjects();
 
-    virtual QString getError() const { return m_error; }
+    QString getError() const override { return m_error; }
 
-    virtual bool putInterleavedFrames(size_t count, float *frames);
+    bool putInterleavedFrames(size_t count, float *frames) override;
     
 protected:
     SF_INFO m_fileInfo;
